/* Paper title: 
Enterprise Zones, Poverty, and Labor Market Outcomes: Resolving Conflicting Evidence 

Authors: 
David Neumark
Timothy Young

* Journal: 
Regional Science and Urban Economics
*/

clear all

*** CHANGE DIRECTORY TO THE PATH FOR WHERE FOLDER IS LOCATED *** 
global dir 

global graphs "${dir}/Figures/"
global tables "${dir}/Tables/"
global rawdata "${dir}/Raw Data/"
global oghsisdata "${dir}/Raw Data/Original HSIS raw data/"
cd "${dir}/Generated data/"

********************************************************************************
********************************************************************************
* Clean raw NCDB data and combine with HSIS data for ENTZ analysis
********************************************************************************
********************************************************************************

*******************************************************************************
//						     Cleaning the NCDB    				 			//
*******************************************************************************

* Import NCDB Data 
import delimited "${rawdata}4_4_2017_Ham_replication.csv", clear
rename geo2000 tractid
sort tractid


* For each variable below, I replace the values equal to missing if the denominator used in the calculation == 0.

//							 Unemployment rate							 	//

foreach i in  8 9 0 {
replace unemprt`i' = . if unempt`i'd == 0
}

// 									Poverty 								//

foreach i in 8 9 0 {
replace povrat`i' = . if povrat`i'd == 0
}


//				 Fraction of Households with Wage and Salary Income 	    //

foreach i in 8 9 0 {
gen frac`i' = avemer`i'd/welfar`i'd
}

// 							Average wage and salary income 					//

foreach i in 8 9 0 {
replace avemer`i' = . if welfar`i'd ==0
}

//									Employment								//

* Variables indemp8 indemp9 indemp0 are all correctly coded

* Keep only the variables used in the analysis
keep tractid ucounty tract00 tch90_00 tch80_00 tch70_00 statecd state unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 pctcov70 pctcov80 trctpop8 unemprt8 povrat8n povrat8d povrat8 avemer8n avemer8d avemer8 trctpop9 indemp9 unempt9n unempt9d unemprt9

* Drop tracts with no people in 1980:
drop if trctpop8 == 0
drop if trctpop9 == 0


* Convert wages to real wages using the Census deflator for 2000 dollars: https://usa.ipums.org/usa/cpi99.shtml
replace avemer8 = 2.295*avemer8
replace avemer9 = 1.344*avemer9

/* Create a balanced panel of variables - ensures that the analysis is always performed on the same tracts.  Tracts are dropped if they are missing data for at least one of the variables.
foreach i of varlist unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 emprat8 emprat9 emprat0 welfare8 welfare9 welfare0 {
drop if `i' == . 
}
*/

* Convert proportions to percentages
foreach i of varlist unemprt8 povrat8 unemprt9 povrat9 unemprt0 povrat0 frac8 frac9 frac0 {
replace `i' = 100*`i'
}

save "NCDB_80_00_clean.dta", replace


***********************************
*****     Contiguous NENTZ    *****
***********************************

* Generate EZ identifiers to merge into Census data set.
use "${rawdata}Entz_Contiguous_Nentz.dta", clear
sort entzid
keep months entzid ezflag dez90to97 nez_dist state OTHER statename nentzid nentz1id nentz2id nentz3id nentz4id nentz5id nentz6id nentz7id nentz8id nentz9id nentz10id nentz11id CA CO FL HI IL MA NE NY OH OR RI VA WI county pop80_entz pop90_entz pop00_entz ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal

foreach i of varlist pop80_entz pop90_entz pop00_entz  ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_contig_entz_tracts
save `hsis_contig_entz_tracts', replace

* Get the NCDB ready to merge

* Rename tractid in NCDB to merge with Ham's data
use "NCDB_80_00_clean.dta", clear
rename tractid entzid
tempfile NCDB_80_00_contiguous_entzid
save `NCDB_80_00_contiguous_entzid', replace

* Generate nentzid in the NCDB to merge into Ham's data
use "NCDB_80_00_clean.dta", clear
rename tractid nentzid
foreach i of var unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
		gen `i'_nentz = `i'
}

tempfile NCDB_80_00_contiguous_nentzid
save `NCDB_80_00_contiguous_nentzid', replace

* Generate variables in the NCDB for each nentz contiguous tract (11): nentz1id - nentz11id
use "NCDB_80_00_clean.dta", clear
foreach i of num 1/11 {
		foreach j of var unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0  {
		gen `j'_nentz`i' = `j'
		}
}

tempfile NCDB_80_00_contig_temp
save `NCDB_80_00_contig_temp', replace

* Generate a data set containing outcome variables for each potential contiguous tract to merge with Ham's tract IDs
foreach i of num 1/11 {
	use `NCDB_80_00_contig_temp'
	keep ucounty trctpop8 trctpop9 tractid tract00 tch90_00 tch80_00 tch70_00 statecd state unemprt8_nentz`i' unemprt9_nentz`i' unemprt0_nentz`i' povrat8_nentz`i' povrat9_nentz`i' povrat0_nentz`i' frac8_nentz`i' frac9_nentz`i' frac0_nentz`i' avemer8_nentz`i' avemer9_nentz`i' avemer0_nentz`i' indemp8_nentz`i' indemp9_nentz`i' indemp0_nentz`i' 
	rename tractid nentz`i'id
	tempfile NCDB_80_00_contiguous_id`i'
	save `NCDB_80_00_contiguous_id`i'', replace	
}	

* Merge in NCDB into Ham's entz/nentz identified tracts	

use `hsis_contig_entz_tracts', clear


merge 1:m entzid using `NCDB_80_00_contiguous_entzid'
drop if _merge==2
drop _merge
merge m:1 nentzid using `NCDB_80_00_contiguous_nentzid'
drop if _merge==2
drop _merge

* Merge in each contiguous NENTZ (there are 11) at the tract level
foreach i of num 1/11 {
merge m:m nentz`i'id using `NCDB_80_00_contiguous_id`i''
drop if _merge==2
drop _merge
}	

* Generate a count for the number of contiguous tracts
gen num_tract_contig = 1
foreach i of numlist 1/11 {
replace num_tract_contig = num_tract_contig + 1 if nentz`i'id~=.
}

foreach i of varlist unemprt8_nentz1 unemprt9_nentz1 unemprt0_nentz1 povrat8_nentz1 povrat9_nentz1 povrat0_nentz1 frac8_nentz1 frac9_nentz1 frac0_nentz1 avemer8_nentz1 avemer9_nentz1 avemer0_nentz1 indemp8_nentz1 indemp9_nentz1 indemp0_nentz1 unemprt8_nentz2 unemprt9_nentz2 unemprt0_nentz2 povrat8_nentz2 povrat9_nentz2 povrat0_nentz2 frac8_nentz2 frac9_nentz2 frac0_nentz2 avemer8_nentz2 avemer9_nentz2 avemer0_nentz2 indemp8_nentz2 indemp9_nentz2 indemp0_nentz2 unemprt8_nentz3 unemprt9_nentz3 unemprt0_nentz3 povrat8_nentz3 povrat9_nentz3 povrat0_nentz3 frac8_nentz3 frac9_nentz3 frac0_nentz3 avemer8_nentz3 avemer9_nentz3 avemer0_nentz3 indemp8_nentz3 indemp9_nentz3 indemp0_nentz3 unemprt8_nentz4 unemprt9_nentz4 unemprt0_nentz4 povrat8_nentz4 povrat9_nentz4 povrat0_nentz4 frac8_nentz4 frac9_nentz4 frac0_nentz4 avemer8_nentz4 avemer9_nentz4 avemer0_nentz4 indemp8_nentz4 indemp9_nentz4 indemp0_nentz4 unemprt8_nentz5 unemprt9_nentz5 unemprt0_nentz5 povrat8_nentz5 povrat9_nentz5 povrat0_nentz5 frac8_nentz5 frac9_nentz5 frac0_nentz5 avemer8_nentz5 avemer9_nentz5 avemer0_nentz5 indemp8_nentz5 indemp9_nentz5 indemp0_nentz5 unemprt8_nentz6 unemprt9_nentz6 unemprt0_nentz6 povrat8_nentz6 povrat9_nentz6 povrat0_nentz6 frac8_nentz6 frac9_nentz6 frac0_nentz6 avemer8_nentz6 avemer9_nentz6 avemer0_nentz6 indemp8_nentz6 indemp9_nentz6 indemp0_nentz6 unemprt8_nentz7 unemprt9_nentz7 unemprt0_nentz7 povrat8_nentz7 povrat9_nentz7 povrat0_nentz7 frac8_nentz7 frac9_nentz7 frac0_nentz7 avemer8_nentz7 avemer9_nentz7 avemer0_nentz7 indemp8_nentz7 indemp9_nentz7 indemp0_nentz7 unemprt8_nentz8 unemprt9_nentz8 unemprt0_nentz8 povrat8_nentz8 povrat9_nentz8 povrat0_nentz8 frac8_nentz8 frac9_nentz8 frac0_nentz8 avemer8_nentz8 avemer9_nentz8 avemer0_nentz8 indemp8_nentz8 indemp9_nentz8 indemp0_nentz8 unemprt8_nentz9 unemprt9_nentz9 unemprt0_nentz9 povrat8_nentz9 povrat9_nentz9 povrat0_nentz9 frac8_nentz9 frac9_nentz9 frac0_nentz9 avemer8_nentz9 avemer9_nentz9 avemer0_nentz9 indemp8_nentz9 indemp9_nentz9 indemp0_nentz9 unemprt8_nentz10 unemprt9_nentz10 unemprt0_nentz10 povrat8_nentz10 povrat9_nentz10 povrat0_nentz10 frac8_nentz10 frac9_nentz10 frac0_nentz10 avemer8_nentz10 avemer9_nentz10 avemer0_nentz10 indemp8_nentz10 indemp9_nentz10 indemp0_nentz10 unemprt8_nentz11 unemprt9_nentz11 unemprt0_nentz11 povrat8_nentz11 povrat9_nentz11 povrat0_nentz11 frac8_nentz11 frac9_nentz11 frac0_nentz11 avemer8_nentz11 avemer9_nentz11 avemer0_nentz11 indemp8_nentz11 indemp9_nentz11 indemp0_nentz11 {
replace `i' = 0 if `i'==.
}

* Generate totals across all the contiguous nentzs
foreach i of varlist unemprt8_nentz unemprt9_nentz unemprt0_nentz povrat8_nentz povrat9_nentz povrat0_nentz frac8_nentz frac9_nentz frac0_nentz avemer8_nentz avemer9_nentz avemer0_nentz indemp8_nentz indemp9_nentz indemp0_nentz  {
bysort entzid: egen `i's = sum(`i' + `i'1 + `i'2 + `i'3 + `i'4 + `i'5 + `i'6 + `i'7 + `i'8 + `i'9 + `i'10 + `i'11) if statecd!=.
}

* Divide totals by the number of contiguous tracts that contributed to that total. This generates an average for each outcome of the contiguous tracts
foreach i of varlist unemprt8_nentzs unemprt9_nentzs unemprt0_nentzs povrat8_nentzs povrat9_nentzs povrat0_nentzs frac8_nentzs frac9_nentzs frac0_nentzs avemer8_nentzs avemer9_nentzs avemer0_nentzs indemp8_nentzs indemp9_nentzs indemp0_nentzs {
replace `i' = `i'/num_tract_contig
}


* Generate entz tags for variables
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0  avemer0 frac8 frac9 frac0 {
rename `i' `i'_entz
}

* Rename some state labels
label var MA "Massachusetts"
label var NE "Nebraska"
label var NY "New York"
label var OH "Ohio"
label var OR "Oregon"
label var RI "Rhode Island"
label var VA "Virginia"
label var WI "Wisconsin"

* Generate triple differenced variables
foreach i in unemprt povrat frac avemer indemp {
gen d_`i'80_90_entz = `i'9_entz - `i'8_entz
gen d_`i'90_00_entz = `i'0_entz - `i'9_entz
gen dd_`i'80_00_entz = d_`i'90_00_entz - d_`i'80_90_entz

gen d_`i'80_90_nentzs = `i'9_nentzs - `i'8_nentzs
gen d_`i'90_00_nentzs = `i'0_nentzs - `i'9_nentzs
gen dd_`i'80_00_nentzs = d_`i'90_00_nentzs - d_`i'80_90_nentzs

gen ddd_`i'_ncdb =  dd_`i'80_00_entz - dd_`i'80_00_nentzs
}


* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0 
drop if trctpop9 == . | trctpop9 == 0

save "hsis_NCDB_contiguous.dta", replace 	

	
***********************************
*****      Nearest NENTZ      *****
***********************************
clear

* Generate EZ identifiers to merge into Census data set.
use "${rawdata}Entz_Closest_Nentz.dta", clear
destring entzid, replace
destring nentzid, replace
sort entzid
keep months entzid ezflag dez90to97 nez_dist state  OTHER statename nentzid CA CO FL HI IL MA NE NY OH OR RI VA WI county pop80_entz pop90_entz pop00_entz ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal
foreach i of varlist months  ezflag dez90to97 nez_dist state statename county pop80_entz pop90_entz pop00_entz ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal OTHER {
rename `i' `i'_ham
}

tempfile hsis_near_tracts
save `hsis_near_tracts', replace

* NCDB for ENTZ
use "NCDB_80_00_clean.dta", clear
rename tractid entzid
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0 {
rename `i' `i'_entz
}

tempfile NCDB_80_00_nearest_entzid
save `NCDB_80_00_nearest_entzid', replace

* NCDB for NENTZ
use "NCDB_80_00_clean.dta", clear
rename tractid nentzid
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0  {
rename `i' `i'_nentz
}

tempfile NCDB_80_00_nearest_nentzid
save `NCDB_80_00_nearest_nentzid', replace

use `hsis_near_tracts', clear
merge 1:m entzid using `NCDB_80_00_nearest_entzid'
// All tracts in Ham data are matched with tracts in NCDB -- 26,833 NCDB tracts not matched.
drop if _merge==2
drop _merge
merge m:1 nentzid using `NCDB_80_00_nearest_nentzid'
// All tracts in Ham data are matched with tracts in NCDB -- 27,533 NCDB tracts not matched.
drop if _merge==2
drop _merge

* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0  // 72 obs dropped
drop if trctpop9 == . | trctpop9 == 0

* Rename some state labels
label var MA "Massachusetts"
label var NE "Nebraska"
label var NY "New York"
label var OH "Ohio"
label var OR "Oregon"
label var RI "Rhode Island"
label var VA "Virginia"
label var WI "Wisconsin"

* Generate triple differenced variables
foreach i in unemprt povrat frac avemer indemp {
gen d_`i'80_90_entz = `i'9_entz - `i'8_entz
gen d_`i'90_00_entz = `i'0_entz - `i'9_entz
gen dd_`i'80_00_entz = d_`i'90_00_entz - d_`i'80_90_entz

gen d_`i'80_90_nentz = `i'9_nentz - `i'8_nentz
gen d_`i'90_00_nentz = `i'0_nentz - `i'9_nentz
gen dd_`i'80_00_nentz = d_`i'90_00_nentz - d_`i'80_90_nentz

gen ddd_`i'_ncdb =  dd_`i'80_00_entz - dd_`i'80_00_nentz
}

save "hsis_NCDB_nearest.dta", replace

***********************************
******        All NENTZ       *****
***********************************

clear

* Generate EZ identifiers to merge into Census data set.
use "${rawdata}Entz_All_Nentz.dta", clear
drop entzid
destring id_fixed, gen(entzid)
sort entzid
keep months entzid ezflag dez90to97 entz CA CO FL HI IL MA NE NY OH OR RI VA WI CAentz FLentz MAentz NYentz OHentz ORentz OTHERentz OTHER county pop80 pop90 pop00 dd_unemployment dd_employment dd_poverty dd_fraction dd_rawagesal

foreach i of varlist months dez90to97 county pop80 pop90 pop00 dd_unemployment dd_employment dd_poverty dd_fraction dd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_all_tracts
save `hsis_all_tracts', replace

* Get the NCDB ready to merge

* NCDB for entz
use "NCDB_80_00_clean.dta", clear
rename tractid entzid

tempfile NCDB_80_00_All_entzid
save `NCDB_80_00_All_entzid', replace

use `hsis_all_tracts', clear
merge 1:m entzid using `NCDB_80_00_All_entzid'
drop if _merge==2
drop _merge

* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0 
drop if trctpop9 == . | trctpop9 == 0

* Rename some state labels
label var MA "Massachusetts"
label var NE "Nebraska"
label var NY "New York"
label var OH "Ohio"
label var OR "Oregon"
label var RI "Rhode Island"
label var VA "Virginia"
label var WI "Wisconsin"

* Generate double differences:
foreach i in  unemprt povrat avemer indemp frac {
gen dd_`i'_ncdb = (`i'0 - `i'9) - (`i'9-`i'8)
}
save "hsis_NCDB_all.dta", replace



********************************************************************************
*****     Contiguous NENTZ w/ original (incorrect) HSIS data for Table 2   *****
********************************************************************************

* Generate EZ identifiers to merge into Census data set.
import delimited "${oghsisdata}Entz_Contiguous_Nentz.csv", clear
sort entzid
keep months entzid ezflag dez90to97 nez_dist state other statename nentzid nentz1id nentz2id nentz3id nentz4id nentz5id nentz6id nentz7id nentz8id nentz9id nentz10id nentz11id ca co fl hi il ma ne ny oh or ri va wi county pop80_entz pop90_entz pop00_entz ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal

foreach i of varlist pop80_entz pop90_entz pop00_entz  ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_contig_entz_tracts
save `hsis_contig_entz_tracts', replace

* Get the NCDB ready to merge

* Rename tractid in NCDB to merge with Ham's data
use "NCDB_80_00_clean.dta", clear
rename tractid entzid
tempfile NCDB_80_00_contiguous_entzid
save `NCDB_80_00_contiguous_entzid', replace

* Generate nentzid in the NCDB to merge into Ham's data
use "NCDB_80_00_clean.dta", clear
rename tractid nentzid
foreach i of var unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
		gen `i'_nentz = `i'
}

tempfile NCDB_80_00_contiguous_nentzid
save `NCDB_80_00_contiguous_nentzid', replace

* Generate variables in the NCDB for each nentz contiguous tract (11): nentz1id - nentz11id
use "NCDB_80_00_clean.dta", clear
foreach i of num 1/11 {
		foreach j of var unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0  {
		gen `j'_nentz`i' = `j'
		}
}

tempfile NCDB_80_00_contig_temp
save `NCDB_80_00_contig_temp', replace

* Generate a data set containing outcome variables for each potential contiguous tract to merge with Ham's tract IDs
foreach i of num 1/11 {
	use `NCDB_80_00_contig_temp'
	keep ucounty trctpop8 trctpop9 tractid tract00 tch90_00 tch80_00 tch70_00 statecd state unemprt8_nentz`i' unemprt9_nentz`i' unemprt0_nentz`i' povrat8_nentz`i' povrat9_nentz`i' povrat0_nentz`i' frac8_nentz`i' frac9_nentz`i' frac0_nentz`i' avemer8_nentz`i' avemer9_nentz`i' avemer0_nentz`i' indemp8_nentz`i' indemp9_nentz`i' indemp0_nentz`i' 
	rename tractid nentz`i'id
	tempfile NCDB_80_00_contiguous_id`i'
	save `NCDB_80_00_contiguous_id`i'', replace	
}	

* Merge in NCDB into Ham's entz/nentz identified tracts	

use `hsis_contig_entz_tracts', clear


merge 1:m entzid using `NCDB_80_00_contiguous_entzid'
drop if _merge==2
drop _merge
merge m:1 nentzid using `NCDB_80_00_contiguous_nentzid'
drop if _merge==2
drop _merge

* Merge in each contiguous NENTZ (there are 11) at the tract level
foreach i of num 1/11 {
merge m:m nentz`i'id using `NCDB_80_00_contiguous_id`i''
drop if _merge==2
drop _merge
}	

* Generate a count for the number of contiguous tracts
gen num_tract_contig = 1
foreach i of numlist 1/11 {
replace num_tract_contig = num_tract_contig + 1 if nentz`i'id~=.
}

foreach i of varlist unemprt8_nentz1 unemprt9_nentz1 unemprt0_nentz1 povrat8_nentz1 povrat9_nentz1 povrat0_nentz1 frac8_nentz1 frac9_nentz1 frac0_nentz1 avemer8_nentz1 avemer9_nentz1 avemer0_nentz1 indemp8_nentz1 indemp9_nentz1 indemp0_nentz1 unemprt8_nentz2 unemprt9_nentz2 unemprt0_nentz2 povrat8_nentz2 povrat9_nentz2 povrat0_nentz2 frac8_nentz2 frac9_nentz2 frac0_nentz2 avemer8_nentz2 avemer9_nentz2 avemer0_nentz2 indemp8_nentz2 indemp9_nentz2 indemp0_nentz2 unemprt8_nentz3 unemprt9_nentz3 unemprt0_nentz3 povrat8_nentz3 povrat9_nentz3 povrat0_nentz3 frac8_nentz3 frac9_nentz3 frac0_nentz3 avemer8_nentz3 avemer9_nentz3 avemer0_nentz3 indemp8_nentz3 indemp9_nentz3 indemp0_nentz3 unemprt8_nentz4 unemprt9_nentz4 unemprt0_nentz4 povrat8_nentz4 povrat9_nentz4 povrat0_nentz4 frac8_nentz4 frac9_nentz4 frac0_nentz4 avemer8_nentz4 avemer9_nentz4 avemer0_nentz4 indemp8_nentz4 indemp9_nentz4 indemp0_nentz4 unemprt8_nentz5 unemprt9_nentz5 unemprt0_nentz5 povrat8_nentz5 povrat9_nentz5 povrat0_nentz5 frac8_nentz5 frac9_nentz5 frac0_nentz5 avemer8_nentz5 avemer9_nentz5 avemer0_nentz5 indemp8_nentz5 indemp9_nentz5 indemp0_nentz5 unemprt8_nentz6 unemprt9_nentz6 unemprt0_nentz6 povrat8_nentz6 povrat9_nentz6 povrat0_nentz6 frac8_nentz6 frac9_nentz6 frac0_nentz6 avemer8_nentz6 avemer9_nentz6 avemer0_nentz6 indemp8_nentz6 indemp9_nentz6 indemp0_nentz6 unemprt8_nentz7 unemprt9_nentz7 unemprt0_nentz7 povrat8_nentz7 povrat9_nentz7 povrat0_nentz7 frac8_nentz7 frac9_nentz7 frac0_nentz7 avemer8_nentz7 avemer9_nentz7 avemer0_nentz7 indemp8_nentz7 indemp9_nentz7 indemp0_nentz7 unemprt8_nentz8 unemprt9_nentz8 unemprt0_nentz8 povrat8_nentz8 povrat9_nentz8 povrat0_nentz8 frac8_nentz8 frac9_nentz8 frac0_nentz8 avemer8_nentz8 avemer9_nentz8 avemer0_nentz8 indemp8_nentz8 indemp9_nentz8 indemp0_nentz8 unemprt8_nentz9 unemprt9_nentz9 unemprt0_nentz9 povrat8_nentz9 povrat9_nentz9 povrat0_nentz9 frac8_nentz9 frac9_nentz9 frac0_nentz9 avemer8_nentz9 avemer9_nentz9 avemer0_nentz9 indemp8_nentz9 indemp9_nentz9 indemp0_nentz9 unemprt8_nentz10 unemprt9_nentz10 unemprt0_nentz10 povrat8_nentz10 povrat9_nentz10 povrat0_nentz10 frac8_nentz10 frac9_nentz10 frac0_nentz10 avemer8_nentz10 avemer9_nentz10 avemer0_nentz10 indemp8_nentz10 indemp9_nentz10 indemp0_nentz10 unemprt8_nentz11 unemprt9_nentz11 unemprt0_nentz11 povrat8_nentz11 povrat9_nentz11 povrat0_nentz11 frac8_nentz11 frac9_nentz11 frac0_nentz11 avemer8_nentz11 avemer9_nentz11 avemer0_nentz11 indemp8_nentz11 indemp9_nentz11 indemp0_nentz11 {
replace `i' = 0 if `i'==.
}

* Generate totals across all the contiguous nentzs
foreach i of varlist unemprt8_nentz unemprt9_nentz unemprt0_nentz povrat8_nentz povrat9_nentz povrat0_nentz frac8_nentz frac9_nentz frac0_nentz avemer8_nentz avemer9_nentz avemer0_nentz indemp8_nentz indemp9_nentz indemp0_nentz  {
bysort entzid: egen `i's = sum(`i' + `i'1 + `i'2 + `i'3 + `i'4 + `i'5 + `i'6 + `i'7 + `i'8 + `i'9 + `i'10 + `i'11) if statecd!=.
}

* Divide totals by the number of contiguous tracts that contributed to that total. This generates an average for each outcome of the contiguous tracts
foreach i of varlist unemprt8_nentzs unemprt9_nentzs unemprt0_nentzs povrat8_nentzs povrat9_nentzs povrat0_nentzs frac8_nentzs frac9_nentzs frac0_nentzs avemer8_nentzs avemer9_nentzs avemer0_nentzs indemp8_nentzs indemp9_nentzs indemp0_nentzs {
replace `i' = `i'/num_tract_contig
}


* Generate entz tags for variables
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0  avemer0 frac8 frac9 frac0 {
rename `i' `i'_entz
}

* Generate triple differenced variables
foreach i in unemprt povrat frac avemer indemp {
gen d_`i'80_90_entz = `i'9_entz - `i'8_entz
gen d_`i'90_00_entz = `i'0_entz - `i'9_entz
gen dd_`i'80_00_entz = d_`i'90_00_entz - d_`i'80_90_entz

gen d_`i'80_90_nentzs = `i'9_nentzs - `i'8_nentzs
gen d_`i'90_00_nentzs = `i'0_nentzs - `i'9_nentzs
gen dd_`i'80_00_nentzs = d_`i'90_00_nentzs - d_`i'80_90_nentzs

gen ddd_`i'_ncdb =  dd_`i'80_00_entz - dd_`i'80_00_nentzs
}


* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0 
drop if trctpop9 == . | trctpop9 == 0

save "hsis_NCDB_contiguous_og.dta", replace 	

	
********************************************************************************
******      Nearest NENTZ w/ original (incorrect) HSIS data for Table 2   ******
********************************************************************************
clear

* Generate EZ identifiers to merge into Census data set.
import delimited "${oghsisdata}Entz_Closest_Nentz.csv", clear
destring entzid, replace
destring nentzid, replace
sort entzid
keep months entzid ezflag dez90to97 nez_dist state other statename nentzid ca co fl hi il ma ne ny oh or ri va wi county pop80_entz pop90_entz pop00_entz ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal
foreach i of varlist months  ezflag dez90to97 nez_dist state statename county pop80_entz pop90_entz pop00_entz ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_near_tracts
save `hsis_near_tracts', replace

* NCDB for ENTZ
use "NCDB_80_00_clean.dta", clear
rename tractid entzid
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0 {
rename `i' `i'_entz
}

tempfile NCDB_80_00_nearest_entzid
save `NCDB_80_00_nearest_entzid', replace

* NCDB for NENTZ
use "NCDB_80_00_clean.dta", clear
rename tractid nentzid
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0  {
rename `i' `i'_nentz
}

tempfile NCDB_80_00_nearest_nentzid
save `NCDB_80_00_nearest_nentzid', replace

use `hsis_near_tracts', clear
merge 1:m entzid using `NCDB_80_00_nearest_entzid'
// All tracts in Ham data are matched with tracts in NCDB -- 26,833 NCDB tracts not matched.
drop if _merge==2
drop _merge
merge m:1 nentzid using `NCDB_80_00_nearest_nentzid'
// All tracts in Ham data are matched with tracts in NCDB -- 27,533 NCDB tracts not matched.
drop if _merge==2
drop _merge

* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0  // 72 obs dropped
drop if trctpop9 == . | trctpop9 == 0

* Generate triple differenced variables
foreach i in unemprt povrat frac avemer indemp {
gen d_`i'80_90_entz = `i'9_entz - `i'8_entz
gen d_`i'90_00_entz = `i'0_entz - `i'9_entz
gen dd_`i'80_00_entz = d_`i'90_00_entz - d_`i'80_90_entz

gen d_`i'80_90_nentz = `i'9_nentz - `i'8_nentz
gen d_`i'90_00_nentz = `i'0_nentz - `i'9_nentz
gen dd_`i'80_00_nentz = d_`i'90_00_nentz - d_`i'80_90_nentz

gen ddd_`i'_ncdb =  dd_`i'80_00_entz - dd_`i'80_00_nentz
}

save "hsis_NCDB_nearest_og.dta", replace

********************************************************************************
*******        All NENTZ w/ original (incorrect) HSIS data for Table 2   *******
********************************************************************************

clear

* Generate EZ identifiers to merge into Census data set.
import delimited "${oghsisdata}Entz_All_Nentz.csv", clear
drop entzid
rename id_fixed entzid
sort entzid
keep months entzid ezflag dez90to97 entz ca co fl hi il ma ne ny oh or ri va wi other county pop80 pop90 pop00 dd_unemployment dd_employment dd_poverty dd_fraction dd_rawagesal

foreach i of varlist months dez90to97 county pop80 pop90 pop00 dd_unemployment dd_employment dd_poverty dd_fraction dd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_all_tracts
save `hsis_all_tracts', replace

* Get the NCDB ready to merge

* NCDB for entz
use "NCDB_80_00_clean.dta", clear
rename tractid entzid

tempfile NCDB_80_00_All_entzid
save `NCDB_80_00_All_entzid', replace

use `hsis_all_tracts', clear
merge 1:m entzid using `NCDB_80_00_All_entzid'
drop if _merge==2
drop _merge

* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0 
drop if trctpop9 == . | trctpop9 == 0

* Generate double differences:
foreach i in  unemprt povrat avemer indemp frac {
gen dd_`i'_ncdb = (`i'0 - `i'9) - (`i'9-`i'8)
}
save "hsis_NCDB_all_og.dta", replace

















********************************************************************************
********************************************************************************
* Clean raw NCDB data and combine with HSIS data for EMPZ analysis
********************************************************************************
********************************************************************************


***********************************
*****     Contiguous NEMPZ    *****
***********************************

* Generate EZ identifiers to merge into Census data set.
use "${rawdata}EMPZ_Contiguous_nempz.dta", clear
sort empzid
keep empzid state nempzid nempz1id nempz2id nempz3id nempz4id nempz5id nempz6id nempz7id nempz8id nempz9id nempz10id nempz11id CA DC GA IL IN KY MD MI MN MS MO NJ NY ND OH PA SC TN TX VA county pop80_empz pop90_empz pop00_empz ddd_unemployment ddd_employment  ddd_poverty ddd_fraction ddd_rawagesal

foreach i of varlist pop80_empz pop90_empz pop00_empz ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_contig_empz_tracts
save `hsis_contig_empz_tracts', replace

* Get the NCDB ready to merge

* Rename tractid in NCDB to merge with Ha's data
use "NCDB_80_00_clean.dta", clear
rename tractid empzid
tempfile NCDB_contiguous_empzid
save `NCDB_contiguous_empzid', replace

* Generate nempzid in the NCDB to merge into Ham's data
use "NCDB_80_00_clean.dta", clear
rename tractid nempzid
foreach i of var unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
		gen `i'_nempz = `i'
}

tempfile NCDB_contiguous_nempzid
save `NCDB_contiguous_nempzid', replace
 
* Generate variables in the NCDB for each nempz contiguous tract (11): nempz1id - nempz11id
use "NCDB_80_00_clean.dta", clear
foreach i of num 1/11 {
		foreach j of var unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
		gen `j'_nempz`i' = `j'
		}
}

tempfile NCDB_contig_temp_empz
save `NCDB_contig_temp_empz', replace

* Generate outcome variables for each potential contiguous tract to merge with Ham's tract IDs
foreach i of num 1/11 {
	use `NCDB_contig_temp_empz'
	keep ucounty trctpop8 trctpop9 tractid tract00 tch90_00 tch80_00 tch70_00 statecd state unemprt8_nempz`i' unemprt9_nempz`i' unemprt0_nempz`i' povrat8_nempz`i' povrat9_nempz`i' povrat0_nempz`i' frac8_nempz`i' frac9_nempz`i' frac0_nempz`i' avemer8_nempz`i' avemer9_nempz`i' avemer0_nempz`i' indemp8_nempz`i' indemp9_nempz`i' indemp0_nempz`i'
	rename tractid nempz`i'id
	tempfile NCDB_contiguous_id`i'_empz
	save `NCDB_contiguous_id`i'_empz', replace	
}	

* Merge in NCDB into Ham's empz/nempz identified tracts	
use `hsis_contig_empz_tracts', clear

merge 1:m empzid using `NCDB_contiguous_empzid'
drop if _merge==2
drop _merge
merge m:1 nempzid using `NCDB_contiguous_nempzid'
drop if _merge==2
drop _merge

* Merge in each contiguous Nempz (there are 11) at the tract level
foreach i of num 1/11 {
merge m:m nempz`i'id using `NCDB_contiguous_id`i'_empz'
drop if _merge==2
drop _merge
}	

* Generate a count for the number of contiguous tracts
gen num_tract_contig = 1
foreach i of numlist 1/11 {
replace num_tract_contig = num_tract_contig + 1 if nempz`i'id~=.
}

foreach i of varlist unemprt8_nempz unemprt9_nempz unemprt0_nempz povrat8_nempz povrat9_nempz povrat0_nempz frac8_nempz frac9_nempz frac0_nempz avemer8_nempz avemer9_nempz avemer0_nempz indemp8_nempz indemp9_nempz indemp0_nempz unemprt8_nempz1 unemprt9_nempz1 unemprt0_nempz1 povrat8_nempz1 povrat9_nempz1 povrat0_nempz1 frac8_nempz1 frac9_nempz1 frac0_nempz1 avemer8_nempz1 avemer9_nempz1 avemer0_nempz1 indemp8_nempz1 indemp9_nempz1 indemp0_nempz1 unemprt8_nempz2 unemprt9_nempz2 unemprt0_nempz2 povrat8_nempz2 povrat9_nempz2 povrat0_nempz2 frac8_nempz2 frac9_nempz2 frac0_nempz2 avemer8_nempz2 avemer9_nempz2 avemer0_nempz2 indemp8_nempz2 indemp9_nempz2 indemp0_nempz2 unemprt8_nempz3 unemprt9_nempz3 unemprt0_nempz3 povrat8_nempz3 povrat9_nempz3 povrat0_nempz3 frac8_nempz3 frac9_nempz3 frac0_nempz3 avemer8_nempz3 avemer9_nempz3 avemer0_nempz3 indemp8_nempz3 indemp9_nempz3 indemp0_nempz3 unemprt8_nempz4 unemprt9_nempz4 unemprt0_nempz4 povrat8_nempz4 povrat9_nempz4 povrat0_nempz4 frac8_nempz4 frac9_nempz4 frac0_nempz4 avemer8_nempz4 avemer9_nempz4 avemer0_nempz4 indemp8_nempz4 indemp9_nempz4 indemp0_nempz4 unemprt8_nempz5 unemprt9_nempz5 unemprt0_nempz5 povrat8_nempz5 povrat9_nempz5 povrat0_nempz5 frac8_nempz5 frac9_nempz5 frac0_nempz5 avemer8_nempz5 avemer9_nempz5 avemer0_nempz5 indemp8_nempz5 indemp9_nempz5 indemp0_nempz5 unemprt8_nempz6 unemprt9_nempz6 unemprt0_nempz6 povrat8_nempz6 povrat9_nempz6 povrat0_nempz6 frac8_nempz6 frac9_nempz6 frac0_nempz6 avemer8_nempz6 avemer9_nempz6 avemer0_nempz6 indemp8_nempz6 indemp9_nempz6 indemp0_nempz6 unemprt8_nempz7 unemprt9_nempz7 unemprt0_nempz7 povrat8_nempz7 povrat9_nempz7 povrat0_nempz7 frac8_nempz7 frac9_nempz7 frac0_nempz7 avemer8_nempz7 avemer9_nempz7 avemer0_nempz7 indemp8_nempz7 indemp9_nempz7 indemp0_nempz7 unemprt8_nempz8 unemprt9_nempz8 unemprt0_nempz8 povrat8_nempz8 povrat9_nempz8 povrat0_nempz8 frac8_nempz8 frac9_nempz8 frac0_nempz8 avemer8_nempz8 avemer9_nempz8 avemer0_nempz8 indemp8_nempz8 indemp9_nempz8 indemp0_nempz8 unemprt8_nempz9 unemprt9_nempz9 unemprt0_nempz9 povrat8_nempz9 povrat9_nempz9 povrat0_nempz9 frac8_nempz9 frac9_nempz9 frac0_nempz9 avemer8_nempz9 avemer9_nempz9 avemer0_nempz9 indemp8_nempz9 indemp9_nempz9 indemp0_nempz9 unemprt8_nempz10 unemprt9_nempz10 unemprt0_nempz10 povrat8_nempz10 povrat9_nempz10 povrat0_nempz10 frac8_nempz10 frac9_nempz10 frac0_nempz10 avemer8_nempz10 avemer9_nempz10 avemer0_nempz10 indemp8_nempz10 indemp9_nempz10 indemp0_nempz10 unemprt8_nempz11 unemprt9_nempz11 unemprt0_nempz11 povrat8_nempz11 povrat9_nempz11 povrat0_nempz11 frac8_nempz11 frac9_nempz11 frac0_nempz11 avemer8_nempz11 avemer9_nempz11 avemer0_nempz11 indemp8_nempz11 indemp9_nempz11 indemp0_nempz11 {
replace `i' = 0 if `i'==.
}

* Generate totals across all the contiguous nempzs
foreach i of varlist unemprt8_nempz unemprt9_nempz unemprt0_nempz povrat8_nempz povrat9_nempz povrat0_nempz frac8_nempz frac9_nempz frac0_nempz avemer8_nempz avemer9_nempz avemer0_nempz indemp8_nempz indemp9_nempz indemp0_nempz {
bysort empzid: egen `i's = sum(`i' + `i'1 + `i'2 + `i'3 + `i'4 + `i'5 + `i'6 + `i'7 + `i'8 + `i'9 + `i'10 + `i'11) if statecd!=.
}

* Divide totals by the number of contiguous tracts that contributed to that total. This generates an average for each outcome of the contiguous tracts
foreach i of varlist unemprt8_nempzs unemprt9_nempzs unemprt0_nempzs povrat8_nempzs povrat9_nempzs povrat0_nempzs frac8_nempzs frac9_nempzs frac0_nempzs avemer8_nempzs avemer9_nempzs avemer0_nempzs indemp8_nempzs indemp9_nempzs indemp0_nempzs {
replace `i' = `i'/num_tract_contig
}


* Generate empz tags for variables
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0 {
rename `i' `i'_empz
}


* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0
drop if trctpop9 == . | trctpop9 == 0

* Generate triple differenced variables
* Generate triple differenced variables
foreach i in unemprt povrat frac avemer indemp {
gen d_`i'80_90_empz = `i'9_empz - `i'8_empz
gen d_`i'90_00_empz = `i'0_empz - `i'9_empz
gen dd_`i'80_00_empz = d_`i'90_00_empz - d_`i'80_90_empz

gen d_`i'80_90_nempzs = `i'9_nempzs - `i'8_nempzs
gen d_`i'90_00_nempzs = `i'0_nempzs - `i'9_nempzs
gen dd_`i'80_00_nempzs = d_`i'90_00_nempzs - d_`i'80_90_nempzs

gen ddd_`i'_ncdb =  dd_`i'80_00_empz - dd_`i'80_00_nempzs
}


save "hsis_NCDB_contiguous_empz.dta", replace 	

	
***********************************
*****      Nearest NEMPZ      *****
***********************************
clear

* Generate EZ identifiers to merge into Census data set.
use "${rawdata}Empz_Closest_nempz.dta", clear
destring empzid, replace
destring nempzid, replace
sort empzid
keep empzid state nempzid CA DC GA IL IN KY MD MI MN MS MO NJ NY ND OH PA SC TN TX VA county pop80_empz pop90_empz pop00_empz ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal
foreach i of varlist pop80_empz pop90_empz pop00_empz  ddd_unemployment ddd_employment  ddd_poverty ddd_fraction ddd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_near_empz_tracts
save `hsis_near_empz_tracts', replace

* NCDB for empz
use "NCDB_80_00_clean.dta", clear
rename tractid empzid
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0 {
rename `i' `i'_empz
}

tempfile NCDB_near_empzid
save `NCDB_near_empzid', replace

use "NCDB_80_00_clean.dta", clear
rename tractid nempzid
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0 {
rename `i' `i'_nempz
}
tempfile NCDB_near_nempzid
save `NCDB_near_nempzid', replace

use `hsis_near_empz_tracts', clear
merge 1:m empzid using `NCDB_near_empzid'
drop if _merge==2
drop _merge
merge m:1 nempzid using `NCDB_near_nempzid'
drop if _merge==2
drop _merge

* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0
drop if trctpop9 == . | trctpop9 == 0

* Generate triple differenced variables
gen dd_unemprt_empz = (unemprt0_empz - unemprt9_empz) - (unemprt9_empz - unemprt8_empz)
gen dd_unemprt_nempz = (unemprt0_nempz - unemprt9_nempz) - (unemprt9_nempz - unemprt8_nempz)
gen ddd_unemprt_ncdb = dd_unemprt_empz - dd_unemprt_nempz

gen dd_povrat_empz = (povrat0_empz - povrat9_empz) - (povrat9_empz - povrat8_empz)
gen dd_povrat_nempz = (povrat0_nempz - povrat9_nempz) - (povrat9_nempz - povrat8_nempz)
gen ddd_povrat_ncdb = dd_povrat_empz - dd_povrat_nempz

gen dd_frac_empz = (frac0_empz - frac9_empz) - (frac9_empz - frac8_empz)
gen dd_frac_nempz = (frac0_nempz - frac9_nempz) - (frac9_nempz - frac8_nempz)
gen ddd_frac_ncdb =  dd_frac_empz - dd_frac_nempz

gen dd_avemer_empz = (avemer0_empz - avemer9_empz) - (avemer9_empz - avemer8_empz)
gen dd_avemer_nempz = (avemer0_nempz - avemer9_nempz) - (avemer9_nempz - avemer8_nempz)
gen ddd_avemer_ncdb = dd_avemer_empz - dd_avemer_nempz

gen dd_indemp_empz = (indemp0_empz - indemp9_empz) - (indemp9_empz - indemp8_empz)
gen dd_indemp_nempz = (indemp0_nempz - indemp9_nempz) - (indemp9_nempz - indemp8_nempz)
gen ddd_indemp_ncdb =  dd_indemp_empz -  dd_indemp_nempz

save "hsis_NCDB_nearest_empz.dta", replace

***********************************
******        All NEMPZ       *****
***********************************

clear

* Generate EZ identifiers to merge into Census data set.
use "${rawhsis}Empz_All_Nempz.dta", clear
destring id_tract, gen(id_fixed)
sort id_fixed
destring id_fixed, replace
foreach i of varlist pop80 pop90 pop00 dd_unemployment dd_employment dd_poverty dd_fraction dd_rawagesal {
rename `i' `i'_ham
}
keep id_fixed empzid empz AL AK AZ AR CA CO CT DE DC FL GA HI ID IL IN IA KS KY LA ME MD MA MI MN MS MO MT NE NV NH NJ NM NY NC ND OH OK OR PA RI SC SD TN TX UT VT VA WA WV WI county pop80 pop90 pop00 dd_unemployment_ham dd_employment_ham dd_poverty_ham dd_fraction_ham dd_rawagesal_ham
save "Ham_All_Empz_Nempz_tracts.dta", replace

* Get the NCDB ready to merge

* NCDB for empz
use "NCDB_80_00_clean.dta", clear
rename tractid id_fixed
save "NCDB_80_00_All_empzid.dta", replace

use "Ham_All_Empz_Nempz_tracts.dta", clear
merge 1:m id_fixed using "NCDB_80_00_All_empzid"
drop if _merge==2
drop _merge

* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0
drop if trctpop9 == . | trctpop9 == 0

* Generate double differenced variables:
gen dd_unemprt_ncdb = (unemprt0 - unemprt9) - (unemprt9 - unemprt8)
gen dd_povrat_ncdb = (povrat0 - povrat9) - (povrat9 - povrat8)
gen dd_frac_ncdb = (frac0 - frac9) - (frac9 - frac8)
gen dd_avemer_ncdb = (avemer0 - avemer9) - (avemer9 - avemer8)
gen dd_indemp_ncdb = (indemp0 - indemp9) - (indemp9 - indemp8)

save "hsis_NCDB_AllEmpz.dta", replace















********************************************************************************
********************************************************************************
* Clean raw NCDB data and combine with HSIS data for ENTC analysis
********************************************************************************
********************************************************************************

***********************************
*****     Contiguous nentc    *****
***********************************

* Generate EZ identifiers to merge into Census data set.
use "${rawdata}Entc_Contiguous_Nentc.dta", clear
sort entcid
keep entcid state nentcid nentc1id nentc2id nentc3id nentc4id nentc5id nentc6id nentc7id nentc8id nentc9id nentc10id CA DC GA IL IN KY MD MI MN MS MO NJ NY ND OH PA SC TN TX VA county pop80_entc pop90_entc pop00_entc ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal

foreach i of varlist pop80_entc pop90_entc pop00_entc ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_contig_entc_tracts
save `hsis_contig_entc_tracts', replace

* Get the NCDB ready to merge

* Rename tractid in NCDB to merge with Ha's data
use "NCDB_80_00_clean.dta", clear
rename tractid entcid
tempfile NCDB_contig_entcid
save `NCDB_contig_entcid', replace

* Generate nentcid in the NCDB to merge into Ham's data
use "NCDB_80_00_clean.dta", clear
rename tractid nentcid
foreach i of var unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
		gen `i'_nentc = `i'
}
tempfile NCDB_contig_nentcid
save `NCDB_contig_nentcid', replace
 
* Generate variables in the NCDB for each nentc contiguous tract (11): nentc1id - nentc11id
use "NCDB_80_00_clean.dta", clear
foreach i of num 1/10 {
		foreach j of var unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
		gen `j'_nentc`i' = `j'
		}
}
tempfile NCDB_contig_temp_entc
save `NCDB_contig_temp_entc', replace

* Generate outcome variables for each potential contiguous tract to merge with Ham's tract IDs
foreach i of num 1/10 {
	use `NCDB_contig_temp_entc'
	keep ucounty trctpop8 trctpop9 tractid tract00 tch90_00 tch80_00 tch70_00 statecd state unemprt8_nentc`i' unemprt9_nentc`i' unemprt0_nentc`i' povrat8_nentc`i' povrat9_nentc`i' povrat0_nentc`i' frac8_nentc`i' frac9_nentc`i' frac0_nentc`i' avemer8_nentc`i' avemer9_nentc`i' avemer0_nentc`i' indemp8_nentc`i' indemp9_nentc`i' indemp0_nentc`i' 
	rename tractid nentc`i'id
	tempfile NCDB_contig_id`i'_entc
	save `NCDB_contig_id`i'_entc', replace	
}	

* Merge in NCDB into Ham's entc/nentc identified tracts	

use `hsis_contig_entc_tracts', clear

merge 1:m entcid using `NCDB_contig_entcid'
drop if _merge==2
drop _merge
merge m:1 nentcid using `NCDB_contig_nentcid'
drop if _merge==2
drop _merge

* Merge in each contiguous nentc (there are 11) at the tract level
foreach i of num 1/10 {
merge m:m nentc`i'id using `NCDB_contig_id`i'_entc'
drop if _merge==2
drop _merge
}	

* Generate a count for the number of contiguous tracts
gen num_tract_contig = 1
foreach i of numlist 1/10 {
replace num_tract_contig = num_tract_contig + 1 if nentc`i'id~=.
}

foreach i of varlist unemprt8_nentc unemprt9_nentc unemprt0_nentc povrat8_nentc povrat9_nentc povrat0_nentc frac8_nentc frac9_nentc frac0_nentc avemer8_nentc avemer9_nentc avemer0_nentc indemp8_nentc indemp9_nentc indemp0_nentc unemprt8_nentc1 unemprt9_nentc1 unemprt0_nentc1 povrat8_nentc1 povrat9_nentc1 povrat0_nentc1 frac8_nentc1 frac9_nentc1 frac0_nentc1 avemer8_nentc1 avemer9_nentc1 avemer0_nentc1 indemp8_nentc1 indemp9_nentc1 indemp0_nentc1 unemprt8_nentc2 unemprt9_nentc2 unemprt0_nentc2 povrat8_nentc2 povrat9_nentc2 povrat0_nentc2 frac8_nentc2 frac9_nentc2 frac0_nentc2 avemer8_nentc2 avemer9_nentc2 avemer0_nentc2 indemp8_nentc2 indemp9_nentc2 indemp0_nentc2 unemprt8_nentc3 unemprt9_nentc3 unemprt0_nentc3 povrat8_nentc3 povrat9_nentc3 povrat0_nentc3 frac8_nentc3 frac9_nentc3 frac0_nentc3 avemer8_nentc3 avemer9_nentc3 avemer0_nentc3 indemp8_nentc3 indemp9_nentc3 indemp0_nentc3 unemprt8_nentc4 unemprt9_nentc4 unemprt0_nentc4 povrat8_nentc4 povrat9_nentc4 povrat0_nentc4 frac8_nentc4 frac9_nentc4 frac0_nentc4 avemer8_nentc4 avemer9_nentc4 avemer0_nentc4 indemp8_nentc4 indemp9_nentc4 indemp0_nentc4 unemprt8_nentc5 unemprt9_nentc5 unemprt0_nentc5 povrat8_nentc5 povrat9_nentc5 povrat0_nentc5 frac8_nentc5 frac9_nentc5 frac0_nentc5 avemer8_nentc5 avemer9_nentc5 avemer0_nentc5 indemp8_nentc5 indemp9_nentc5 indemp0_nentc5 unemprt8_nentc6 unemprt9_nentc6 unemprt0_nentc6 povrat8_nentc6 povrat9_nentc6 povrat0_nentc6 frac8_nentc6 frac9_nentc6 frac0_nentc6 avemer8_nentc6 avemer9_nentc6 avemer0_nentc6 indemp8_nentc6 indemp9_nentc6 indemp0_nentc6 unemprt8_nentc7 unemprt9_nentc7 unemprt0_nentc7 povrat8_nentc7 povrat9_nentc7 povrat0_nentc7 frac8_nentc7 frac9_nentc7 frac0_nentc7 avemer8_nentc7 avemer9_nentc7 avemer0_nentc7 indemp8_nentc7 indemp9_nentc7 indemp0_nentc7 unemprt8_nentc8 unemprt9_nentc8 unemprt0_nentc8 povrat8_nentc8 povrat9_nentc8 povrat0_nentc8 frac8_nentc8 frac9_nentc8 frac0_nentc8 avemer8_nentc8 avemer9_nentc8 avemer0_nentc8 indemp8_nentc8 indemp9_nentc8 indemp0_nentc8 unemprt8_nentc9 unemprt9_nentc9 unemprt0_nentc9 povrat8_nentc9 povrat9_nentc9 povrat0_nentc9 frac8_nentc9 frac9_nentc9 frac0_nentc9 avemer8_nentc9 avemer9_nentc9 avemer0_nentc9 indemp8_nentc9 indemp9_nentc9 indemp0_nentc9 unemprt8_nentc10 unemprt9_nentc10 unemprt0_nentc10 povrat8_nentc10 povrat9_nentc10 povrat0_nentc10 frac8_nentc10 frac9_nentc10 frac0_nentc10 avemer8_nentc10 avemer9_nentc10 avemer0_nentc10 indemp8_nentc10 indemp9_nentc10 indemp0_nentc10 {
replace `i' = 0 if `i'==.
}

* Generate totals across all the contiguous nentcs
foreach i of varlist unemprt8_nentc unemprt9_nentc unemprt0_nentc povrat8_nentc povrat9_nentc povrat0_nentc frac8_nentc frac9_nentc frac0_nentc avemer8_nentc avemer9_nentc avemer0_nentc indemp8_nentc indemp9_nentc indemp0_nentc {
bysort entcid: egen `i's = sum(`i' + `i'1 + `i'2 + `i'3 + `i'4 + `i'5 + `i'6 + `i'7 + `i'8 + `i'9 + `i'10) if statecd!=.
}

* Divide totals by the number of contiguous tracts that contributed to that total. This generates an average for each outcome of the contiguous tracts
foreach i of varlist unemprt8_nentcs unemprt9_nentcs unemprt0_nentcs povrat8_nentcs povrat9_nentcs povrat0_nentcs frac8_nentcs frac9_nentcs frac0_nentcs avemer8_nentcs avemer9_nentcs avemer0_nentcs indemp8_nentcs indemp9_nentcs indemp0_nentcs {
replace `i' = `i'/num_tract_contig
}


* Generate empz tags for variables
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0 {
rename `i' `i'_entc
}


* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0
drop if trctpop9 == . | trctpop9 == 0

* Generate triple differenced variables
gen dd_unemprt_entc = (unemprt0_entc - unemprt9_entc) - (unemprt9_entc - unemprt8_entc)
gen dd_unemprt_nentc = (unemprt0_nentcs - unemprt9_nentcs) - (unemprt9_nentcs - unemprt8_nentcs)
gen ddd_unemprt_ncdb = dd_unemprt_entc - dd_unemprt_nentc

gen dd_povrat_entc = (povrat0_entc - povrat9_entc) - (povrat9_entc - povrat8_entc)
gen dd_povrat_nentc = (povrat0_nentcs - povrat9_nentcs) - (povrat9_nentcs - povrat8_nentcs)
gen ddd_povrat_ncdb = dd_povrat_entc - dd_povrat_nentc

gen dd_frac_entc = (frac0_entc - frac9_entc) - (frac9_entc - frac8_entc)
gen dd_frac_nentc = (frac0_nentcs - frac9_nentcs) - (frac9_nentcs - frac8_nentcs)
gen ddd_frac_ncdb =  dd_frac_entc - dd_frac_nentc

gen dd_avemer_entc = (avemer0_entc - avemer9_entc) - (avemer9_entc - avemer8_entc)
gen dd_avemer_nentc = (avemer0_nentcs - avemer9_nentcs) - (avemer9_nentcs - avemer8_nentcs)
gen ddd_avemer_ncdb = dd_avemer_entc - dd_avemer_nentc

gen dd_indemp_entc = (indemp0_entc - indemp9_entc) - (indemp9_entc - indemp8_entc)
gen dd_indemp_nentc = (indemp0_nentcs - indemp9_nentcs) - (indemp9_nentcs - indemp8_nentcs)
gen ddd_indemp_ncdb =  dd_indemp_entc -  dd_indemp_nentc

save "hsis_NCDB_contiguous_entc.dta", replace 	

	
***********************************
*****      Nearest nentc      *****
***********************************
clear

* Generate EZ identifiers to merge into Census data set.
use "${rawdata}Entc_Closest_Nentc.dta", clear
destring entcid, replace
destring nentcid, replace
sort entcid
keep entcid state nentcid AL AZ AR CA CO CT DE DC FL GA IL IN IA KS KY LA ME MA MI MN MS MO NE NV NH NM NY NC OH OK OR PA RI SC SD TN TX UT VA WA WV WI county pop80_entc pop90_entc pop00_entc ddd_unemployment ddd_employment ddd_poverty ddd_fraction ddd_rawagesal
foreach i of varlist pop80_entc pop90_entc pop00_entc  ddd_unemployment ddd_employment  ddd_poverty ddd_fraction ddd_rawagesal {
rename `i' `i'_ham
}

tempfile hsis_near_entc_tracts
save `hsis_near_entc_tracts', replace

* NCDB for entc
use "NCDB_80_00_clean.dta", clear
rename tractid entcid
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0 {
rename `i' `i'_entc
}
tempfile NCDB_near_entcid
save `NCDB_near_entcid', replace

use "NCDB_80_00_clean.dta", clear
rename tractid nentcid
foreach i of varlist indemp8 unemprt8 povrat8 avemer8 tch90_00 indemp9 unemprt9 povrat9 avemer9 tract00 indemp0 unemprt0 povrat0 avemer0 frac8 frac9 frac0 {
rename `i' `i'_nentc
}
tempfile NCDB_near_nentcid
save `NCDB_near_nentcid', replace

use `hsis_near_entc_tracts', clear
merge 1:m entcid using `NCDB_near_entcid'
drop if _merge==2
drop _merge
merge m:1 nentcid using `NCDB_near_nentcid'
drop if _merge==2
drop _merge


* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0
drop if trctpop9 == . | trctpop9 == 0

* Generate triple differenced variables
gen dd_unemprt_entc = (unemprt0_entc - unemprt9_entc) - (unemprt9_entc - unemprt8_entc)
gen dd_unemprt_nentc = (unemprt0_nentc - unemprt9_nentc) - (unemprt9_nentc - unemprt8_nentc)
gen ddd_unemprt_ncdb = dd_unemprt_entc - dd_unemprt_nentc

gen dd_povrat_entc = (povrat0_entc - povrat9_entc) - (povrat9_entc - povrat8_entc)
gen dd_povrat_nentc = (povrat0_nentc - povrat9_nentc) - (povrat9_nentc - povrat8_nentc)
gen ddd_povrat_ncdb = dd_povrat_entc - dd_povrat_nentc

gen dd_frac_entc = (frac0_entc - frac9_entc) - (frac9_entc - frac8_entc)
gen dd_frac_nentc = (frac0_nentc - frac9_nentc) - (frac9_nentc - frac8_nentc)
gen ddd_frac_ncdb =  dd_frac_entc - dd_frac_nentc

gen dd_avemer_entc = (avemer0_entc - avemer9_entc) - (avemer9_entc - avemer8_entc)
gen dd_avemer_nentc = (avemer0_nentc - avemer9_nentc) - (avemer9_nentc - avemer8_nentc)
gen ddd_avemer_ncdb = dd_avemer_entc - dd_avemer_nentc

gen dd_indemp_entc = (indemp0_entc - indemp9_entc) - (indemp9_entc - indemp8_entc)
gen dd_indemp_nentc = (indemp0_nentc - indemp9_nentc) - (indemp9_nentc - indemp8_nentc)
gen ddd_indemp_ncdb =  dd_indemp_entc -  dd_indemp_nentc

save "hsis_NCDB_nearest_entc.dta", replace

***********************************
******        All nentc       *****
***********************************

* Generate entc identifiers to merge into Census data set. 

* Ham's data does not have tract ids.  Need to generate these in their data and then merge them into NCDB.
import delimited "${rawdata}4_4_2017_Ham_replication.csv", clear

* Rename merging variables to match those in ham's data
rename ucounty county
rename povrat0n blvpov00
rename indemp0 employment00
rename avemer0d numhhld00
keep tract00 state county blvpov00 employment00 numhhld00
sort tract00 state county blvpov00 employment00 numhhld00

tempfile ncdb00_merge
save `ncdb00_merge', replace

use "${rawdata}Entc_All_Nentc.dta", clear
drop entcid
destring id_tract, gen(tract00)
sort tract00 state county blvpov00 employment00 numhhld00 
merge m:m state county blvpov00 employment00 numhhld00  using `ncdb00_merge'
keep if _merge == 3

foreach i of varlist pop80 pop90 pop00 dd_unemployment dd_employment dd_poverty dd_fraction dd_rawagesal {
rename `i' `i'_ham
}
keep tract00 entc AL AK AZ AR CA CO CT DE DC FL GA HI ID IL IN IA KS KY LA ME MD MA MI MN MS MO MT NE NV NH NJ NM NY NC ND OH OK OR PA RI SC SD TN TX UT VT VA WA WV WI county pop80 pop90 pop00 dd_unemployment_ham dd_poverty_ham dd_fraction_ham dd_rawagesal_ham dd_employment_ham

tempfile hsis_all_entc_tracts
save `hsis_all_entc_tracts', replace

* NCDB for empz
use `hsis_all_entc_tracts', clear
 
merge 1:m tract00 using "NCDB_80_00_clean"
keep if _merge==3
drop _merge
rename tract00 entcid

* Drop tracts with no people in 1980:
drop if trctpop8 == . | trctpop8 == 0
drop if trctpop9 == . | trctpop9 == 0

* Generate double differenced variables:
gen dd_unemprt_ncdb = (unemprt0 - unemprt9) - (unemprt9 - unemprt8)
gen dd_povrat_ncdb = (povrat0 - povrat9) - (povrat9 - povrat8)
gen dd_frac_ncdb = (frac0 - frac9) - (frac9 - frac8)
gen dd_avemer_ncdb = (avemer0 - avemer9) - (avemer9 - avemer8)
gen dd_indemp_ncdb = (indemp0 - indemp9) - (indemp9 - indemp8)

save "hsis_NCDB_all_entc.dta", replace











********************************************************************************
********************************************************************************
* Clean data from Busso et al. to create NCDB dataset with future/rejected ENTZ indicator
********************************************************************************
********************************************************************************

* Import Busso and Kline data:
use "${rawdata}blocklevel_admdata.dta", clear

codebook tract2000 // 2,662 tracts

* Code missing values to compare variables to each other
foreach i in program1995 assigned_tract progid_power {
replace `i' = 99999 if missing(`i')
}

* There are 88 observations (all in ATL) that are coded as not assigned in the first round but are coded as getting an EZ program in 1995 (progam1995). This is further confirmed by Appendix Table D in BK's paper and a quick internet search.
replace assigned_tract = 1 if program1995 == 3
tab program1995 assigned_tract 

* Compare the controls to the assigned tracts:
tab progid_power assigned_tract

* Compare progid_power to program1995
tab progid_power program1995

* Recode missings to actual missings:
foreach i in program1995 assigned_tract progid_power {
replace `i' = . if `i' == 99999
}

****************** Generate treated and control indicators *********************

* Generate EMPZ treatment variable
gen bk_treat_empz = .
replace bk_treat_empz = 1 if assigned_tract == 1

* Generate EMPZ control variable
gen bk_control_empz = .
replace bk_control_empz = 1 if assigned_tract == 0

* Genereate EMPZ treatment/control variable
gen empz_bk = 0 if bk_control_empz == 1
replace empz_bk = 1 if bk_treat_empz == 1

* Generate ENTC treatment variable
gen bk_treat_entc = .
replace bk_treat_entc = 1 if program1995 == 1 | program1995 == 2

* Generate ENTC control variable
gen bk_control_entc = .
replace bk_control_entc = 1 if progid_power!=. & !inrange(program1995,1,3)

* Generate BK ENTC treatment variable
gen entc_bk = bk_treat_entc
replace entc_bk = 0 if bk_control_entc == 1

* Generate state variable
generate str2 fips = substr(county,1,2)
destring fips, replace

collapse bk_treat_empz bk_control_empz empz_bk bk_treat_entc bk_control_entc entc_bk program1995 program1999 program2001 progid_cons progid_power application_tract assigned_tract, by(city tract2000 fips)

drop if tract == "17163502900" & city == "St. Louis city" // repeats East St. Louis City

codebook tract2000 // 2,662 tracts.

destring tract2000, replace

* Some 2000 tracts have variation in the treatment and control variables, probably because the tract underwent changes between 1990 and 2000. I only want to keep tracts are fully treated or untreated. Results in 49 changes
foreach i of varlist bk_treat_empz bk_control_empz bk_treat_entc bk_control_entc application_tract entc_bk empz_bk assigned_tract {
replace `i'= . if inrange(`i',0.000001,0.9999999)
}

codebook tract2000 // 2,662

keep tract2000 city fips bk_treat_empz bk_control_empz bk_treat_entc bk_control_entc entc_bk empz_bk program1995 

gen bk_tract = 1

save "bussokline_ezcomment_table7.dta", replace



********************************************************************************
* 						Import NCDB and merge with BK
********************************************************************************

import delimited "${rawdata}4_4_2017_Ham_replication.csv", clear

codebook geo2000 // 65,442 tracts

* For each variable below, I replace the values equal to missing if the denominator used in the calculation == 0.

//							 Unemployment rate							 	//

foreach i in  8 9 0 {
replace unemprt`i' = . if unempt`i'd == 0
}

// 									Poverty 								//

foreach i in 8 9 0 {
replace povrat`i' = . if povrat`i'd == 0
}


//				 Fraction of Households with Wage and Salary Income 	    //

foreach i in 8 9 0 {
gen frac`i' = avemer`i'd/welfar`i'd
}

// 							Average wage and salary income 					//

foreach i in 8 9 0 {
replace avemer`i' = . if welfar`i'd ==0
}

* Convert wages to real wages using the Census deflator for 2000 dollars: https://usa.ipums.org/usa/cpi99.shtml
replace avemer8 = 2.295*avemer8
replace avemer9 = 1.344*avemer9

* Convert proportions to percentages
foreach i of varlist unemprt8 povrat8 welfare8 unemprt9 povrat9 welfare9 unemprt0 povrat0 welfare0 frac8 frac9 frac0 {
replace `i' = 100*`i'
}

* Rename state
rename statecd fips

* Rename 2000 tract id
rename geo2000 tract2000

codebook tract2000 // 65,422

***************************** Merge in BK **************************************

merge 1:1 tract2000 using "bussokline_ezcomment_table7.dta"

* All tracts from BK matched to the NCDB.

rename _merge _mergebk
	
tab _mergebk // 2,662 tracts in ncdb and bk
	
codebook tract2000 // 65,442

save "ncdb_bk.dta", replace



********************************************************************************
********************************************************************************
********************************************************************************

****************************** EMPZ analysis ***********************************

********************************************************************************
********************************************************************************
********************************************************************************


********************** Merge in HSIS EMPZ data to ncdb_bk **********************

use "ncdb_bk.dta", clear

preserve 
import delimited "${oghsisdata}Empz_All_Nempz.csv", clear

tab state // only 8 states in this data
rename state fips

rename id_fixed tract2000
destring tract2000, replace

codebook tract2000 // 15,139 unique tracts

keep tract2000 overlapentz round obs ovrlentz label empzid empz fips dd_employment dd_unemployment dd_poverty dd_fraction dd_rawagesal

foreach i in overlapentz round obs ovrlentz label empzid empz fips  {
rename `i' `i'_hsis
}

gen hsis_tract = 1

tempfile hsis_empz
save `hsis_empz'
restore

* Merge in HSIS EMPZ data
merge 1:1 tract2000 using `hsis_empz'

rename _merge _mergehsis

* Drop tracts that were only in the NCDB and not in HSIS or BK:
drop if _mergebk == 1 & _mergehsis == 1

* Generate identifier for whether the state appears in HSIS data
gen hsis_states = 0
replace hsis_states = 1 if  fips == 17 | /// IL
							fips == 24 | /// MD
							fips == 26 | /// MI
							fips == 28 | /// MS
							fips == 34 | /// NJ
							fips == 36 | /// NY
							fips == 39 | /// OH
							fips == 42  /// PA

* Replacing missings with "9999" so that it's easier to tabulate variables
foreach i in bk_treat_empz bk_control_empz bk_treat_entc empz_bk empz_hsis program1995 hsis_states bk_tract _mergebk hsis_tract _mergehsis {
replace `i' = 9999 if `i' == .
}

* Is there any disagreement in the tracts that BK and HSIS code as treated?
tab empz_bk empz_hsis // Yes - 8 tracts that BK code as EMPZs are coded as non-EMPZs by HSIS

/* Cleaning steps:
1. Restrict sample to states that HSIS analyze
2. Tabulate treatment and controls between BK and HSIS
3. Drop tracts with zero population in 1980 and 1990
4. Tabulate treatment and controls between BK and HSIS
*/

* 1. Restrict sample to states that HSIS analyze
keep if hsis_states == 1

* 2. Tabulate treatment and controls between BK and HSIS
tab empz_bk empz_hsis

* 3. Drop tracts with zero population counts
drop if trctpop8 == 0
drop if trctpop9 == 0

* 4. Tabulate treatment and controls between BK and HSIS
tab empz_bk empz_hsis

/*
save "empz_hsis_ncdb_bk_clean.dta", replace

********************************************************************************
*************** Analysis of EMPZs using B & K EMPZ controls ********************
********************************************************************************

use "empz_hsis_ncdb_bk_clean.dta", clear 
*/

* For each variable below, I replace the values equal to missing if the denominator used in the calculation == 0.

* Generate double differenced variables:
foreach i in unemprt povrat frac avemer indemp {
gen dd_`i'_ncdb = (`i'0 - `i'9) - (`i'9 - `i'8)
}

* Replace EMPZ indicator to missing if == 9
replace empz_hsis = . if empz_hsis == 9999

* Generate estimator using the intersection of HSIS and BK controls
gen empz_tr_inter_ctrl_inter = .
replace empz_tr_inter_ctrl_inter = 0 if bk_control_empz == 1 & empz_hsis == 0
replace empz_tr_inter_ctrl_inter = 1 if bk_treat_empz == 1 & empz_hsis == 1

* Generate estimator for intersection of BK/HSIS treated tracts -- all BK controls
gen empz_tr_inter_ctrl_bk = .
replace empz_tr_inter_ctrl_bk = 0 if bk_control_empz == 1
replace empz_tr_inter_ctrl_bk = 1 if empz_hsis == 1 & bk_treat_empz == 1

* Generate estimator for intersection of BK/HSIS treated tracts -- HSIS controls
gen empz_tr_inter_ctrl_hsis = .
replace empz_tr_inter_ctrl_hsis = 0 if empz_hsis == 0
replace empz_tr_inter_ctrl_hsis = 1 if empz_hsis == 1 & bk_treat_empz == 1

* Generate estimator for only HSIS treated tracts -- all BK controls
gen empz_tr_hsis_ctrl_bk = .
replace empz_tr_hsis_ctrl_bk = 0 if bk_control_empz == 1
replace empz_tr_hsis_ctrl_bk = 1 if empz_hsis == 1

* Generate estimator for only HSIS treated tracts and the intersection of BK and HSIS control tracts
gen empz_tr_hsis_ctrl_inter = 0 if bk_control_empz == 1 & empz_hsis == 0
replace empz_tr_hsis_ctrl_inter = 1 if empz_hsis == 1
replace empz_tr_hsis_ctrl_inter = . if empz_hsis == 0 & empz_bk == 1 // there are 8 tracts that HSIS code as not having an EMPZ that BK code as having an EMPZ. I drop these tracts due to the disagreement.
/* These tracts are:
24510210100
24510210200
26163520700
26163520800
26163522400
36005005302
36061021900
39035111401
*/

save "empz_hsis_ncdb_bk_coded.dta", replace




********************************************************************************
* 				Prepare NCDB to identify tract IDs in HSIS ENTC data
********************************************************************************

clear

* Generate entc identifiers to merge into NCDB and BK data set. 

* Ham's data does not have tract ids for NENTCs.  Need to generate these in their data and then merge them into NCDB.
import delimited "${rawdata}4_4_2017_Ham_replication.csv", clear

* Rename merging variables to match those in ham's data. Note these are all variables for 2000
rename ucounty county
rename povrat0n blvpov00
rename indemp0 employment00
rename avemer0d numhhld00
rename welfar0d tothhlds00
keep tract00 state county blvpov00 employment00 numhhld00 povrat0d tothhlds00
sort tract00 state county blvpov00 employment00 numhhld00 povrat0d tothhlds00

* Sometimes even all these variables do not uniquely define a row -- this seems to be because they have missing values. Only want rows that are uniquely defined by these variables (65,223 out of 65,442 tracts are uniquely defined using these variables)
bysort state county blvpov00 employment00 numhhld00 povrat0d tothhlds00: gen n=_N
tab n

codebook tract00 // 65,442 tracts

keep if n == 1 // drops 219 tracts

codebook tract00 // 65,223 tracts

tempfile ncdb00_merge
save `ncdb00_merge', replace


* Import HSIS data
use "${rawdata}Entc_All_Nentc", clear

codebook state // 29,690 observations

gen hsis_tract = 1
rename entc entc_hsis

gen povrat0d = abvpov00 + blvpov00
sort state county blvpov00 employment00 numhhld00 povrat0d tothhlds00 // Same as NCDB merging varaibles

* There are a few duplicates due to missings -- drop these tracts (very few of them, like 28). These tracts are missing data and would have likely been dropped later anyways (29,662 out of 29,690 tracts are uniquely identified with these variables)
bysort state county blvpov00 employment00 numhhld00 povrat0d tothhlds00: gen n=_N
keep if n == 1 // drops 28 tracts

codebook state // 29,662 observations

merge 1:1 state county blvpov00 employment00 numhhld00 povrat0d tothhlds00 using `ncdb00_merge'
keep if (entc_hsis == 1 | _merge == 3) // 64 control tracts remain unidentified because they do not show up in the NCDB. There is lots of missing data (HSIS) for these tracts so I suspect they had zero populations in 1980. Either way, this data likely wouldn't be useful for the analysis anyway because of the extent of missingness in values.

replace tract00 = entcid if missing(tract00) // replaces tract00 for the three HSIS tracts that didn't appear in the NCDB

* Identify variables as HSIS variables
foreach i of varlist pop80 pop90 pop00 dd_unemployment dd_employment dd_poverty dd_fraction dd_rawagesal {
rename `i' `i'_ham
}

keep tract00 state county hsis_tract entc_hsis pop80 pop90 pop00 dd_unemployment_ham dd_employment_ham dd_poverty_ham dd_fraction_ham dd_rawagesal_ham

codebook tract00 // 29,601 tracts
rename tract00 tract2000

save "Ham_All_ENTC_NENTC_tracts.dta", replace

**************************** Merge in NCDB and BK ******************************

use "Ham_All_ENTC_NENTC_tracts", clear
merge 1:1 tract2000 using "ncdb_bk"

rename _merge _mergehsis

****************************** Assess merged data ******************************

* Number of observations in each dataset:
codebook tract2000 // 65,442 -- all tracts with either HSIS or 
codebook tract2000 if bk_tract == 1 // All 2,662 tracts from BK
codebook tract2000 if hsis_tract == 1 // All 29,601 ENTC tracts according to HSIS

save "entc_hsis_ncdb_bk_merged.dta", replace

********************************************************************************
* 								Clean data
********************************************************************************

use "entc_hsis_ncdb_bk_merged.dta",clear

* Generate identifier for whether the state appears in HSIS data
gen hsis_states = 0
replace hsis_states = 1 if state == 1  | ///
						   state == 4  | ///
						   state == 5  | ///
						   state == 6  | ///
						   state == 8  | ///
						   state == 9  | ///
						   state == 10 | ///
						   state == 11 | ///
						   state == 12 | ///
						   state == 13 | ///
						   state == 17 | ///
						   state == 18 | ///
						   state == 21 | ///
						   state == 26 | ///
						   state == 27 | ///
						   state == 28 | ///
						   state == 29 | ///
						   state == 31 | ///
						   state == 32 | ///
						   state == 33 | ///
						   state == 35 | ///
						   state == 37 | ///
						   state == 39 | ///
						   state == 40 | ///
						   state == 41 | ///
						   state == 42 | ///
						   state == 44 | ///
						   state == 46 | ///
						   state == 47 | ///
						   state == 48 | ///
						   state == 49 | ///
						   state == 51 | ///
						   state == 53 | ///
						   state == 54

* Replacing missings with "9999" so that it's easier to tabulate variables
foreach i in bk_treat_empz bk_control_empz bk_treat_entc bk_control_entc program1995 hsis_states bk_tract _mergebk entc_hsis hsis_tract _mergehsis entc_bk entc_hsis {
replace `i' = 9999 if `i' == .
}

* Is there any disagreement in the tracts that BK and HSIS code as treated?
tab entc_bk entc_hsis // Yes -- 56 tracts that HSIS code as controls are coded as treated by BK

/* Cleaning steps:
1. Restrict sample to states that HSIS analyze
2. Tabulate treatment and controls between BK and HSIS
3. Drop tracts with zero population in 1980 and 1990
4. Tabulate treatment and controls between BK and HSIS
*/

* 1. Restrict sample to states that HSIS analyze
keep if hsis_states == 1

* 2. Tabulate treatment and controls between BK and HSIS
tab entc_bk entc_hsis

* 3. Drop tracts with zero population counts
drop if trctpop8 == 0
drop if trctpop9 == 0

* 4. Tabulate treatment and controls between BK and HSIS
tab entc_bk entc_hsis

save "entc_hsis_ncdb_bk_clean.dta", replace


********************************************************************************
*************** Analysis of ENTCs using Kline ENTC controls ********************
********************************************************************************

use "entc_hsis_ncdb_bk_clean.dta", clear 

* Generate double differenced variables:
foreach i in unemprt povrat frac avemer indemp {
gen dd_`i'_ncdb = (`i'0 - `i'9) - (`i'9 - `i'8)
}

* Replace ENTC indicator to missing if == 9
replace entc_hsis = . if entc_hsis == 9999

* Generate estimator using the intersection of HSIS and BK treatment and controls
gen entc_tr_inter_ctrl_inter = .
replace entc_tr_inter_ctrl_inter = 0 if bk_control_entc == 1 & entc_hsis == 0
replace entc_tr_inter_ctrl_inter = 1 if bk_treat_entc == 1 & entc_hsis == 1

* Generate estimator for intersection of BK/HSIS treated tracts -- all BK controls
gen entc_hsis_inter_ctrl_bk = .
replace entc_hsis_inter_ctrl_bk = 0 if bk_control_entc == 1
replace entc_hsis_inter_ctrl_bk = 1 if entc_hsis == 1 & bk_treat_entc == 1

* Generate estimator for intersection of BK/HSIS treated tracts -- HSIS controls
gen entc_tr_inter_ctrl_hsis = .
replace entc_tr_inter_ctrl_hsis = 0 if entc_hsis == 0
replace entc_tr_inter_ctrl_hsis = 1 if entc_hsis == 1 & bk_treat_entc == 1

* Generate estimator for only HSIS treated tracts -- all BK controls
gen entc_tr_hsis_ctrl_bk = .
replace entc_tr_hsis_ctrl_bk = 0 if bk_control_entc == 1
replace entc_tr_hsis_ctrl_bk = 1 if entc_hsis == 1

* Generate estimator for only HSIS treated tracts and intersection of HSIS and BK controls
gen entc_tr_hsis_ctrl_inter = 0 if bk_control_entc == 1 & entc_hsis == 0
replace entc_tr_hsis_ctrl_inter = 1 if entc_hsis == 1

save "entc_hsis_ncdb_bk_coded.dta", replace

























********************************************************************************
********************************************************************************
* Table 2. Summary Statistics for Poverty Outcomes in State Enterprise Zone Analysis: Comparing Estimates Using NCDB Data and HSIS Data 
********************************************************************************
********************************************************************************

********************************************************************************
* Panel I. Row 1. 1980
********************************************************************************

* Column 1. Treated - NCDB
use "hsis_NCDB_nearest_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentz == .
}
label var constant "ENTZ 1980"
reg povrat8_entz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 1. Summary statistics - 1980.xls", replace title("Table 2 - Row 1") label dec(2) ctitle("NCDB - treated")

* Column 2. Treated - HSIS
import delimited "${oghsisdata}Entz_Closest_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1980"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentz==.) | (povrate90_nentz==.) | (povrate00_nentz==.)
reg povrate80_entz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 1. Summary statistics - 1980.xls", append title("Table 2 - Row 1") label dec(2) ctitle("HSIS - treated")

* Column 3. Nearest - NCDB
use "hsis_NCDB_nearest_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentz == .
}
label var constant "ENTZ 1980"
reg povrat8_nentz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 1. Summary statistics - 1980.xls", append title("Table 2 - Row 1") label dec(2) ctitle("NCDB - nearest")

* Column 4. Nearest - HSIS
import delimited "${oghsisdata}Entz_Closest_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1980"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentz==.) | (povrate90_nentz==.) | (povrate00_nentz==.)
reg povrate80_nentz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 1. Summary statistics - 1980.xls", append title("Table 2 - Row 1") label dec(2) ctitle("HSIS - nearest")

* Column 5. Contiguous - NCDB
use "hsis_NCDB_contiguous_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentzs == .
}
label var constant "Contiguous NENTZ 1980"
reg povrat8_nentzs constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 1. Summary statistics - 1980.xls", append title("Table 2 - Row 1") label dec(2) ctitle("NCDB - contiguous")

* Column 6. Contiguous - HSIS
import delimited "${oghsisdata}Entz_Contiguous_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1980"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentzs==.) | (povrate90_nentzs==.) | (povrate00_nentzs==.)
reg povrate80_nentzs constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 1. Summary statistics - 1980.xls", append title("Table 2 - Row 1") label dec(2) ctitle("HSIS - contiguous")

* Column 7. All - NCDB
use "hsis_NCDB_all_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i' == .
}
label var constant "All ENTZ 1980"
reg povrat8 constant if entz==0, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 1. Summary statistics - 1980.xls", append title("Table 2 - Row 1") label dec(2) ctitle("NCDB - All")
 
* Column 8. All - HSIS
import delimited "${oghsisdata}Entz_All_nentz.csv", clear
gen constant=1
label var constant "ENTZ 1980"
drop if (povrate80==.) | (povrate90==.) | (povrate00==.) 
reg povrate80 constant if entz==0, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 1. Summary statistics - 1980.xls", append title("Table 2 - Row 1") label dec(2) ctitle("HSIS - All")


********************************************************************************
* Panel I. Row 2. 1990
********************************************************************************

* Column 1. Treated - NCDB
use "hsis_NCDB_nearest_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentz == .
}
label var constant "ENTZ 1990"
reg povrat9_entz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 2. Summary statistics - 1990.xls", replace title("Table 2 - Row 2") label dec(2) ctitle("NCDB - treated")

* Column 2. Treated - HSIS
import delimited "${oghsisdata}Entz_Closest_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1990"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentz==.) | (povrate90_nentz==.) | (povrate00_nentz==.)
reg povrate90_entz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 2. Summary statistics - 1990.xls", append title("Table 2 - Row 2") label dec(2) ctitle("HSIS - treated")

* Column 3. Nearest - NCDB
use "hsis_NCDB_nearest_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentz == .
}
label var constant "ENTZ 1990"
reg povrat9_nentz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 2. Summary statistics - 1990.xls", append title("Table 2 - Row 2") label dec(2) ctitle("NCDB - nearest")

* Column 4. Nearest - HSIS
import delimited "${oghsisdata}Entz_Closest_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1990"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentz==.) | (povrate90_nentz==.) | (povrate00_nentz==.)
reg povrate90_nentz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 2. Summary statistics - 1990.xls", append title("Table 2 - Row 2") label dec(2) ctitle("HSIS - nearest")

* Column 5. Contiguous - NCDB
use "hsis_NCDB_contiguous_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentzs == .
}
label var constant "Contiguous NENTZ 1990"
reg povrat9_nentzs constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 2. Summary statistics - 1990.xls", append title("Table 2 - Row 2") label dec(2) ctitle("NCDB - contiguous")

* Column 6. Contiguous - HSIS
import delimited "${oghsisdata}Entz_Contiguous_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1990"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentzs==.) | (povrate90_nentzs==.) | (povrate00_nentzs==.)
reg povrate90_nentzs constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 2. Summary statistics - 1990.xls", append title("Table 2 - Row 2") label dec(2) ctitle("HSIS - contiguous")

* Column 7. All - NCDB
use "hsis_NCDB_all_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i' == .
}
label var constant "All ENTZ 1990"
reg povrat9 constant if entz==0, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 2. Summary statistics - 1990.xls", append title("Table 2 - Row 2") label dec(2) ctitle("NCDB - All")
 
* Column 8. All - HSIS
import delimited "${oghsisdata}Entz_All_nentz.csv", clear
gen constant=1
label var constant "ENTZ 1990"
drop if (povrate80==.) | (povrate90==.) | (povrate00==.) 
reg povrate90 constant if entz==0, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 2. Summary statistics - 1990.xls", append title("Table 2 - Row 2") label dec(2) ctitle("HSIS - All")


********************************************************************************
* Panel I. Row 3. 1990
********************************************************************************

* Column 1. Treated - NCDB
use "hsis_NCDB_nearest_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentz == .
}
label var constant "ENTZ 1990"
reg povrat0_entz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 3. Summary statistics - 2000.xls", replace title("Table 2 - Row 3") label dec(2) ctitle("NCDB - treated")

* Column 2. Treated - HSIS
import delimited "${oghsisdata}Entz_Closest_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1990"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentz==.) | (povrate90_nentz==.) | (povrate00_nentz==.)
reg povrate00_entz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 3. Summary statistics - 2000.xls", append title("Table 2 - Row 3") label dec(2) ctitle("HSIS - treated")

* Column 3. Nearest - NCDB
use "hsis_NCDB_nearest_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentz == .
}
label var constant "ENTZ 1990"
reg povrat0_nentz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 3. Summary statistics - 2000.xls", append title("Table 2 - Row 3") label dec(2) ctitle("NCDB - nearest")

* Column 4. Nearest - HSIS
import delimited "${oghsisdata}Entz_Closest_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1990"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentz==.) | (povrate90_nentz==.) | (povrate00_nentz==.)
reg povrate00_nentz constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 3. Summary statistics - 2000.xls", append title("Table 2 - Row 3") label dec(2) ctitle("HSIS - nearest")

* Column 5. Contiguous - NCDB
use "hsis_NCDB_contiguous_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i'_entz == .
drop if povrat`i'_nentzs == .
}
label var constant "Contiguous NENTZ 1990"
reg povrat0_nentzs constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 3. Summary statistics - 2000.xls", append title("Table 2 - Row 3") label dec(2) ctitle("NCDB - contiguous")

* Column 6. Contiguous - HSIS
import delimited "${oghsisdata}Entz_Contiguous_Nentz.csv", clear
gen constant=1
label var constant "ENTZ 1990"
drop if (povrate80_entz==.) | (povrate90_entz==.) | (povrate00_entz==.) | (povrate80_nentzs==.) | (povrate90_nentzs==.) | (povrate00_nentzs==.)
reg povrate00_nentzs constant, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 3. Summary statistics - 2000.xls", append title("Table 2 - Row 3") label dec(2) ctitle("HSIS - contiguous")

* Column 7. All - NCDB
use "hsis_NCDB_all_og.dta", clear
gen constant=1
foreach i of numlist 8 9 0 {
drop if povrat`i' == .
}
label var constant "All ENTZ 1990"
reg povrat0 constant if entz==0, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 3. Summary statistics - 2000.xls", append title("Table 2 - Row 3") label dec(2) ctitle("NCDB - All")
 
* Column 8. All - HSIS
import delimited "${oghsisdata}Entz_All_nentz.csv", clear
gen constant=1
label var constant "ENTZ 1990"
drop if (povrate80==.) | (povrate90==.) | (povrate00==.) 
reg povrate00 constant if entz==0, nocon cluster(county)

outreg2 using "${tables}Table 2. Row 3. Summary statistics - 2000.xls", append title("Table 2 - Row 3") label dec(2) ctitle("HSIS - All")



********************************************************************************
* Panel II. Triple-differences estimates
********************************************************************************

* NCDB - Nearest
use "hsis_NCDB_nearest_og.dta", clear
keep if ddd_poverty_ham != .
xtset county
xtreg ddd_povrat_ncdb, re

// Merge in the double differenced poverty variable from HSIS's original (i.e., incorrect) data because the sample of tracts for which poverty data is available changes from the incorrect to the corrected data.
preserve
import delimited "${oghsisdata}Entz_All_nentz.csv", clear
drop entzid
rename id_fixed entzid
rename dd_poverty dd_poverty_ham_og
keep entzid dd_poverty_ham_og
tempfile hsis_all_og
save `hsis_all_og', replace
restore
merge 1:1 entzid using `hsis_all_og'

keep if dd_poverty_ham_og !=.

outreg2 using "${tables}Table 2. Panel 2. Triple difference estimates.xls", replace title("Table 2. Panel 2. Triple difference estimates") label dec(2) ctitle("NCDB - nearest")

* HSIS - Nearest
import delimited "${oghsisdata}Entz_Closest_Nentz.csv", clear

xtset county
xtreg ddd_poverty, re

outreg2 using "${tables}Table 2. Panel 2. Triple difference estimates.xls", append title("Table 2. Panel 2. Triple difference estimates") label dec(2) ctitle("HSIS - nearest")

* NCDB - Contiguous
use "hsis_NCDB_contiguous_og.dta", clear
keep if ddd_poverty_ham != .
xtset county
xtreg ddd_povrat_ncdb, re

outreg2 using "${tables}Table 2. Panel 2. Triple difference estimates.xls", append title("Table 2. Panel 2. Triple difference estimates") label dec(2) ctitle("NCDB - contiguous")

* HSIS - Contiguous
import delimited "${oghsisdata}Entz_Contiguous_Nentz.csv", clear

xtset county
xtreg ddd_poverty, re

outreg2 using "${tables}Table 2. Panel 2. Triple difference estimates.xls", append title("Table 2. Panel 2. Triple difference estimates") label dec(2) ctitle("HSIS - contiguous")

* NCDB - All 
use "hsis_NCDB_all_og.dta", clear

keep if dd_poverty_ham != .
xtset county
xtreg dd_povrat_ncdb entz ca fl ma ny oh or

outreg2 using "${tables}Table 2. Panel 2. Triple difference estimates.xls", append title("Table 2. Panel 2. Triple difference estimates") label dec(2) ctitle("NCDB - All")

* HSIS - All
import delimited "${oghsisdata}Entz_All_nentz.csv", clear

xtset county
xtreg dd_poverty entz ca fl ma ny oh or

outreg2 using "${tables}Table 2. Panel 2. Triple difference estimates.xls", append title("Table 2. Panel 2. Triple difference estimates") label dec(2) ctitle("HSIS - All")







********************************************************************************
********************************************************************************
* ENTZ data cleaning for PSM and analysis
********************************************************************************
********************************************************************************

******************************* Nearest NENTZs *********************************

use "hsis_NCDB_nearest.dta", clear

keep entzid unemprt8_entz unemprt9_entz unemprt0_entz povrat8_entz povrat9_entz povrat0_entz frac8_entz frac9_entz frac0_entz avemer8_entz avemer9_entz avemer0_entz indemp8_entz indemp9_entz indemp0_entz unemprt8_nentz unemprt9_nentz unemprt0_nentz povrat8_nentz povrat9_nentz povrat0_nentz frac8_nentz frac9_nentz frac0_nentz avemer8_nentz avemer9_nentz avemer0_nentz indemp8_nentz indemp9_nentz indemp0_nentz ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb ucounty

* Format variables
format entzid %13.0g
tostring entzid, gen(id_str)
gen double entzidtemp = entzid
format entzidtemp %13.0g
order entzid entzidtemp
							
							// Data cleaning //

* 1. Drop observations if missing data for any outcome
foreach i in unemprt8_entz unemprt9_entz unemprt0_entz povrat8_entz povrat9_entz povrat0_entz frac8_entz frac9_entz frac0_entz avemer8_entz avemer9_entz avemer0_entz indemp8_entz indemp9_entz indemp0_entz unemprt8_nentz unemprt9_nentz unemprt0_nentz povrat8_nentz povrat9_nentz povrat0_nentz frac8_nentz frac9_nentz frac0_nentz avemer8_nentz avemer9_nentz avemer0_nentz indemp8_nentz indemp9_nentz indemp0_nentz ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb {
drop if missing(`i')
}


* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
	foreach j in entz nentz {
	gen d_`i'_90_80_`j' = (`i'9_`j' - `i'8_`j')
	drop if missing(d_`i'_90_80_`j')
	}
}
foreach i in unemprt povrat avemer frac indemp {
	gen dd_`i'_90_80 = d_`i'_90_80_entz - d_`i'_90_80_nentz
}

save entz_nearest_reg, replace


					// Collapse data for creating graphs //

				
use entz_nearest_reg, clear

* Keep only nearest outcomes
collapse unemprt8_nentz unemprt9_nentz unemprt0_nentz povrat8_nentz povrat9_nentz povrat0_nentz frac8_nentz frac9_nentz frac0_nentz avemer8_nentz avemer9_nentz avemer0_nentz indemp8_nentz indemp9_nentz indemp0_nentz 

foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
rename `i'_nentz `i'
}

* Sort by entzid
gen n = _n

save nearest_temp, replace


* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use nearest_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save temp_nearest_`j', replace
}

use temp_nearest_unemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "temp_nearest_`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_near
}

save entz_near_ctrl, replace


******************************* Contiguous *************************************

use "hsis_NCDB_contiguous.dta", clear

keep entzid unemprt8_entz unemprt9_entz unemprt0_entz povrat8_entz povrat9_entz povrat0_entz frac8_entz frac9_entz frac0_entz avemer8_entz avemer9_entz avemer0_entz indemp8_entz indemp9_entz indemp0_entz unemprt8_nentzs unemprt9_nentzs unemprt0_nentzs povrat8_nentzs povrat9_nentzs povrat0_nentzs frac8_nentzs frac9_nentzs frac0_nentzs avemer8_nentzs avemer9_nentzs avemer0_nentzs indemp8_nentzs indemp9_nentzs indemp0_nentzs ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb ucounty

* Format variables
format entzid %13.0g
tostring entzid, gen(id_str)
gen double entzidtemp = entzid
format entzidtemp %13.0g
order entzid entzidtemp
							
							// Data cleaning //

							
* 1. Drop observations if missing data for any outcome
foreach i in unemprt8_entz unemprt9_entz unemprt0_entz povrat8_entz povrat9_entz povrat0_entz frac8_entz frac9_entz frac0_entz avemer8_entz avemer9_entz avemer0_entz indemp8_entz indemp9_entz indemp0_entz unemprt8_nentzs unemprt9_nentzs unemprt0_nentzs povrat8_nentzs povrat9_nentzs povrat0_nentzs frac8_nentzs frac9_nentzs frac0_nentzs avemer8_nentzs avemer9_nentzs avemer0_nentzs indemp8_nentzs indemp9_nentzs indemp0_nentzs ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb {
drop if missing(`i')
}

* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
	foreach j in entz nentzs {
	gen d_`i'_90_80_`j' = (`i'9_`j' - `i'8_`j')
	drop if missing(d_`i'_90_80_`j')
	}
}
foreach i in unemprt povrat avemer frac indemp {
	gen dd_`i'_90_80 = d_`i'_90_80_entz - d_`i'_90_80_nentz
}

save entz_contiguous_reg, replace


					// Collapse data for creating graphs //


use  entz_contiguous_reg, clear
					
* Collapse data to year-by-outcome cells
collapse unemprt8_nentzs unemprt9_nentzs unemprt0_nentzs povrat8_nentzs povrat9_nentzs povrat0_nentzs frac8_nentzs frac9_nentzs frac0_nentzs avemer8_nentzs avemer9_nentzs avemer0_nentzs indemp8_nentzs indemp9_nentzs indemp0_nentzs

foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {

rename `i'_nentzs `i'

}

gen n = _n

save contig_temp, replace
 

* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use contig_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save contig_temp`j', replace
}

use contig_tempunemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "contig_temp`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_contig
}

save entz_contig_ctrl, replace

******************************* All *************************************

use "hsis_NCDB_all.dta", clear

* Sort data by tract id
gsort - entz + entzid
rename entzid entzid
							
							
							// Data cleaning //

							
* 1. Drop observations if missing data for any outcome
foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 dd_unemprt_ncdb dd_povrat_ncdb dd_avemer_ncdb dd_indemp_ncdb dd_frac_ncdb {
drop if missing(`i')
}

* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
gen d_`i'_90_80 = (`i'9 - `i'8)
drop if missing(d_`i'_90_80)
}

save entz_all_reg, replace


					// Collapse data for creating graphs //


use entz_all_reg, clear

* Collapse data down to year-by-outcome cells
collapse unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0
gen n = _n

save all_temp, replace
 
use all_temp, clear
* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use all_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save all_temp`j', replace
}

use all_tempunemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "all_temp`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_all
}

save entz_all_ctrl, replace


******************************** Treated ENTZs *********************************


			// Collapse treated from ALL data for creating graphs //

					
* Collapse All treated outcomes
use entz_all_reg, clear

keep if ezflag == 1

collapse unemprt* povrat* frac* avemer* indemp*

gen n = _n

save entz_treat_collapsed, replace


* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use entz_treat_collapsed, clear

reshape long `j', i(n) j(year)

keep year `j'

save temp_treat_`j', replace
}

use temp_treat_unemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "temp_treat_`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_treat
}

save entz_treated, replace



**************************** PS matched Entz ***********************************

use entz_all_reg, clear

tab entz // 1296

* Run PS match using ATT (default) to identify PS-matched control tracts
capture noi teffects psmatch (dd_unemprt_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), gen(match) osample(drop) atet
 
codebook match if entz == 1 // 1,172 controls selected
tab entz if e(sample) // 1,293 treated

* I want to identify the control tracts that match up to treated tracts
* Sort data by tract id
gsort - entz + entzid
gen n = _n
gen control = match1 if entz == 1

* Create individual datasets of matched pairs and then append them.
foreach i of numlist 1/1296 {
preserve
qui gen flag = 1 if n == `i'
qui gen tempm = match1 if flag == 1
qui replace tempm = 0 if missing(tempm)
qui egen m1 = max(tempm)
qui drop tempm
qui replace flag = 1 if n == m1
qui keep if flag == 1
qui gen id = `i'
qui tempfile m`i'
qui save `m`i'', replace
restore
}

* Append temp files created above
use `m1', clear
foreach i of numlist 2/1296 {
append using `m`i''
}

save entz_psm_append, replace


					// Collapse data for creating graphs //

					
use entz_psm_append, clear

* Keep only controls
keep if entz == 0

* Collapse outcomes to their means
collapse (mean) unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 avemer8 avemer9 avemer0 frac8 frac9 frac0 indemp8 indemp9 indemp0 

* Save data and process each variable separately
tempfile entz_psm_temp
save `entz_psm_temp', replace

* Reshape data doing each variable individually

foreach i in unemprt povrat frac avemer indemp {

use `entz_psm_temp', clear
gen n = _n
reshape long `i', i(n) j(year)
keep year `i'

tempfile entz_psm_`i'
save `entz_psm_`i'', replace

}

* Combine PS matched data

use `entz_psm_unemprt', clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using `entz_psm_`j''
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_psm
}

save entz_psm_ctrl, replace



********************************************************************************
* Merge together all datasets to create graphs
********************************************************************************

use entz_treated, clear
merge 1:1 year using entz_near_ctrl
drop _merge
merge 1:1 year using entz_contig_ctrl
drop _merge
merge 1:1 year using entz_all_ctrl
drop _merge
merge 1:1 year using entz_psm_ctrl
drop _merge

recode year (0 = 2000) (9 = 1990) (8 = 1980)

sort year 

* Label variables 
foreach i in unemprt povrat frac avemer indemp {
label var `i'_treat "Treated"
label var `i'_near "Nearest"
label var `i'_contig "Contiguous"
label var `i'_all "All"
label var `i'_psm "PS Matched"
}

save entz_ashenfelter_graph, replace



********************************************************************************
* Figure 1. Comparing Trends for State Enterprise Zones (ENTZs) and Potential Controls
********************************************************************************

use entz_ashenfelter_graph, clear

* Unemployment:
twoway (line unemprt_treat year, lcolor(black)) (line unemprt_near year, lpattern(longdash) lcolor(black)) (line unemprt_contig year, lpattern(dash) lcolor(black)) (line unemprt_all year, lpattern(shortdash) lcolor(black)) (line unemprt_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Unemployment Rate (%)") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 1. A. Unemployment rate.png", replace
 
* Poverty
twoway (line povrat_treat year, lcolor(black)) (line povrat_near year, lpattern(longdash) lcolor(black)) (line povrat_contig year, lpattern(dash) lcolor(black)) (line povrat_all year, lpattern(shortdash) lcolor(black)) (line povrat_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Poverty Rate (%)") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 1. B. Poverty rate.png", replace

* Fraction with wage and salary income
twoway (line frac_treat year, lcolor(black)) (line frac_near year, lpattern(longdash) lcolor(black)) (line frac_contig year, lpattern(dash) lcolor(black)) (line frac_all year, lpattern(shortdash) lcolor(black)) (line frac_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Fraction with wage and salary income") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 1. C. Fraction of HHs with W & S income.png", replace

* Wage and salary income
twoway (line avemer_treat year, lcolor(black)) (line avemer_near year, lpattern(longdash) lcolor(black)) (line avemer_contig year, lpattern(dash) lcolor(black)) (line avemer_all year, lpattern(shortdash) lcolor(black)) (line avemer_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Average wage and salary income") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 1. D. Avg W & S income.png", replace

* Employment
twoway (line indemp_treat year, lcolor(black)) (line indemp_near year, lpattern(longdash) lcolor(black)) (line indemp_contig year, lpattern(dash) lcolor(black)) (line indemp_all year, lpattern(shortdash) lcolor(black)) (line indemp_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Employment") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 1. E. Employment.png", replace



********************************************************************************
* Table 3. Regression estimates of the effect of ENTZs on pre-treatement changes
********************************************************************************

							// Panel 1: Treated ENTZs //


use entz_all_reg, clear

* Keep only ENTZs
keep if entz == 1

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 3. Panel 1. Pre-treatment trends - Treated ENTZs.xls", replace sum(log) title("Table 3. Panel 1. Pre-treatment trends - Treated ENTZs") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)



							// Panel 2: Nearest //
	
	
use entz_nearest_reg, clear

order d_unemprt_90_80_nentz d_povrat_90_80_nentz d_frac_90_80_nentz d_avemer_90_80_nentz d_indemp_90_80_nentz

* Outreg results
outreg2 using "${tables}Table 3. Panel 2. Pre-treatment trends - Nearest NENTZs means.xls", replace sum(log) title("Table 3. Panel 2. Pre-treatment trends - Nearest NENTZs means") keep(d_unemprt_90_80_nentz d_povrat_90_80_nentz d_frac_90_80_nentz d_avemer_90_80_nentz d_indemp_90_80_nentz)

*** t-test of differences compared to treated

* Unemployment
ttesti 1296	1.436	5.201	1174	0.479	3.531
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti 1296	1.087	6.557	1174	-0.357	5.989
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti 1296	0.313	7.660	1174	-0.803	6.207
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti 1296	5576	7747	1174	8497	10273
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti 1296	182	352.9	1174	202.0	321.6
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 3. Panel 2. Pre-treatment trends - Nearest NENTZs - p-values.xls", replace sum(log) title("Table 3. Panel 2. Pre-treatment trends - Nearest NENTZs - p-values")



							// Panel 3: Contiguous //
	
	
use entz_contiguous_reg, clear

order d_unemprt_90_80_nentzs d_povrat_90_80_nentzs d_frac_90_80_nentzs d_avemer_90_80_nentzs d_indemp_90_80_nentzs

* Outreg results
outreg2 using "${tables}Table 3. Panel 3. Pre-treatment trends - Contiguous NENTZs means.xls", replace sum(log) title("Table 3. Panel 3. Pre-treatment trends - Contiguous NENTZs means") keep(d_unemprt_90_80_nentzs d_povrat_90_80_nentzs d_frac_90_80_nentzs d_avemer_90_80_nentzs d_indemp_90_80_nentzs)

* Unemployment
ttesti 1296	1.436	5.201	1193	0.328	3.253
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti 1296	1.087	6.557	1193	-0.344	5.112
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti 1296	0.313	7.660	1193	-0.887	5.747
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti 1296	5576	7747	1193	8764	10092
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti 1296	182	352.9	1193	221.0	285.5
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 3. Panel 3. Pre-treatment trends - Contiguous NENTZs - p-values.xls", replace sum(log) title("Table 3. Panel 3. Pre-treatment trends - Contiguous NENTZs - p-values") 


							
								// Panel 4: All //

								
use entz_all_reg, clear

* Keep only NENTZs
keep if entz == 0

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 3. Panel 4. Pre-treatment trends - All NENTZs means.xls", replace sum(log) title("Table 3. Panel 4. Pre-treatment trends - All NENTZs means") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)

* Unemployment
ttesti	21894	-0.0258	3.889 	1296	1.436	5.201
ttesti	1296	1.436	5.201	21894	-0.0258	3.889
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	1296	1.087	6.557	21894	0.670	6.041
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	1296	0.313	7.660	21894	-0.279	7.225
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	1296	5576	7747	21894	6699	12159
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	1296	182	352.9	21894	351.6	532.3
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 3. Panel 4. Pre-treatment trends - All NENTZs - p-values.xls", replace sum(log) title("Table 3. Panel 4. Pre-treatment trends - All NENTZs - p-values") 



				
						// Panel 5: PS-matched level changes //

						
						
use entz_psm_append, clear
				
* Keep only NENTZ matched controls				
keep if entz == 0					
codebook entzid
					
* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 3. Panel 5. Pre-treatment trends - PS matched NENTZs means.xls", replace sum(log) title("Table 3. Panel 5. Pre-treatment trends - PS matched NENTZs means") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)
					
* Unemployment					
ttesti	1296	1.436	5.201	1296	1.290	4.676
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	1296	1.087	6.557	1296	1.315	8.225
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	1296	0.313	7.660	1296	-0.248	8.273
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	1296	5576	7747	1296	5101	11438
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	1296	182	352.9	1296	162.2	411.9
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 3. Panel 5. Pre-treatment trends - PS matched NENTZs - p-values.xls", replace sum(log) title("Table 3. Panel 5. Pre-treatment trends - PS matched NENTZs - p-values")


					
********************************************************************************
* Table 6. Regression estimates of the effect of ENTZs on LMOs
********************************************************************************

************************* 1. HSIS preferred estimators *************************
use entz_contiguous_reg, clear

xtset ucounty

* Unemployment
xtreg ddd_unemprt_ncdb, re
outreg2 using "${tables}Table 6. Panel 1. HSIS preferred estimator.xls", replace title("Table 6. Panel 1. HSIS preferred estimator") ///
ctitle("Unemployment rate - Contiguous")

* Poverty
xtreg ddd_povrat_ncdb, re
outreg2 using "${tables}Table 6. Panel 1. HSIS preferred estimator.xls", append title("Table 6. Panel 1. HSIS preferred estimatort") ///
ctitle("Poverty - Contiguous")

* Fraction
xtreg ddd_frac_ncdb, re
outreg2 using "${tables}Table 6. Panel 1. HSIS preferred estimator.xls", append title("Table 6. Panel 1. HSIS preferred estimatort") ///
ctitle("Fraction - Contiguous")

use entz_nearest_reg, clear

xtset ucounty

* Average Wage and Salary Income
xtreg ddd_avemer_ncdb, re
outreg2 using "${tables}Table 6. Panel 1. HSIS preferred estimator.xls", append title("Table 6. Panel 1. HSIS preferred estimatort") ///
ctitle("Average Wage and Salary Income - Nearest")

use entz_contiguous_reg, clear

xtset ucounty

* Employment
xtreg ddd_indemp_ncdb, re
outreg2 using "${tables}Table 6. Panel 1. HSIS preferred estimator.xls", append title("Table 6. Panel 1. HSIS preferred estimatort") ///
ctitle("Employment - Contiguous")

******************************** 2. PS matched *********************************

use entz_all_reg, clear

* Number of counties for treated tracts
codebook ucounty if entz == 1

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 6. Panel 2. ENTZ estimates - Propensity Score.xls", replace title("Table 6. Panel 2. ENTZ estimates - Propensity Score") ///
ctitle("Unemployment Rate")

* Poverty rate
teffects psmatch (dd_povrat_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 6. Panel 2. ENTZ estimates - Propensity Score.xls", append title("Table 6. Panel 2. ENTZ estimates - Propensity Score") ///
ctitle("Poverty Rate")

* Fraction with W/S income
teffects psmatch (dd_frac_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 6. Panel 2. ENTZ estimates - Propensity Score.xls", append title("Table 6. Panel 2. ENTZ estimates - Propensity Score") ///
ctitle("Fraction")

* Average WS income
teffects psmatch (dd_avemer_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 6. Panel 2. ENTZ estimates - Propensity Score.xls", append title("Table 6. Panel 2. ENTZ estimates - Propensity Score") ///
ctitle("Average WS Income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 6. Panel 2. ENTZ estimates - Propensity Score.xls", append title("Table 6. Panel 2. ENTZ estimates - Propensity Score") ///
ctitle("Employment")


********************************************************************************
********************************************************************************
* Bootstrapped Table 6 estimates
********************************************************************************
********************************************************************************

********************************************************************************
* Create dataset containing nearest, contiguous, all, and PSM data
********************************************************************************

* Combine contiguous and nearest triple difference values into a single all dataset.

* Contiguous
use entz_contiguous_reg, clear
keep entzid ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb 

foreach i in ddd_unemprt_ ddd_povrat_ ddd_frac_ ddd_avemer_ ddd_indemp_ {
rename `i'ncdb `i'contig
}

save temp_entz_contig, replace

* Nearest
use entz_nearest_reg, clear

keep entzid ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb 

foreach i in ddd_unemprt_ ddd_povrat_ ddd_frac_ ddd_avemer_ ddd_indemp_ {
rename `i'ncdb `i'nearest
}

save temp_entz_nearest, replace

* Merge in HSIS's wide data into the clean all data
use entz_all_reg, clear

merge 1:1 entzid using temp_entz_contig
drop _merge
merge 1:1 entzid using temp_entz_nearest
drop _merge

save table6_entz, replace

********************************************************************************
* Loop over all outcomes
********************************************************************************

global iteration 1000

* Loop over regressions, selecting a new bootstrapped sample each time. This is computationally intensive, but I can be sure of what is happening.

foreach j in unemprt povrat frac avemer indemp {

	*** Run the boostrapped samples and save betas and SEs
	
	foreach i of numlist 1/$iteration {

	* Import data
	use table6_entz, clear

	* Set seed
	set seed `i' // Change seed each time
	gen seed = `i' // generate indicator which which seed is used

	* Generate new bootstrapped sample
	bsample // Generates new bootstrapped sample. 

	* 1. Run HSIS model with nearest controls, save betas and SEs
	qui xtreg ddd_`j'_near, re
	gen b_hsis_near_`j'_bs = _b[_cons]
	gen se_hsis_near_`j'_bs = _se[_cons]

	* Drop treated tracts that were not used in the HSIS estimation (due to missing data on the triple difference outcome)
	drop if entz == 1 & !e(sample) 

	* 2. Run HSIS model with contiguous controls, save betas and SEs. Run contiguous first, because most restrictive set of controls in terms of data availability.
	qui xtreg ddd_`j'_contig, re
	gen b_hsis_contig_`j'_bs = _b[_cons]
	gen se_hsis_contig_`j'_bs = _se[_cons]

	* 3. Run HSIS model with all controls, save betas
	qui xtreg dd_`j'_ncdb entz i.state
	gen b_hsis_all_`j'_bs = _b[entz]
	gen se_hsis_all_`j'_bs = _se[entz]

	* 4. Run PSM model
	qui teffects psmatch (dd_`j'_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
	gen b_psm_`j'_bs = _b[r1vs0.entz]
	gen se_psm_`j'_bs = _se[r1vs0.entz]

	* Keep only the betas and SEs. These do not vary across observations, so it's really just collapsing repeated values to a single row
	collapse b_* se_* seed
	
	tempfile table6_entz_`j'`i'
	qui save `table6_entz_`j'`i'', replace // the estimates from each iteration are saved as a separate dta file. Each file varies by the outcome and the seed.
	}
}

* Combine all betas and SEs
foreach j in unemprt povrat frac avemer indemp {

* Append all the iterations from each bootstrap for a given outcome	
use `table6_entz_`j'1', clear
	foreach i of numlist 2/$iteration {
	qui append using `table6_entz_`j'`i''
	}

* Generate correlations between HSIS and PS estimates
	* Nearest and PS
	corr b_hsis_near_`j'_bs b_psm_`j'_bs
	gen corr_near_ps_`j' = r(rho)
	* Contiguous and PS
	corr b_hsis_contig_`j'_bs b_psm_`j'_bs
	gen corr_contig_ps_`j' = r(rho)
	* All and PS
	corr b_hsis_all_`j'_bs b_psm_`j'_bs
	gen corr_all_ps_`j' = r(rho)

collapse b_* se_* corr_*

gen id = 1 // for merging
	
qui save tab6_`j'_ests, replace

}


* Run models in Table 6, and combine these estimates with the bootstrapped correlation estimates above
use table6_entz, clear
xtset county

foreach j in unemprt povrat frac avemer indemp {

* Contiguous
qui xtreg ddd_`j'_contig, re
gen b_hsis_`j'_contig = _b[_cons]
gen se_hsis_`j'_contig = _se[_cons]

* Nearest
qui xtreg ddd_`j'_near, re
gen b_hsis_`j'_near = _b[_cons]
gen se_hsis_`j'_near = _se[_cons]

* All
qui xtreg dd_`j'_ncdb entz i.state
gen b_hsis_`j'_all = _b[entz]
gen se_hsis_`j'_all = _se[entz]

* PS 
qui teffects psmatch (dd_`j'_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
gen b_psm_`j' = _b[r1vs0.entz]
gen se_psm_`j' = _se[r1vs0.entz]

}


collapse b_* se_*
gen id = 1 // Id for merging

foreach j in unemprt povrat frac avemer indemp {

merge 1:1 id using tab6_`j'_ests
drop _merge
}

save table6_corrs, replace

*** Calculate standard errors and t-statistics for Table 6
use table6_corrs, clear

foreach i in unemprt povrat frac avemer indemp {


//gen cov_`i'_contig = corr_contig_ps_`i'*se_hsis_`i'_contig*se_psm_`i'
	foreach j in contig near all {
	* Generate covariances
	gen cov_`i'_`j' = corr_`j'_ps_`i'*se_hsis_`i'_`j'*se_psm_`i'
	* Generate standard error of differences
	gen se_dif_`i'_`j' = sqrt(se_hsis_`i'_`j'^2 + se_psm_`i'^2 - 2*cov_`i'_`j')
	* Generate t-statistics
	gen t_dif_`i'_`j' = (b_psm_`i' - b_hsis_`i'_`j')/se_dif_`i'_`j'
	
	}
}

save table6_final, replace

use table6_final, clear

su se_dif_unemprt_contig t_dif_unemprt_contig se_dif_povrat_contig t_dif_povrat_contig se_dif_frac_contig t_dif_frac_contig se_dif_avemer_contig t_dif_avemer_contig se_dif_indemp_contig t_dif_indemp_contig

outreg2 using "${tables}Table 6. ENTZ BSed comparisons.xls", replace keep(se_dif_unemprt_contig t_dif_unemprt_contig se_dif_povrat_contig t_dif_povrat_contig se_dif_frac_contig t_dif_frac_contig se_dif_avemer_contig t_dif_avemer_contig se_dif_indemp_contig t_dif_indemp_contig) sum(log)

















































********************************************************************************
************************** Federal Empowerment Zones  **************************
********************************************************************************



******************************* Nearest NEMPZs *********************************

use "hsis_NCDB_nearest_empz.dta", clear

keep empzid unemprt8_empz unemprt9_empz unemprt0_empz povrat8_empz povrat9_empz povrat0_empz frac8_empz frac9_empz frac0_empz avemer8_empz avemer9_empz avemer0_empz indemp8_empz indemp9_empz indemp0_empz unemprt8_nempz unemprt9_nempz unemprt0_nempz povrat8_nempz povrat9_nempz povrat0_nempz frac8_nempz frac9_nempz frac0_nempz avemer8_nempz avemer9_nempz avemer0_nempz indemp8_nempz indemp9_nempz indemp0_nempz ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb ucounty

* Format variables
format empzid %13.0g
tostring empzid, gen(id_str)
gen double empzidtemp = empzid
format empzidtemp %13.0g
order empzid empzidtemp
							
							// Data cleaning //

* 1. Drop observations if missing data for any outcome
foreach i in unemprt8_empz unemprt9_empz unemprt0_empz povrat8_empz povrat9_empz povrat0_empz frac8_empz frac9_empz frac0_empz avemer8_empz avemer9_empz avemer0_empz indemp8_empz indemp9_empz indemp0_empz unemprt8_nempz unemprt9_nempz unemprt0_nempz povrat8_nempz povrat9_nempz povrat0_nempz frac8_nempz frac9_nempz frac0_nempz avemer8_nempz avemer9_nempz avemer0_nempz indemp8_nempz indemp9_nempz indemp0_nempz ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb {
drop if missing(`i')
}


* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
	foreach j in empz nempz {
	gen d_`i'_90_80_`j' = (`i'9_`j' - `i'8_`j')
	drop if missing(d_`i'_90_80_`j')
	}
}
foreach i in unemprt povrat avemer frac indemp {
	gen dd_`i'_90_80 = d_`i'_90_80_empz - d_`i'_90_80_nempz
}

save empz_nearest_reg, replace


					// Collapse data for creating graphs //

				
use empz_nearest_reg, clear

* Keep only nearest outcomes
collapse unemprt8_nempz unemprt9_nempz unemprt0_nempz povrat8_nempz povrat9_nempz povrat0_nempz frac8_nempz frac9_nempz frac0_nempz avemer8_nempz avemer9_nempz avemer0_nempz indemp8_nempz indemp9_nempz indemp0_nempz 

foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
rename `i'_nempz `i'
}

* Sort by empzid
gen n = _n

save nearest_temp, replace


* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use nearest_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save temp_nearest_`j', replace
}

use temp_nearest_unemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "temp_nearest_`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_near
}

save empz_near_ctrl, replace


******************************* Contiguous *************************************

use "hsis_NCDB_contiguous_empz.dta", clear

keep empzid unemprt8_empz unemprt9_empz unemprt0_empz povrat8_empz povrat9_empz povrat0_empz frac8_empz frac9_empz frac0_empz avemer8_empz avemer9_empz avemer0_empz indemp8_empz indemp9_empz indemp0_empz unemprt8_nempzs unemprt9_nempzs unemprt0_nempzs povrat8_nempzs povrat9_nempzs povrat0_nempzs frac8_nempzs frac9_nempzs frac0_nempzs avemer8_nempzs avemer9_nempzs avemer0_nempzs indemp8_nempzs indemp9_nempzs indemp0_nempzs ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb ucounty

* Format variables
format empzid %13.0g
tostring empzid, gen(id_str)
gen double empzidtemp = empzid
format empzidtemp %13.0g
order empzid empzidtemp
							
							// Data cleaning //

							
* 1. Drop observations if missing data for any outcome
foreach i in unemprt8_empz unemprt9_empz unemprt0_empz povrat8_empz povrat9_empz povrat0_empz frac8_empz frac9_empz frac0_empz avemer8_empz avemer9_empz avemer0_empz indemp8_empz indemp9_empz indemp0_empz unemprt8_nempzs unemprt9_nempzs unemprt0_nempzs povrat8_nempzs povrat9_nempzs povrat0_nempzs frac8_nempzs frac9_nempzs frac0_nempzs avemer8_nempzs avemer9_nempzs avemer0_nempzs indemp8_nempzs indemp9_nempzs indemp0_nempzs ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb {
drop if missing(`i')
}

* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
	foreach j in empz nempzs {
	gen d_`i'_90_80_`j' = (`i'9_`j' - `i'8_`j')
	drop if missing(d_`i'_90_80_`j')
	}
}
foreach i in unemprt povrat avemer frac indemp {
	gen dd_`i'_90_80 = d_`i'_90_80_empz - d_`i'_90_80_nempzs
}

save empz_contiguous_reg, replace


					// Collapse data for creating graphs //


use  empz_contiguous_reg, clear
					
* Collapse data to year-by-outcome cells
collapse unemprt8_nempzs unemprt9_nempzs unemprt0_nempzs povrat8_nempzs povrat9_nempzs povrat0_nempzs frac8_nempzs frac9_nempzs frac0_nempzs avemer8_nempzs avemer9_nempzs avemer0_nempzs indemp8_nempzs indemp9_nempzs indemp0_nempzs

foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {

rename `i'_nempzs `i'

}

gen n = _n

save empz_contig_temp, replace
 

* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use empz_contig_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save empz_contig_temp`j', replace
}

use contig_tempunemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "empz_contig_temp`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_contig
}

save empz_contig_ctrl, replace

******************************* All *************************************

use "hsis_NCDB_AllEmpz.dta", clear

* Sort data
rename id_fixed tractid
gsort - empz + tractid

							// Data cleaning //


* 1. Drop observations if missing data for any outcome
foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 dd_unemprt_ncdb dd_povrat_ncdb dd_avemer_ncdb dd_indemp_ncdb dd_frac_ncdb {
drop if missing(`i')
}

* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
	gen d_`i'_90_80 = (`i'9 - `i'8)
	drop if missing(d_`i'_90_80)
}

save empz_all_reg, replace


					// Collapse data for creating graphs //


use empz_all_reg, clear

* Collapse data down to year-by-outcome cells
collapse unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0
gen n = _n

save all_temp, replace
 
use all_temp, clear
* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use all_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save all_temp`j', replace
}

use all_tempunemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "all_temp`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_all
}

save empz_all_ctrl, replace


******************************** Treated EMPZs *********************************


			// Collapse treated from ALL data for creating graphs //

					
* Collapse All treated outcomes
use empz_all_reg, clear

keep if empz == 1

collapse unemprt* povrat* frac* avemer* indemp*

gen n = _n

save empz_treat_collapsed, replace


* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use empz_treat_collapsed, clear

reshape long `j', i(n) j(year)

keep year `j'

save temp_treat_`j', replace
}

use temp_treat_unemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "temp_treat_`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_treat
}

save empz_treated, replace



******************************* PS matched EMPZ ********************************

use empz_all_reg, clear

tab empz // 262


				// Run PS Match to identify PS-matched controls //


* Run PS match using ATT to identify matched controls
capture noi teffects psmatch (dd_unemprt_ncdb) (empz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), gen(match) atet


			// Create treated and selected controls data for Table 4 //

codebook match if empz == 1 // 221 controls selected
tab empz if e(sample) // 262 treated


* I want to identify the control tracts that match up to treated tracts
* Sort data by tract id
gsort - empz + tractid
gen n = _n
gen control = match1 if empz == 1

* Create individual datasets of matched pairs and then append them.
foreach i of numlist 1/262 {
preserve
qui gen flag = 1 if n == `i'
qui gen tempm = match1 if flag == 1
qui replace tempm = 0 if missing(tempm)
qui egen m1 = max(tempm)
qui drop tempm
qui replace flag = 1 if n == m1
qui keep if flag == 1
qui gen id = `i'
qui tempfile m`i'
qui save `m`i'', replace
restore
}

* Append temp files created above
use `m1', clear
foreach i of numlist 2/262 {
append using `m`i''
}

save empz_psm_append, replace


					// Collapse data for creating graphs //

					
use empz_psm_append, clear

* Keep only controls
keep if empz == 0

* Collapse outcomes to their means
collapse (mean) unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 avemer8 avemer9 avemer0 frac8 frac9 frac0 indemp8 indemp9 indemp0 

* Save data and process each variable separately
tempfile empz_psm_temp
save `empz_psm_temp', replace

* Reshape data doing each variable individually

foreach i in unemprt povrat frac avemer indemp {

use `empz_psm_temp', clear
gen n = _n
reshape long `i', i(n) j(year)
keep year `i'

tempfile empz_psm_`i'
save `empz_psm_`i'', replace

}

* Combine PS matched data

use `empz_psm_unemprt', clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using `empz_psm_`j''
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_psm
}

save empz_psm_ctrl, replace




****************************** Busso & Kline ************************************

use empz_hsis_ncdb_bk_coded, clear

foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 dd_unemprt_ncdb dd_povrat_ncdb dd_frac_ncdb dd_avemer_ncdb dd_indemp_ncdb {
drop if missing(`i')
}

* Generate 1980-1990 changes
foreach i in unemprt povrat avemer frac indemp {
	gen d_`i'_90_80 = (`i'9 - `i'8)
	drop if missing(d_`i'_90_80)
}

save empz_bk_reg, replace


					// Collapse data for creating graphs //


use empz_bk_reg, clear

* BK controls and intersection of BK and HSIS controls
keep if empz_tr_hsis_ctrl_inter == 0

collapse unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0

gen n = _n

save empz_bk_temp, replace
 

* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use empz_bk_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save empz_bk_temp`j', replace
}

use empz_bk_tempunemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "empz_bk_temp`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_bk
}

save empz_bk_ctrl, replace


********************************************************************************
* Merge together all datasets

use empz_treated, clear
merge 1:1 year using empz_near_ctrl
drop _merge
merge 1:1 year using empz_contig_ctrl
drop _merge
merge 1:1 year using empz_all_ctrl
drop _merge
merge 1:1 year using empz_bk_ctrl
drop _merge
merge 1:1 year using empz_psm_ctrl
drop _merge

recode year (0 = 2000) (9 = 1990) (8 = 1980)

sort year 

* Label variables 
foreach i in unemprt povrat frac avemer indemp {
label var `i'_treat "Treated"
label var `i'_near "Nearest"
label var `i'_contig "Contiguous"
label var `i'_all "All"
label var `i'_bk "Rejected/Future"
label var `i'_psm "PS Matched"
}

save empz_ashenfelter_graph, replace



********************************************************************************
* Figure 2. Comparing Trends in for Federal Empowerment Zones (EMPZs) and Potential Controls
********************************************************************************

use empz_ashenfelter_graph, clear

* Unemployment:
twoway (line unemprt_treat year, lcolor(black)) (line unemprt_near year, lpattern(longdash) lcolor(black)) (line unemprt_contig year, lpattern(dash) lcolor(black)) (line unemprt_all year, lpattern(shortdash) lcolor(black)) (line unemprt_bk year, lpattern(longdash_dot) lcolor(black)) (line unemprt_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Unemployment Rate (%)") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 2. A. Unemployment rate.png", replace

* Poverty
twoway (line povrat_treat year, lcolor(black)) (line povrat_near year, lpattern(longdash) lcolor(black)) (line povrat_contig year, lpattern(dash) lcolor(black)) (line povrat_all year, lpattern(shortdash) lcolor(black)) (line povrat_bk year, lpattern(longdash_dot) lcolor(black)) (line povrat_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Poverty Rate (%)") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 2. B. Poverty rate.png", replace

* Fraction with wage and salary income
twoway (line frac_treat year, lcolor(black)) (line frac_near year, lpattern(longdash) lcolor(black)) (line frac_contig year, lpattern(dash) lcolor(black)) (line frac_all year, lpattern(shortdash) lcolor(black)) (line frac_bk year, lpattern(longdash_dot) lcolor(black)) (line frac_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Fraction with wage and salary income") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 2. C. Fraction of HHs with W & S income.png", replace

* Wage and salary income
twoway (line avemer_treat year, lcolor(black)) (line avemer_near year, lpattern(longdash) lcolor(black)) (line avemer_contig year, lpattern(dash) lcolor(black)) (line avemer_all year, lpattern(shortdash) lcolor(black)) (line avemer_bk year, lpattern(longdash_dot) lcolor(black)) (line avemer_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Average wage and salary income") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 2. D. Avg W & S Income.png", replace

* Employment
twoway (line indemp_treat year, lcolor(black)) (line indemp_near year, lpattern(longdash) lcolor(black)) (line indemp_contig year, lpattern(dash) lcolor(black)) (line indemp_all year, lpattern(shortdash) lcolor(black)) (line indemp_bk year, lpattern(longdash_dot) lcolor(black)) (line indemp_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Employment") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 2. E. Employment.png", replace


********************************************************************************
*			 Regression estimates of the effect of EMPZs on LMOs
********************************************************************************

********************************************************************************
* Table 4. Estimates of the effect of empzs on pre-treatement changes
********************************************************************************

							// Panel 1: Treated //
						
			
use empz_all_reg, clear

* Keep only EMPZs
keep if empz == 1

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 4. Panel 1. Pre-treatment trends - Treated EMPZs.xls", replace sum(log) title("Table 4. Panel 1. Pre-treatment trends - Treated EMPZs") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)
						

						
							// Panel 2: Nearest //
						
use empz_nearest_reg, clear

* Order variables
order d_unemprt_90_80_nempz d_povrat_90_80_nempz d_frac_90_80_nempz d_avemer_90_80_nempz d_indemp_90_80_nempz

* Outreg results
outreg2 using "${tables}Table 4. Panel 2. Pre-treatment trends - Nearest NEMPZs.xls", replace sum(log) title("Table 4. Panel 2. Pre-treatment trends - Nearest NEMPZs") keep(d_unemprt_90_80_nempz d_povrat_90_80_nempz d_frac_90_80_nempz d_avemer_90_80_nempz d_indemp_90_80_nempz)

*** t-test of differences compared to treated

* Unemployment
ttesti	262	6.040	11.35	259	2.084	9.033
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	262	5.766	11.71	259	2.388	10.61
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	262	-0.541	12.13	259	-0.537	9.981
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	262	-129.3	9890	259	1828	9244
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	262	-121.1	252.9	259	-48.22	269.2
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 4. Panel 2. Pre-treatment trends - Nearest EMPZs - p-values.xls", replace sum(log) title("Table 4. Panel 2. Pre-treatment trends - Nearest EMPZs - p-values")


							// Panel 3: Contiguous //
				
				
use empz_contiguous_reg, clear

* Order variables
order d_unemprt_90_80_nempzs d_povrat_90_80_nempzs d_frac_90_80_nempzs d_avemer_90_80_nempzs d_indemp_90_80_nempzs

* Outreg results
outreg2 using "${tables}Table 4. Panel 3. Pre-treatment trends - Contiguous NEMPZs.xls", replace sum(log) title("Table 4. Panel 3. Pre-treatment trends - Contiguous NEMPZs") keep(d_unemprt_90_80_nempzs d_povrat_90_80_nempzs d_frac_90_80_nempzs d_avemer_90_80_nempzs d_indemp_90_80_nempzs)

*** t-test of differences compared to treated

* Unemployment
ttesti	262	6.040	11.35	259	2.036	7.488
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	262	5.766	11.71	259	2.606	7.830
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	262	-0.541	12.13	259	-0.735	7.727
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	262	-129.3	9890	259	1815	7973
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	262	-121.1	252.9	259	-46.41	234.0
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 4. Panel 3. Pre-treatment trends - Contiguous EMPZs - p-values.xls", replace sum(log) title("Table 4. Panel 3. Pre-treatment trends - Contiguous EMPZs - p-values")




								// Panel 4: All //

use empz_all_reg, clear

* Keep only NEMPZs
keep if empz == 0

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 4. Panel 4. Pre-treatment trends - All NEMPZs.xls", replace sum(log) title("Table 4. Panel 4. Pre-treatment trends - All NEMPZs") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)

*** t-test of differences compared to treated

* Unemployment	
ttesti	262	6.040	11.35	13881	-0.564	4.446
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	262	5.766	11.71	13881	0.775	6.733
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	262	-0.541	12.13	13881	-0.948	7.263
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	262	-129.3	9890	13881	6165	12581
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	262	-121.1	252.9	13881	205.9	422.1
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 4. Panel 4. Pre-treatment trends - All EMPZs - p-values.xls", replace sum(log) title("Table 4. Panel 4. Pre-treatment trends - All EMPZs - p-values")



							// Panel 5: Busso and Kline //

use empz_bk_reg, clear

* Keep only NEMPZs
keep if empz_tr_hsis_ctrl_inter == 0

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 4. Panel 5. Pre-treatment trends - BK NEMPZs.xls", replace sum(log) title("Table 4. Panel 5. Pre-treatment trends - BK NEMPZs") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)

*** t-test of differences compared to treated

* Unemployment	
ttesti	262	6.040	11.35	442	2.815	7.267
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	262	5.766	11.71	442	6.286	12.58
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	262	-0.541	12.13	442	-1.520	9.612
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	262	-129.3	9890	442	-1258	7958
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	262	-121.1	252.9	442	-116.8	238.4
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 4. Panel 5. Pre-treatment trends - BK NEMPZs - p-values.xls", replace sum(log) title("Table 4. Panel 5. Pre-treatment trends - BK NEMPZs - p-values")



							// Panel 6: PS-matched //

use empz_psm_append, clear

* Keep only NEMPZs
keep if empz == 0

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 4. Panel 6. Pre-treatment trends - PS matched.xls", replace sum(log) title("Table 4. Panel 6. Pre-treatment trends - PS matched") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)
	
*** t-test of differences compared to treated

* Unemployment	
ttesti	262	6.040	11.35	262	4.628	9.196
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	262	5.766	11.71	262	6.143	15.11
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	262	-0.541	12.13	262	-1.152	12.61
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	262	-129.3	9890	262	5.081	11128
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	262	-121.1	252.9	262	-125.2	244.3
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 4. Panel 6. Pre-treatment trends - PS Matched NEMPZs - p-values.xls", replace sum(log) title("Table 4. Panel 6. Pre-treatment trends - PS Matched NEMPZs - p-values")

	

********************************************************************************
* Table 7. Regression estimates of the effect of EMPZs on LMOs
********************************************************************************

**************************** 1. HSIS Preferred *********************************

use empz_all_reg, clear

xtset ucounty
      
* Unemployment
xtreg dd_unemprt_ncdb empz i.statecd, re
outreg2 using "${tables}Table 7. Panel 1. EMPZ preferred estimates.xls", replace title("Table 7. Panel 1. EMPZ preferred estimates") ///
ctitle("Unemployment rate - All")

tab empz if e(sample)

use empz_contiguous_reg, clear

xtset ucounty

* Poverty
xtreg ddd_povrat_ncdb, re
outreg2 using "${tables}Table 7. Panel 1. EMPZ preferred estimates.xls", append title("Table 7. Panel 1. EMPZ preferred estimates") ///
ctitle("Poverty - Contiguous")

* Fraction
xtreg ddd_frac_ncdb, re
outreg2 using "${tables}Table 7. Panel 1. EMPZ preferred estimates.xls", append title("Table 7. Panel 1. EMPZ preferred estimates") ///
ctitle("Fraction - Contiguous")


use empz_all_reg, clear

xtset ucounty

* Average Wage and Salary Income
xtreg dd_avemer_ncdb empz i.statecd, re
outreg2 using "${tables}Table 7. Panel 1. EMPZ preferred estimates.xls", append title("Table 7. Panel 1. EMPZ preferred estimates") ///
ctitle("Average Wage and Salary Income - All")

* Employment
xtreg dd_indemp_ncdb empz i.statecd, re
outreg2 using "${tables}Table 7. Panel 1. EMPZ preferred estimates.xls", append title("Table 7. Panel 1. EMPZ preferred estimates") ///
ctitle("Employment - All")


***************************** 2. Busso and Kline *******************************

use empz_bk_reg, clear

* Number of counties for treatd tracts
codebook ucounty if empz_tr_hsis_ctrl_inter == 1

xtset ucounty
      
* Unemployment
xtreg dd_unemprt_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 7. Panel 2. EMPZ estimates - Busso and Kline.xls", replace title("Table 7. Panel 2. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Unemployment rate")

tab empz_tr_hsis_ctrl_inter if e(sample)

* Poverty
xtreg dd_povrat_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 7. Panel 2. EMPZ estimates - Busso and Kline.xls", append title("Table 7. Panel 2. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Poverty")

* Fraction
xtreg dd_frac_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 7. Panel 2. EMPZ estimates - Busso and Kline.xls", append title("Table 7. Panel 2. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg dd_avemer_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 7. Panel 2. EMPZ estimates - Busso and Kline.xls", append title("Table 7. Panel 2. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg dd_indemp_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 7. Panel 2. EMPZ estimates - Busso and Kline.xls", append title("Table 7. Panel 2. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Employment")


********************* 3. Propensity Score ********************

use empz_all_reg, clear

* Number of counties for treated tracts
codebook ucounty if empz == 1

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 7. Panel 3. EMPZ estimates - Propensity Score.xls", replace title("Table 7. Panel 3. EMPZ estimates - Propensity Score") ///
ctitle("Unemployment Rate")
codebook ucounty

tab empz if e(sample)

* Poverty rate
teffects psmatch (dd_povrat_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 7. Panel 3. EMPZ estimates - Propensity Score.xls", append title("Table 7. Panel 3. EMPZ estimates - Propensity Score") ///
ctitle("Poverty Rate")

* Fraction with W/S income
teffects psmatch (dd_frac_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 7. Panel 3. EMPZ estimates - Propensity Score.xls", append title("Table 7. Panel 3. EMPZ estimates - Propensity Score") ///
ctitle("Fraction")

* Average WS income
teffects psmatch (dd_avemer_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 7. Panel 3. EMPZ estimates - Propensity Score.xls", append title("Table 7. Panel 3. EMPZ estimates - Propensity Score") ///
ctitle("Average WS Income")

* Employment
teffects psmatch (dd_indemp_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 7. Panel 3. EMPZ estimates - Propensity Score.xls", append title("Table 7. Panel 3. EMPZ estimates - Propensity Score") ///
ctitle("Employment")



********************************************************************************
********************************************************************************
* Bootstrapped Table 7 estimates
********************************************************************************
********************************************************************************

********************************************************************************
* Create dataset containing nearest, contiguous, all, and PSM data
********************************************************************************

* Combine contiguous and nearest triple difference values into a single all dataset.

* Contiguous
use empz_contiguous_reg, clear
keep empzid ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb 

foreach i in ddd_unemprt_ ddd_povrat_ ddd_frac_ ddd_avemer_ ddd_indemp_ {
rename `i'ncdb `i'contig
}

save temp_empz_contig, replace

* Nearest
use empz_nearest_reg, clear

keep empzid ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb 

foreach i in ddd_unemprt_ ddd_povrat_ ddd_frac_ ddd_avemer_ ddd_indemp_ {
rename `i'ncdb `i'nearest
}

save temp_empz_nearest, replace

* BK controls
use empz_bk_reg, clear

rename tract2000 empzid
keep empzid empz_tr_hsis_ctrl_inter
drop if empz_tr == .

save temp_empz_bk, replace


* Merge in HSIS's wide data into the clean all data
use empz_all_reg, clear

drop empzid
rename tractid empzid

merge 1:1 empzid using temp_empz_contig
drop _merge
merge 1:1 empzid using temp_empz_nearest
drop _merge
merge 1:1 empzid using temp_empz_bk
drop _merge

save table7_empz, replace

********************************************************************************
* Loop over all outcomes
********************************************************************************

global iteration 1000

* Loop over regressions, selecting a new bootstrapped sample each time. This is computationally intensive, but I can be sure of what is happening.

foreach j in unemprt povrat frac avemer indemp {

	*** Run the boostrapped samples and save betas and SEs
	
	foreach i of numlist 1/$iteration {

	* Import data
	use table7_empz, clear

	* Set seed
	set seed `i' // Change seed each time
	gen seed = `i' // generate indicator which which seed is used

	* Generate new bootstrapped sample
	bsample // Generates new bootstrapped sample. I don't want to iterate ove this, because I think each bootstrapped sample will be based on the last bootstrapped sample, and my data will lose variation. The other option would be to write a program for this and iterate over it.

	* 1. Run HSIS model with nearest controls, save betas and SEs
	qui xtreg ddd_`j'_near, re
	gen b_hsis_near_`j'_bs = _b[_cons]
	gen se_hsis_near_`j'_bs = _se[_cons]

	* Drop treated tracts that were not used in the HSIS estimation (due to missing data on the triple difference outcome)
	drop if empz == 1 & !e(sample) 

	* 2. Run HSIS model with contiguous controls, save betas and SEs. Run contiguous first, because most restrictive set of controls in terms of data availability.
	qui xtreg ddd_`j'_contig, re
	gen b_hsis_contig_`j'_bs = _b[_cons]
	gen se_hsis_contig_`j'_bs = _se[_cons]

	* 3. Run HSIS model with all controls, save betas
	qui xtreg dd_`j'_ncdb empz i.state
	gen b_hsis_all_`j'_bs = _b[empz]
	gen se_hsis_all_`j'_bs = _se[empz]

	* 4. Run Busso et al. model
	qui xtreg dd_`j'_ncdb empz_tr_hsis_ctrl_inter, re
	gen b_bk_`j'_bs = _b[empz_tr_hsis_ctrl_inter]
	gen se_bk_`j'_bs = _se[empz_tr_hsis_ctrl_inter]
	
	* 5. Run PSM model
	qui teffects psmatch (dd_`j'_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
	gen b_psm_`j'_bs = _b[r1vs0.empz]
	gen se_psm_`j'_bs = _se[r1vs0.empz]

	
	* Keep only the betas and SEs. These do not vary across observations, so it's really just collapsing repeated values to a single row
	collapse b_* se_* seed
	
	tempfile table7_empz_`j'`i'
	qui save `table7_empz_`j'`i'', replace // the estimates from each iteration are saved as a separate dta file. Each file varies by the outcome and the seed.
	}
}

* Combine all betas and SEs
foreach j in unemprt povrat frac avemer indemp {

* Append all the iterations from each bootstrap for a given outcome	
use `table7_empz_`j'1', clear
	foreach i of numlist 2/$iteration {
	qui append using `table7_empz_`j'`i''
	}

* Generate correlations between HSIS and PS estimates
	* Nearest and PS
	corr b_hsis_near_`j'_bs b_psm_`j'_bs
	gen corr_near_ps_`j' = r(rho)
	* Contiguous and PS
	corr b_hsis_contig_`j'_bs b_psm_`j'_bs
	gen corr_contig_ps_`j' = r(rho)
	* BK and PS
	corr b_bk_`j'_bs b_psm_`j'_bs
	gen corr_bk_ps_`j' = r(rho)
	* All and PS
	corr b_hsis_all_`j'_bs b_psm_`j'_bs
	gen corr_all_ps_`j' = r(rho)

collapse b_* se_* corr_*

gen id = 1 // for merging
	
qui save tab7_`j'_ests, replace

}


* Run models in Table 7, and combine these estimates with the bootstrapped correlation estimates above
use table7_empz, clear
xtset county

foreach j in unemprt povrat frac avemer indemp {

* Contiguous
qui xtreg ddd_`j'_contig, re
gen b_hsis_`j'_contig = _b[_cons]
gen se_hsis_`j'_contig = _se[_cons]

* Nearest
qui xtreg ddd_`j'_near, re
gen b_hsis_`j'_near = _b[_cons]
gen se_hsis_`j'_near = _se[_cons]

* All
qui xtreg dd_`j'_ncdb empz i.state
gen b_hsis_`j'_all = _b[empz]
gen se_hsis_`j'_all = _se[empz]

* BK
qui xtreg dd_`j'_ncdb empz_tr_hsis_ctrl_inter
gen b_bk_`j' = _b[empz_tr_hsis_ctrl_inter]
gen se_bk_`j' = _se[empz_tr_hsis_ctrl_inter]

* PS 
qui teffects psmatch (dd_`j'_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
gen b_psm_`j' = _b[r1vs0.empz]
gen se_psm_`j' = _se[r1vs0.empz]

}

collapse b_* se_*
gen id = 1 // Id for merging

* Merge in estimated correlations between betas from the bootstrapping above.
foreach j in unemprt povrat frac avemer indemp {

merge 1:1 id using tab7_`j'_ests
drop _merge
}

save table7_corrs, replace

*** Calculate estimated covariance from bootstraps, standard errors, and t-statistics for Table 7. Note that all the correlation variables in these data are bootstrapped. The standard errors are from non-bootstrapped models and equal the standard errors prsented in the paper.
use table7_corrs, clear

foreach i in unemprt povrat frac avemer indemp {

*** For HSIS
foreach j in near contig all {
* Generate covariances
gen cov_`i'_`j' = corr_`j'_ps_`i'*se_hsis_`i'_`j'*se_psm_`i'
* Generate standard error of differences
gen se_dif_`i'_`j' = sqrt(se_hsis_`i'_`j'^2 + se_psm_`i'^2 - 2*cov_`i'_`j')
* Generate t-statistics
gen t_dif_`i'_`j' = (b_psm_`i' - b_hsis_`i'_`j')/se_dif_`i'_`j'
}

** For BK
* Generate covariances
gen cov_`i'_bk = corr_bk_ps_`i'*se_bk_`i'_bs*se_psm_`i'
* Generate standard error of differences
gen se_dif_`i'_bk = sqrt(se_bk_`i'_bs^2 + se_psm_`i'_bs^2 - 2*cov_`i'_bk)
* Generate t-statistics
gen t_dif_`i'_bk = (b_psm_`i' - b_bk_`i')/se_dif_`i'_bk

}

save table7_final, replace

use table7_final, clear

order b_hsis_unemprt_all se_hsis_unemprt_all b_psm_unemprt se_psm_unemprt se_dif_unemprt_all t_dif_unemprt_all ///
   b_hsis_povrat_contig se_hsis_povrat_contig b_psm_povrat se_psm_povrat se_dif_povrat_contig t_dif_povrat_contig ///
   b_hsis_frac_contig se_hsis_frac_contig b_psm_frac se_psm_frac se_dif_frac_contig t_dif_frac_contig ///
   b_hsis_avemer_all se_hsis_avemer_all b_psm_avemer se_psm_avemer se_dif_avemer_all t_dif_avemer_all ///
   b_hsis_indemp_all se_hsis_indemp_all b_psm_indemp se_psm_indemp se_dif_indemp_all t_dif_indemp_all

outreg2 using "${tables}Table 7. EMPZ BSed comparisons - HSIS.xls", replace keep(b_hsis_unemprt_all se_hsis_unemprt_all b_psm_unemprt se_psm_unemprt se_dif_unemprt_all t_dif_unemprt_all ///
   b_hsis_povrat_contig se_hsis_povrat_contig b_psm_povrat se_psm_povrat se_dif_povrat_contig t_dif_povrat_contig ///
   b_hsis_frac_contig se_hsis_frac_contig b_psm_frac se_psm_frac se_dif_frac_contig t_dif_frac_contig ///
   b_hsis_avemer_all se_hsis_avemer_all b_psm_avemer se_psm_avemer se_dif_avemer_all t_dif_avemer_all ///
   b_hsis_indemp_all se_hsis_indemp_all b_psm_indemp se_psm_indemp se_dif_indemp_all t_dif_indemp_all) sum(log)

order b_bk_unemprt se_bk_unemprt b_psm_unemprt se_psm_unemprt se_dif_unemprt_bk t_dif_unemprt_bk ///
   b_bk_povrat se_bk_povrat b_psm_povrat se_psm_povrat se_dif_povrat_bk t_dif_povrat_bk ///
   b_bk_frac se_bk_frac b_psm_frac se_psm_frac se_dif_frac_bk t_dif_frac_bk ///
   b_bk_avemer se_bk_avemer b_psm_avemer se_psm_avemer se_dif_avemer_bk t_dif_avemer_bk ///
   b_bk_indemp se_bk_indemp b_psm_indemp se_psm_indemp se_dif_indemp_bk t_dif_indemp_bk
   
outreg2 using "${tables}Table 7. EMPZ BSed comparisons - BK.xls", replace keep(b_bk_unemprt se_bk_unemprt b_psm_unemprt se_psm_unemprt se_dif_unemprt_bk t_dif_unemprt_bk ///
   b_bk_povrat se_bk_povrat b_psm_povrat se_psm_povrat se_dif_povrat_bk t_dif_povrat_bk ///
   b_bk_frac se_bk_frac b_psm_frac se_psm_frac se_dif_frac_bk t_dif_frac_bk ///
   b_bk_avemer se_bk_avemer b_psm_avemer se_psm_avemer se_dif_avemer_bk t_dif_avemer_bk ///
   b_bk_indemp se_bk_indemp b_psm_indemp se_psm_indemp se_dif_indemp_bk t_dif_indemp_bk) sum(log)
    
















































































































********************************************************************************
*********************** Federal Enterprise Communities  ************************
********************************************************************************



******************************* Nearest Nentcs *********************************

use "hsis_NCDB_nearest_entc.dta", clear

keep entcid unemprt8_entc unemprt9_entc unemprt0_entc povrat8_entc povrat9_entc povrat0_entc frac8_entc frac9_entc frac0_entc avemer8_entc avemer9_entc avemer0_entc indemp8_entc indemp9_entc indemp0_entc unemprt8_nentc unemprt9_nentc unemprt0_nentc povrat8_nentc povrat9_nentc povrat0_nentc frac8_nentc frac9_nentc frac0_nentc avemer8_nentc avemer9_nentc avemer0_nentc indemp8_nentc indemp9_nentc indemp0_nentc ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb ucounty

* Format variables
format entcid %13.0g
tostring entcid, gen(id_str)
gen double entcidtemp = entcid
format entcidtemp %13.0g
order entcid entcidtemp
							
							// Data cleaning //

* 1. Drop observations if missing data for any outcome
foreach i in unemprt8_entc unemprt9_entc unemprt0_entc povrat8_entc povrat9_entc povrat0_entc frac8_entc frac9_entc frac0_entc avemer8_entc avemer9_entc avemer0_entc indemp8_entc indemp9_entc indemp0_entc unemprt8_nentc unemprt9_nentc unemprt0_nentc povrat8_nentc povrat9_nentc povrat0_nentc frac8_nentc frac9_nentc frac0_nentc avemer8_nentc avemer9_nentc avemer0_nentc indemp8_nentc indemp9_nentc indemp0_nentc ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb {
drop if missing(`i')
}


* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
	foreach j in entc nentc {
	gen d_`i'_90_80_`j' = (`i'9_`j' - `i'8_`j')
	drop if missing(d_`i'_90_80_`j')
	}
}
foreach i in unemprt povrat avemer frac indemp {
	gen dd_`i'_90_80 = d_`i'_90_80_entc - d_`i'_90_80_nentc
}

save entc_nearest_reg, replace


					// Collapse data for creating graphs //

				
use entc_nearest_reg, clear

* Keep only nearest outcomes
collapse unemprt8_nentc unemprt9_nentc unemprt0_nentc povrat8_nentc povrat9_nentc povrat0_nentc frac8_nentc frac9_nentc frac0_nentc avemer8_nentc avemer9_nentc avemer0_nentc indemp8_nentc indemp9_nentc indemp0_nentc 

foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {
rename `i'_nentc `i'
}

* Sort by entcid
gen n = _n

save nearest_temp, replace


* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use nearest_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save temp_nearest_`j', replace
}

use temp_nearest_unemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "temp_nearest_`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_near
}

save entc_near_ctrl, replace


******************************* Contiguous *************************************

use "hsis_NCDB_contiguous_entc.dta", clear

keep entcid unemprt8_entc unemprt9_entc unemprt0_entc povrat8_entc povrat9_entc povrat0_entc frac8_entc frac9_entc frac0_entc avemer8_entc avemer9_entc avemer0_entc indemp8_entc indemp9_entc indemp0_entc unemprt8_nentcs unemprt9_nentcs unemprt0_nentcs povrat8_nentcs povrat9_nentcs povrat0_nentcs frac8_nentcs frac9_nentcs frac0_nentcs avemer8_nentcs avemer9_nentcs avemer0_nentcs indemp8_nentcs indemp9_nentcs indemp0_nentcs ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb ucounty

* Format variables
format entcid %13.0g
tostring entcid, gen(id_str)
gen double entcidtemp = entcid
format entcidtemp %13.0g
order entcid entcidtemp
							
							// Data cleaning //

							
* 1. Drop observations if missing data for any outcome
foreach i in unemprt8_entc unemprt9_entc unemprt0_entc povrat8_entc povrat9_entc povrat0_entc frac8_entc frac9_entc frac0_entc avemer8_entc avemer9_entc avemer0_entc indemp8_entc indemp9_entc indemp0_entc unemprt8_nentcs unemprt9_nentcs unemprt0_nentcs povrat8_nentcs povrat9_nentcs povrat0_nentcs frac8_nentcs frac9_nentcs frac0_nentcs avemer8_nentcs avemer9_nentcs avemer0_nentcs indemp8_nentcs indemp9_nentcs indemp0_nentcs ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb {
drop if missing(`i')
}

* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
	foreach j in entc nentcs {
	gen d_`i'_90_80_`j' = (`i'9_`j' - `i'8_`j')
	drop if missing(d_`i'_90_80_`j')
	}
}
foreach i in unemprt povrat avemer frac indemp {
	gen dd_`i'_90_80 = d_`i'_90_80_entc - d_`i'_90_80_nentc
}

save entc_contiguous_reg, replace


					// Collapse data for creating graphs //


use  entc_contiguous_reg, clear
					
* Collapse data to year-by-outcome cells
collapse unemprt8_nentcs unemprt9_nentcs unemprt0_nentcs povrat8_nentcs povrat9_nentcs povrat0_nentcs frac8_nentcs frac9_nentcs frac0_nentcs avemer8_nentcs avemer9_nentcs avemer0_nentcs indemp8_nentcs indemp9_nentcs indemp0_nentcs

foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 {

rename `i'_nentcs `i'

}

gen n = _n

save entc_contig_temp, replace
 

* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use entc_contig_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save entc_contig_temp`j', replace
}

use contig_tempunemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "entc_contig_temp`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_contig
}

save entc_contig_ctrl, replace

******************************* All *************************************

use "hsis_NCDB_all_entc.dta", clear

* Sort data
gsort - entc + tractid

							// Data cleaning //


* 1. Drop observations if missing data for any outcome
foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 dd_unemprt_ncdb dd_povrat_ncdb dd_avemer_ncdb dd_indemp_ncdb dd_frac_ncdb {
drop if missing(`i')
}

* 2. Generate 1980-1990 percent change in each outcome, and drop tracts if missing any outcome data
foreach i in unemprt povrat avemer frac indemp {
	gen d_`i'_90_80 = (`i'9 - `i'8)
	drop if missing(d_`i'_90_80)
}

save entc_all_reg, replace


					// Collapse data for creating graphs //


use entc_all_reg, clear

* Collapse data down to year-by-outcome cells
collapse unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0
gen n = _n

save all_temp, replace
 
use all_temp, clear
* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use all_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save all_temp`j', replace
}

use all_tempunemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "all_temp`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_all
}

save entc_all_ctrl, replace


******************************** Treated entcs *********************************


			// Collapse treated from ALL data for creating graphs //

					
* Collapse All treated outcomes
use entc_all_reg, clear

keep if entc == 1

collapse unemprt* povrat* frac* avemer* indemp*

gen n = _n

save entc_treat_collapsed, replace


* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use entc_treat_collapsed, clear

reshape long `j', i(n) j(year)

keep year `j'

save temp_treat_`j', replace
}

use temp_treat_unemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "temp_treat_`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_treat
}

save entc_treated, replace



******************************* PS matched ENTC ********************************

use entc_all_reg, clear

tab entc // 373
gsort - entc + tractid


				// Run PS Match to identify PS-matched controls //


* Run PS match using ATE (default) (will have to drop tracts that do not satisfy the overlap condition)
capture noi teffects psmatch (dd_povrat_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), gen(match) atet


codebook match if entc == 1 // 323 controls selected
tab entc if e(sample) // 373 treated


* I want to identify the control tracts that match up to treated tracts
* Sort data by tract id
gsort - entc + tractid
gen n = _n
gen control = match1 if entc == 1


			// Create treated and selected controls data for Table 4 //

			
* Goal: create a dataset where each observation is a treated tract, and then there is also an observation for it's matched control tract. There should be a total of 372 treated tracts, and 372 control tracts (with some repeats for the controls). When running the regressions on the pretreatment trends, include ID fixed effects.  

* Create individual datasets of matched pairs and then append them.
foreach i of numlist 1/373 {
preserve
qui gen flag = 1 if n == `i'
qui gen tempm = match1 if flag == 1
qui replace tempm = 0 if missing(tempm)
qui egen m1 = max(tempm)
qui drop tempm
qui replace flag = 1 if n == m1
qui keep if flag == 1
qui gen id = `i'
qui tempfile m`i'
qui save `m`i'', replace
restore
}

* Append temp files created above
use `m1', clear
foreach i of numlist 2/373 {
append using `m`i''
}

save entc_psm_append, replace


					// Collapse data for creating graphs //

					
use entc_psm_append, clear

* Keep only controls
keep if entc == 0

* Collapse outcomes to their means
collapse (mean) unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 avemer8 avemer9 avemer0 frac8 frac9 frac0 indemp8 indemp9 indemp0 

* Save data and process each variable separately
tempfile entc_psm_temp
save `entc_psm_temp', replace

* Reshape data doing each variable individually

foreach i in unemprt povrat frac avemer indemp {

use `entc_psm_temp', clear
gen n = _n
reshape long `i', i(n) j(year)
keep year `i'

tempfile entc_psm_`i'
save `entc_psm_`i'', replace

}

* Combine PS matched data

use `entc_psm_unemprt', clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using `entc_psm_`j''
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_psm
}

save entc_psm_ctrl, replace



****************************** Busso & Kline ************************************

use "entc_hsis_ncdb_bk_coded.dta", clear

foreach i in unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0 dd_unemprt_ncdb dd_povrat_ncdb dd_frac_ncdb dd_avemer_ncdb dd_indemp_ncdb {
drop if missing(`i')
}

* Generate 1980-1990 changes
foreach i in unemprt povrat avemer frac indemp {
	gen d_`i'_90_80 = (`i'9 - `i'8)
	drop if missing(d_`i'_90_80)
}

save entc_bk_reg, replace


					// Collapse data for creating graphs //


use entc_bk_reg, clear

* BK controls and intersection of BK and HSIS controls
keep if entc_tr_hsis_ctrl_inter == 0

collapse unemprt8 unemprt9 unemprt0 povrat8 povrat9 povrat0 frac8 frac9 frac0 avemer8 avemer9 avemer0 indemp8 indemp9 indemp0

gen n = _n

save entc_bk_temp, replace
 

* Reshape data doing each variable individually
foreach j in unemprt povrat frac avemer indemp {
use entc_bk_temp, clear

reshape long `j', i(n) j(year)

keep year `j'

save entc_bk_temp`j', replace
}

use entc_bk_tempunemprt, clear
foreach j in povrat frac avemer indemp {
merge 1:1 year using "entc_bk_temp`j'"
drop _merge
} 

foreach i in unemprt povrat frac avemer indemp {
rename `i' `i'_bk
}

save entc_bk_ctrl, replace


********************************************************************************
* Merge together all datasets

use entc_treated, clear
merge 1:1 year using entc_near_ctrl
drop _merge
merge 1:1 year using entc_contig_ctrl
drop _merge
merge 1:1 year using entc_all_ctrl
drop _merge
merge 1:1 year using entc_bk_ctrl
drop _merge
merge 1:1 year using entc_psm_ctrl
drop _merge

recode year (0 = 2000) (9 = 1990) (8 = 1980)

sort year 

* Label variables 
foreach i in unemprt povrat frac avemer indemp {
label var `i'_treat "Treated"
label var `i'_near "Nearest"
label var `i'_contig "Contiguous"
label var `i'_all "All"
label var `i'_bk "Rejected/Future"
label var `i'_psm "PS Matched"
}

save entc_ashenfelter_graph, replace



********************************************************************************
* Figure 3. Comparing Trends in for Federal Enterprise Communities (ENTCs) and Potential Controls
********************************************************************************

use entc_ashenfelter_graph, clear

* Unemployment:
twoway (line unemprt_treat year, lcolor(black)) (line unemprt_near year, lpattern(longdash) lcolor(black)) (line unemprt_contig year, lpattern(dash) lcolor(black)) (line unemprt_all year, lpattern(shortdash) lcolor(black)) (line unemprt_bk year, lpattern(longdash_dot) lcolor(black)) (line unemprt_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Unemployment Rate (%)") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 3. A. Unemployment rate.png", replace

* Poverty
twoway (line povrat_treat year, lcolor(black)) (line povrat_near year, lpattern(longdash) lcolor(black)) (line povrat_contig year, lpattern(dash) lcolor(black)) (line povrat_all year, lpattern(shortdash) lcolor(black)) (line povrat_bk year, lpattern(longdash_dot) lcolor(black)) (line povrat_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Poverty Rate (%)") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 3. B. Poverty rate.png", replace

* Fraction with wage and salary income
twoway (line frac_treat year, lcolor(black)) (line frac_near year, lpattern(longdash) lcolor(black)) (line frac_contig year, lpattern(dash) lcolor(black)) (line frac_all year, lpattern(shortdash) lcolor(black)) (line frac_bk year, lpattern(longdash_dot) lcolor(black)) (line frac_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Fraction with wage and salary income") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 3. C. Fraction with W & S income.png", replace

* Wage and salary income
twoway (line avemer_treat year, lcolor(black)) (line avemer_near year, lpattern(longdash) lcolor(black)) (line avemer_contig year, lpattern(dash) lcolor(black)) (line avemer_all year, lpattern(shortdash) lcolor(black)) (line avemer_bk year, lpattern(longdash_dot) lcolor(black)) (line avemer_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Average wage and salary income") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 3. E. Avg W & S income.png", replace

* Employment
twoway (line indemp_treat year, lcolor(black)) (line indemp_near year, lpattern(longdash) lcolor(black)) (line indemp_contig year, lpattern(dash) lcolor(black)) (line indemp_all year, lpattern(shortdash) lcolor(black)) (line indemp_bk year, lpattern(longdash_dot) lcolor(black)) (line indemp_psm year, lpattern(shortdash_dot) lcolor(black)), ///
ytitle("Employment") xtitle("Year") xlabel(#3)

graph export "${graphs}Figure 3. B. Employment.png", replace


********************************************************************************
*			 Regression estimates of the effect of ENTCs on LMOs
********************************************************************************

********************************************************************************
* Table 5. Estimates of the effect of ENTCs on pre-treatement changes
********************************************************************************

							// Panel 1: Treated //
						
			
use entc_all_reg, clear

* Keep only EMPZs
keep if entc == 1

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 5. Panel 1. Pre-treatment trends - Treated ENTCs.xls", replace sum(log) title("Table 5. Panel 1. Pre-treatment trends - Treated ENTCs") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)
						
							// Panel 2: Nearest //
			// Panel 2: Nearest //
						
use entc_nearest_reg, clear

* Order variables
order d_unemprt_90_80_nentc d_povrat_90_80_nentc d_frac_90_80_nentc d_avemer_90_80_nentc d_indemp_90_80_nentc

* Outreg results
outreg2 using "${tables}Table 5. Panel 2. Pre-treatment trends - Nearest NENTCs.xls", replace sum(log) title("Table 5. Panel 2. Pre-treatment trends - Nearest Nentcs") keep(d_unemprt_90_80_nentc d_povrat_90_80_nentc d_frac_90_80_nentc d_avemer_90_80_nentc d_indemp_90_80_nentc)

*** t-test of differences compared to treated


* Unemployment
ttesti	373	2.676	6.774	341	0.319	5.504
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	373	6.921	11.01	341	1.641	10.91
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	373	-1.910	9.156	341	0.448	9.247
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	373	-944.9	7129	341	1915	10127
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	373	-90.98	249.2	341	13.99	267.8
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 5. Panel 2. Pre-treatment trends - Nearest ENTCs - p-values.xls", replace sum(log) title("Table 5. Panel 2. Pre-treatment trends - Nearest ENTCs - p-values")


							// Panel 3: Contiguous //
				
				
use entc_contiguous_reg, clear

* Order variables
order d_unemprt_90_80_nentcs d_povrat_90_80_nentcs d_frac_90_80_nentcs d_avemer_90_80_nentcs d_indemp_90_80_nentcs

* Outreg results
outreg2 using "${tables}Table 5. Panel 3. Pre-treatment trends - Contiguous NENTCs.xls", replace sum(log) title("Table 5. Panel 3. Pre-treatment trends - Contiguous Nentcs") keep(d_unemprt_90_80_nentcs d_povrat_90_80_nentcs d_frac_90_80_nentcs d_avemer_90_80_nentcs d_indemp_90_80_nentcs)

*** t-test of differences compared to treated

* Unemployment
ttesti	373	2.676	6.774	342	0.496	4.232

local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	373	6.921	11.01	342	1.759	7.482
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	373	-1.910	9.156	342	0.669	7.079
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	373	-944.9	7129	342	1954	8934
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	373	-90.98	249.2	342	15.72	213.7
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 5. Panel 3. Pre-treatment trends - Contiguous ENTCs - p-values.xls", replace sum(log) title("Table 5. Panel 3. Pre-treatment trends - Contiguous ENTCs - p-values")




								// Panel 4: All //

use entc_all_reg, clear

* Keep only Nentcs
keep if entc == 0

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 5. Panel 4. Pre-treatment trends - All NENTCs.xls", replace sum(log) title("Table 5. Panel 4. Pre-treatment trends - All Nentcs") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)

*** t-test of differences compared to treated

* Unemployment	
ttesti	373	2.676	6.774	27145	-0.121	3.64
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	373	6.921	11.01	27145	1.148	5.634
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	373	-1.910	9.156	27145	-0.901	6.816
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	373	-944.9	7129	27145	4124	11791
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	373	-90.98	249.2	27145	379.3	564.6
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 5. Panel 4. Pre-treatment trends - All ENTCs - p-values.xls", replace sum(log) title("Table 5. Panel 4. Pre-treatment trends - All ENTCs - p-values")



							// Panel 5: Busso and Kline //

use entc_bk_reg, clear

* Keep only Nentcs
keep if entc_tr_hsis_ctrl_inter == 0

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 5. Panel 5. Pre-treatment trends - BK NENTCs.xls", replace sum(log) title("Table 5. Panel 5. Pre-treatment trends - BK Nentcs") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)

*** t-test of differences compared to treated

* Unemployment	
ttesti	373	2.676	6.774	360	4.374	7.543
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	373	6.921	11.01	360	7.135	10.52
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	373	-1.910	9.156	360	-1.433	9.275
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	373	-944.9	7129	360	-931	8340
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	373	-90.98	249.2	360	-50.31	326.8
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 5. Panel 5. Pre-treatment trends - BK NENTCs - p-values.xls", replace sum(log) title("Table 5. Panel 5. Pre-treatment trends - BK NENTCs - p-values")



							// Panel 6: PS-matched //

use entc_psm_append, clear

* Keep only Nentcs
keep if entc == 0
codebook entcid

* Order variables
order d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80

* Outreg results
outreg2 using "${tables}Table 5. Panel 6. Pre-treatment trends - PS matched.xls", replace sum(log) title("Table 5. Panel 6. Pre-treatment trends - PS matched") keep(d_unemprt_90_80 d_povrat_90_80 d_frac_90_80 d_avemer_90_80 d_indemp_90_80)
	
*** t-test of differences compared to treated

* Unemployment	
ttesti	373	2.676	6.774	373	2.805	7.384
local near_unemp_t = r(t)
local near_unemp_p = r(p)
gen near_unemp_t = `near_unemp_t'
gen near_unemp_p = `near_unemp_p'

* Poverty
ttesti	373	6.921	11.01	373	6.693	11.79
local near_povrat_t = r(t)
local near_povrat_p = r(p)
gen near_povrat_t = `near_povrat_t'
gen near_povrat_p = `near_povrat_p'

* Fraction
ttesti	373	-1.910	9.156	373	-1.811	12.12
local near_frac_t = r(t)
local near_frac_p = r(p)
gen near_frac_t = `near_frac_t'
gen near_frac_p = `near_frac_p'

* Wage/sal
ttesti	373	-944.9	7129	373	-964.9	8923
local near_ws_t = r(t)
local near_ws_p = r(p)
gen near_ws_t = `near_ws_t'
gen near_ws_p = `near_ws_p'

* Employment
ttesti	373	-90.98	249.2	373	-90.43	278.5
local near_emp_t = r(t)
local near_emp_p = r(p)
gen near_emp_t = `near_emp_t'
gen near_emp_p = `near_emp_p'

collapse near*
outreg2 using "${tables}Table 5. Panel 6. Pre-treatment trends - PS Matched NENTCs - p-values.xls", replace sum(log) title("Table 5. Panel 6. Pre-treatment trends - PS Matched NENTCs - p-values")

	

		


********************************************************************************
* Table 8. Regression estimates of the effect of ENTCs on LMOs
********************************************************************************

****************************** 1. HSIS preferred *******************************
use entc_nearest_reg, clear

xtset ucounty

**** Unemployment - All
use entc_all_reg, clear

xtset ucounty
      
xtreg dd_unemprt_ncdb entc i.statecd, re
outreg2 using "${tables}Table 8. Panel 1. ENTC estimates.xls", replace title("Table 8. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes") ///
ctitle("Unemployment rate")

tab entc if e(sample)

**** Poverty - All

xtreg dd_povrat_ncdb entc i.statecd, re
outreg2 using "${tables}Table 8. Panel 1. ENTC estimates.xls", append title("Table 8. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes") ///
ctitle("Poverty")

**** Fraction - All
xtreg dd_frac_ncdb entc i.statecd, re
outreg2 using "${tables}Table 8. Panel 1. ENTC estimates.xls", append title("Table 8. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes") ///
ctitle("Fraction")

**** Average Wage and Salary Income - Contiguous
use entc_contiguous_reg, clear

xtset ucounty

xtreg ddd_avemer_ncdb, re
outreg2 using "${tables}Table 8. Panel 1. ENTC estimates.xls", append title("Table 8. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes") ///
ctitle("Average Wage and Salary Income")

**** Employment - All

use entc_all_reg, clear

xtreg dd_indemp_ncdb entc i.statecd, re
outreg2 using "${tables}Table 8. Panel 1. ENTC estimates.xls", append title("Table 8. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes") ///
ctitle("Unemployment rate")


***************************** 2. Busso and Kline *******************************

use entc_bk_reg, clear

* Number of counties for treatd tracts
codebook ucounty if entc_tr_hsis_ctrl_inter == 1

xtset ucounty
      
* Unemployment
xtreg dd_unemprt_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 8. Panel 2. ENTC estimates - Busso and Kline.xls", replace title("Table 8. Panel 2. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Unemployment rate")

* Number of ENTCs
tab entc_tr_hsis_ctrl_inter if e(sample)

* Poverty
xtreg dd_povrat_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 8. Panel 2. ENTC estimates - Busso and Kline.xls", append title("Table 8. Panel 2. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Poverty")

* Fraction
xtreg dd_frac_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 8. Panel 2. ENTC estimates - Busso and Kline.xls", append title("Table 8. Panel 2. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg dd_avemer_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 8. Panel 2. ENTC estimates - Busso and Kline.xls", append title("Table 8. Panel 2. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg dd_indemp_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Table 8. Panel 2. ENTC estimates - Busso and Kline.xls", append title("Table 8. Panel 2. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Employment")

tab entc_tr_hsis_ctrl_inter if e(sample)
codebook tract2000 if e(sample) & entc_tr_hsis_ctrl_inter == 0


***************************** 3. Propensity Score ******************************

use entc_all_reg, clear

* Number of counties for treated tracts
codebook ucounty if entc == 1

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 8. Panel 3. ENTC estimates - Propensity Score.xls", replace title("Table 8. Panel 3. ENTC estimates - Propensity Score") ///
ctitle("Unemployment Rate")

* Number of ENTCs
tab entc if e(sample)

* Poverty rate
teffects psmatch (dd_povrat_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 8. Panel 3. ENTC estimates - Propensity Score.xls", append title("Table 8. Panel 3. ENTC estimates - Propensity Score") ///
ctitle("Poverty Rate")

* Fraction with W/S income
teffects psmatch (dd_frac_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 8. Panel 3. ENTC estimates - Propensity Score.xls", append title("Table 8. Panel 3. ENTC estimates - Propensity Score") ///
ctitle("Fraction")

* Average WS income
teffects psmatch (dd_avemer_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 8. Panel 3. ENTC estimates - Propensity Score.xls", append title("Table 8. Panel 3. ENTC estimates - Propensity Score") ///
ctitle("Average WS Income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Table 8. Panel 3. ENTC estimates - Propensity Score.xls", append title("Table 8. Panel 3. ENTC estimates - Propensity Score") ///
ctitle("Employment")












































********************************************************************************
********************************************************************************
* Bootstrapped Table 8 estimates
********************************************************************************
********************************************************************************

********************************************************************************
* Create dataset containing nearest, contiguous, all, and PSM data
********************************************************************************

* Combine contiguous and nearest triple difference values into a single all dataset.

* Contiguous
use entc_contiguous_reg, clear
keep entcid ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb 

foreach i in ddd_unemprt_ ddd_povrat_ ddd_frac_ ddd_avemer_ ddd_indemp_ {
rename `i'ncdb `i'contig
}

save temp_entc_contig, replace

* Nearest
use entc_nearest_reg, clear

keep entcid ddd_unemprt_ncdb ddd_povrat_ncdb ddd_frac_ncdb ddd_avemer_ncdb ddd_indemp_ncdb 

foreach i in ddd_unemprt_ ddd_povrat_ ddd_frac_ ddd_avemer_ ddd_indemp_ {
rename `i'ncdb `i'nearest
}

save temp_entc_nearest, replace

* BK controls
use entc_bk_reg, clear

rename tract2000 entcid
keep entcid entc_tr_hsis_ctrl_inter
drop if entc_tr == .

save temp_entc_bk, replace


* Merge in HSIS's wide data into the clean all data
use entc_all_reg, clear

drop entcid
rename tractid entcid

merge 1:1 entcid using temp_entc_contig
drop _merge
merge 1:1 entcid using temp_entc_nearest
drop _merge
merge 1:1 entcid using temp_entc_bk
drop _merge

save table8_entc, replace

********************************************************************************
* Loop over all outcomes
********************************************************************************

global iteration 1000

* Loop over regressions, selecting a new bootstrapped sample each time. This is computationally intensive, but I can be sure of what is happening.

foreach j in unemprt povrat frac avemer indemp {

	*** Run the boostrapped samples and save betas and SEs
	
	foreach i of numlist 1/$iteration {

	* Import data
	use table8_entc, clear

	* Set seed
	set seed `i' // Change seed each time
	gen seed = `i' // generate indicator which which seed is used

	* Generate new bootstrapped sample
	bsample // Generates new bootstrapped sample. I don't want to iterate ove this, because I think each bootstrapped sample will be based on the last bootstrapped sample, and my data will lose variation. The other option would be to write a program for this and iterate over it.

	* 1. Run HSIS model with nearest controls, save betas and SEs
	qui xtreg ddd_`j'_near, re
	gen b_hsis_near_`j'_bs = _b[_cons]
	gen se_hsis_near_`j'_bs = _se[_cons]

	* Drop treated tracts that were not used in the HSIS estimation (due to missing data on the triple difference outcome)
	drop if entc == 1 & !e(sample) 

	* 2. Run HSIS model with contiguous controls, save betas and SEs. Run contiguous first, because most restrictive set of controls in terms of data availability.
	qui xtreg ddd_`j'_contig, re
	gen b_hsis_contig_`j'_bs = _b[_cons]
	gen se_hsis_contig_`j'_bs = _se[_cons]

	* 3. Run HSIS model with all controls, save betas
	qui xtreg dd_`j'_ncdb entc i.state
	gen b_hsis_all_`j'_bs = _b[entc]
	gen se_hsis_all_`j'_bs = _se[entc]

	* 4. Run Busso et al. model
	qui xtreg dd_`j'_ncdb entc_tr_hsis_ctrl_inter, re
	gen b_bk_`j'_bs = _b[entc_tr_hsis_ctrl_inter]
	gen se_bk_`j'_bs = _se[entc_tr_hsis_ctrl_inter]
	
	* 5. Run PSM model
	qui teffects psmatch (dd_`j'_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
	gen b_psm_`j'_bs = _b[r1vs0.entc]
	gen se_psm_`j'_bs = _se[r1vs0.entc]

	
	* Keep only the betas and SEs. These do not vary across observations, so it's really just collapsing repeated values to a single row
	collapse b_* se_* seed
	
	tempfile table8_entc_`j'`i'
	qui save `table8_entc_`j'`i'', replace // the estimates from each iteration are saved as a separate dta file. Each file varies by the outcome and the seed.
	}
}

* Combine all betas and SEs
foreach j in unemprt povrat frac avemer indemp {

* Append all the iterations from each bootstrap for a given outcome	
use `table8_entc_`j'1', clear
	foreach i of numlist 2/$iteration {
	qui append using `table8_entc_`j'`i''
	}

* Generate correlations between HSIS and PS estimates
	* Nearest and PS
	corr b_hsis_near_`j'_bs b_psm_`j'_bs
	gen corr_near_ps_`j' = r(rho)
	* Contiguous and PS
	corr b_hsis_contig_`j'_bs b_psm_`j'_bs
	gen corr_contig_ps_`j' = r(rho)
	* BK and PS
	corr b_bk_`j'_bs b_psm_`j'_bs
	gen corr_bk_ps_`j' = r(rho)
	* All and PS
	corr b_hsis_all_`j'_bs b_psm_`j'_bs
	gen corr_all_ps_`j' = r(rho)

collapse b_* se_* corr_*

gen id = 1 // for merging
	
qui save tab8_`j'_ests, replace

}


* Run models in Table 8, and combine these estimates with the bootstrapped correlation estimates above
use table8_entc, clear
xtset county

foreach j in unemprt povrat frac avemer indemp {

* Contiguous
qui xtreg ddd_`j'_contig, re
gen b_hsis_`j'_contig = _b[_cons]
gen se_hsis_`j'_contig = _se[_cons]

* Nearest
qui xtreg ddd_`j'_near, re
gen b_hsis_`j'_near = _b[_cons]
gen se_hsis_`j'_near = _se[_cons]

* All
qui xtreg dd_`j'_ncdb entc i.state
gen b_hsis_`j'_all = _b[entc]
gen se_hsis_`j'_all = _se[entc]

* BK
qui xtreg dd_`j'_ncdb entc_tr_hsis_ctrl_inter
gen b_bk_`j' = _b[entc_tr_hsis_ctrl_inter]
gen se_bk_`j' = _se[entc_tr_hsis_ctrl_inter]

* PS 
qui teffects psmatch (dd_`j'_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
gen b_psm_`j' = _b[r1vs0.entc]
gen se_psm_`j' = _se[r1vs0.entc]

}

* Collapse data to a single row -- each variable is a different estimate and standard error
collapse b_* se_*
gen id = 1 // Id for merging

* Merge in the bootstrapped correlations performed above.
foreach j in unemprt povrat frac avemer indemp {
merge 1:1 id using tab8_`j'_ests
drop _merge
}

save table8_corrs, replace

*** Calculate standard errors and t-statistics for Table 8
use table8_corrs, clear

foreach i in unemprt povrat frac avemer indemp {

* For HSIS
foreach j in near contig all {
*** Calculate estimated covariance from bootstraps, standard errors, and t-statistics for Table 8. Note that all the correlation variables in these data are bootstrapped. The standard errors are from non-bootstrapped models and equal the standard errors in the paper.

* Generate covariances
gen cov_`i'_`j' = corr_`j'_ps_`i'*se_hsis_`i'_`j'*se_psm_`i'
* Generate standard error of differences
gen se_dif_`i'_`j' = sqrt(se_hsis_`i'_`j'^2 + se_psm_`i'^2 - 2*cov_`i'_`j')
* Generate t-statistics
gen t_dif_`i'_`j' = (b_psm_`i' - b_hsis_`i'_`j')/se_dif_`i'_`j'
}

** For BK
* Generate covariances
gen cov_`i'_bk = corr_bk_ps_`i'*se_bk_`i'_bs*se_psm_`i'
* Generate standard error of differences
gen se_dif_`i'_bk = sqrt(se_bk_`i'_bs^2 + se_psm_`i'_bs^2 - 2*cov_`i'_bk)
* Generate t-statistics
gen t_dif_`i'_bk = (b_psm_`i' - b_bk_`i')/se_dif_`i'_bk

}

save table8_final, replace

* Generate Table 8
use table8_final, clear

order b_hsis_unemprt_all se_hsis_unemprt_all b_psm_unemprt se_psm_unemprt se_dif_unemprt_all t_dif_unemprt_all ///
   b_hsis_povrat_all se_hsis_povrat_all b_psm_povrat se_psm_povrat se_dif_povrat_all t_dif_povrat_all ///
   b_hsis_frac_all se_hsis_frac_all b_psm_frac se_psm_frac se_dif_frac_all t_dif_frac_all ///
   b_hsis_avemer_contig se_hsis_avemer_all b_psm_avemer se_psm_avemer se_dif_avemer_contig t_dif_avemer_contig ///
   b_hsis_indemp_all se_hsis_indemp_all b_psm_indemp se_psm_indemp se_dif_indemp_all t_dif_indemp_all

outreg2 using "${tables}Table 8. ENTC BSed comparisons - HSIS.xls", replace keep(b_hsis_unemprt_all se_hsis_unemprt_all b_psm_unemprt se_psm_unemprt se_dif_unemprt_all t_dif_unemprt_all ///
   b_hsis_povrat_all se_hsis_povrat_all b_psm_povrat se_psm_povrat se_dif_povrat_all t_dif_povrat_all ///
   b_hsis_frac_all se_hsis_frac_all b_psm_frac se_psm_frac se_dif_frac_all t_dif_frac_all ///
   b_hsis_avemer_contig se_hsis_avemer_all b_psm_avemer se_psm_avemer se_dif_avemer_contig t_dif_avemer_contig ///
   b_hsis_indemp_all se_hsis_indemp_all b_psm_indemp se_psm_indemp se_dif_indemp_all t_dif_indemp_all) sum(log)
    
order b_bk_unemprt se_bk_unemprt b_psm_unemprt se_psm_unemprt se_dif_unemprt_bk t_dif_unemprt_bk ///
   b_bk_povrat se_bk_povrat b_psm_povrat se_psm_povrat se_dif_povrat_bk t_dif_povrat_bk ///
   b_bk_frac se_bk_frac b_psm_frac se_psm_frac se_dif_frac_bk t_dif_frac_bk ///
   b_bk_avemer se_bk_avemer b_psm_avemer se_psm_avemer se_dif_avemer_bk t_dif_avemer_bk ///
   b_bk_indemp se_bk_indemp b_psm_indemp se_psm_indemp se_dif_indemp_bk t_dif_indemp_bk
	
outreg2 using "${tables}Table 8. ENTC BSed comparisons - BK.xls", replace keep(b_bk_unemprt se_bk_unemprt b_psm_unemprt se_psm_unemprt se_dif_unemprt_bk t_dif_unemprt_bk ///
   b_bk_povrat se_bk_povrat b_psm_povrat se_psm_povrat se_dif_povrat_bk t_dif_povrat_bk ///
   b_bk_frac se_bk_frac b_psm_frac se_psm_frac se_dif_frac_bk t_dif_frac_bk ///
   b_bk_avemer se_bk_avemer b_psm_avemer se_psm_avemer se_dif_avemer_bk t_dif_avemer_bk ///
   b_bk_indemp se_bk_indemp b_psm_indemp se_psm_indemp se_dif_indemp_bk t_dif_indemp_bk) sum(log)
    

	
	
	
	
	
	
	
	
	
	
	
	
	
	


	

	
	
	
	
	
	
	
	
	
	
	
	
	


	

	
	
	
	
	
	
	
	
	
	
	
	
	


	
	
	
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
* 							ONLINE APPENDIX TABLES
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************















********************************************************************************
********************************************************************************
* Appendix Table A1. ENTZ - Bootstrapped estimates and differences for all estimators
********************************************************************************
********************************************************************************

********************************* 1. Nearest ***********************************
use entz_nearest_reg, clear

xtset ucounty

* Unemployment
xtreg ddd_unemprt_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 1. ENTZ estimates - Nearest.xls", replace title("Appendix Table A1. Panel1. Estimates of the effect of ENTZs on local labor market outcomes - Nearest") ///
ctitle("Unemployment rate")

* Poverty
xtreg ddd_povrat_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 1. ENTZ estimates - Nearest.xls", append title("Appendix Table A1. Panel1. Estimates of the effect of ENTZs on local labor market outcomes - Nearest") ///
ctitle("Poverty")

* Fraction
xtreg ddd_frac_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 1. ENTZ estimates - Nearest.xls", append title("Appendix Table A1. Panel1. Estimates of the effect of ENTZs on local labor market outcomes - Nearest") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg ddd_avemer_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 1. ENTZ estimates - Nearest.xls", append title("Appendix Table A1. Panel1. Estimates of the effect of ENTZs on local labor market outcomes - Nearest") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg ddd_indemp_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 1. ENTZ estimates - Nearest.xls", append title("Appendix Table A1. Panel1. Estimates of the effect of ENTZs on local labor market outcomes - Nearest") ///
ctitle("Employment")

******************************** 2. Contiguous *********************************
use entz_contiguous_reg, clear

xtset ucounty

* Unemployment
xtreg ddd_unemprt_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 2. ENTZ estimates - Contiguous.xls", replace title("Appendix Table A1. Panel 2. Estimates of the effect of ENTZs on local labor market outcomes - Contiguous") ///
ctitle("Unemployment rate")

* Poverty
xtreg ddd_povrat_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 2. ENTZ estimates - Contiguous.xls", append title("Appendix Table A1. Panel 2. Estimates of the effect of ENTZs on local labor market outcomes - Contiguous") ///
ctitle("Poverty")

* Fraction
xtreg ddd_frac_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 2. ENTZ estimates - Contiguous.xls", append title("Appendix Table A1. Panel 2. Estimates of the effect of ENTZs on local labor market outcomes - Contiguous") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg ddd_avemer_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 2. ENTZ estimates - Contiguous.xls", append title("Appendix Table A1. Panel 2. Estimates of the effect of ENTZs on local labor market outcomes - Contiguous") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg ddd_indemp_ncdb, re
outreg2 using "${tables}Appendix Table A1. Panel 2. ENTZ estimates - Contiguous.xls", append title("Appendix Table A1. Panel 2. Estimates of the effect of ENTZs on local labor market outcomes - Contiguous") ///
ctitle("Employment")


************************************ 3. All ************************************
use entz_all_reg, clear
tab entz
xtset county
      
* Unemployment
xtreg dd_unemprt_ncdb entz CA CO FL HI IL MA NE NY OH OR RI VA, re
outreg2 using "${tables}Appendix Table A1. Panel 3. ENTZ estimates - All.xls", replace title("Appendix Table A1. Panel 3. Estimates of the effect of ENTZs on local labor market outcomes - All") ///
ctitle("Unemployment rate")

* Poverty
xtreg dd_povrat_ncdb entz CA CO FL HI IL MA NE NY OH OR RI VA, re
outreg2 using "${tables}Appendix Table A1. Panel 3. ENTZ estimates - All.xls", append title("Appendix Table A1. Panel 3. Estimates of the effect of ENTZs on local labor market outcomes - All") ///
ctitle("Poverty")

* Fraction
xtreg dd_frac_ncdb entz CA CO FL HI IL MA NE NY OH OR RI VA, re
outreg2 using "${tables}Appendix Table A1. Panel 3. ENTZ estimates - All.xls", append title("Appendix Table A1. Panel 3. Estimates of the effect of ENTZs on local labor market outcomes - All") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg dd_avemer_ncdb entz CA CO FL HI IL MA NE NY OH OR RI VA, re
outreg2 using "${tables}Appendix Table A1. Panel 3. ENTZ estimates - All.xls", append title("Appendix Table A1. Panel 3. Estimates of the effect of ENTZs on local labor market outcomes - All") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg dd_indemp_ncdb entz CA CO FL HI IL MA NE NY OH OR RI VA, re
outreg2 using "${tables}Appendix Table A1. Panel 3. ENTZ estimates - All.xls", append title("Appendix Table A1. Panel 3. Estimates of the effect of ENTZs on local labor market outcomes - All") ///
ctitle("Employment")



****************************** 4. Propensity score *****************************

use entz_all_reg, clear

* Number of counties for treated tracts
codebook ucounty if entz == 1

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score.xls", replace title("Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score") ///
ctitle("Unemployment Rate")

* Poverty rate
teffects psmatch (dd_povrat_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score.xls", append title("Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score") ///
ctitle("Poverty Rate")

* Fraction with W/S income
teffects psmatch (dd_frac_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score.xls", append title("Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score") ///
ctitle("Fraction")

* Average WS income
teffects psmatch (dd_avemer_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score.xls", append title("Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score") ///
ctitle("Average WS Income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entz unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score.xls", append title("Appendix Table A1. Panel 4. ENTZ estimates - Propensity Score") ///
ctitle("Employment")




********************************************************************************
********************************************************************************
* Appendix Table A2. EMPZ - Bootstrapped estimates and differences for all estimators
********************************************************************************
********************************************************************************


********************************* 1. Nearest ***********************************
use empz_nearest_reg, clear

xtset ucounty

* Unemployment
xtreg ddd_unemprt_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 1. EMPZ estimates - Nearest.xls", replace title("Appendix Table A2. Panel 1. Estimates of the effect of empzs on local labor market outcomes - Nearest") ///
ctitle("Unemployment rate")

* Poverty
xtreg ddd_povrat_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 1. EMPZ estimates - Nearest.xls", append title("Appendix Table A2. Panel 1. Estimates of the effect of empzs on local labor market outcomes - Nearest") ///
ctitle("Poverty")

* Fraction
xtreg ddd_frac_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 1. EMPZ estimates - Nearest.xls", append title("Appendix Table A2. Panel 1. Estimates of the effect of empzs on local labor market outcomes - Nearest") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg ddd_avemer_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 1. EMPZ estimates - Nearest.xls", append title("Appendix Table A2. Panel 1. Estimates of the effect of empzs on local labor market outcomes - Nearest") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg ddd_indemp_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 1. EMPZ estimates - Nearest.xls", append title("Appendix Table A2. Panel 1. Estimates of the effect of empzs on local labor market outcomes - Nearest") ///
ctitle("Employment")

******************************** 2. Contiguous *********************************
use empz_contiguous_reg, clear

xtset ucounty

* Unemployment
xtreg ddd_unemprt_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 2. EMPZ estimates - Contiguous.xls", replace title("Appendix Table A2. Panel 2. Estimates of the effect of empzs on local labor market outcomes - Contiguous") ///
ctitle("Unemployment rate")

* Poverty
xtreg ddd_povrat_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 2. EMPZ estimates - Contiguous.xls", append title("Appendix Table A2. Panel 2. Estimates of the effect of empzs on local labor market outcomes - Contiguous") ///
ctitle("Poverty")

* Fraction
xtreg ddd_frac_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 2. EMPZ estimates - Contiguous.xls", append title("Appendix Table A2. Panel 2. Estimates of the effect of empzs on local labor market outcomes - Contiguous") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg ddd_avemer_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 2. EMPZ estimates - Contiguous.xls", append title("Appendix Table A2. Panel 2. Estimates of the effect of empzs on local labor market outcomes - Contiguous") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg ddd_indemp_ncdb, re
outreg2 using "${tables}Appendix Table A2. Panel 2. EMPZ estimates - Contiguous.xls", append title("Appendix Table A2. Panel 2. Estimates of the effect of empzs on local labor market outcomes - Contiguous") ///
ctitle("Employment")


************************************ 3. All ************************************
use empz_all_reg, clear

xtset ucounty
      
* Unemployment
xtreg dd_unemprt_ncdb empz i.statecd, re
outreg2 using "${tables}Appendix Table A2. Panel 3. EMPZ estimates - All.xls", replace title("Appendix Table A2. Panel 3. Estimates of the effect of empzs on local labor market outcomes - All") ///
ctitle("Unemployment rate")

tab empz if e(sample)

* Poverty
xtreg dd_povrat_ncdb empz i.statecd, re
outreg2 using "${tables}Appendix Table A2. Panel 3. EMPZ estimates - All.xls", append title("Appendix Table A2. Panel 3. Estimates of the effect of empzs on local labor market outcomes - All") ///
ctitle("Poverty")

* Fraction
xtreg dd_frac_ncdb empz i.statecd, re
outreg2 using "${tables}Appendix Table A2. Panel 3. EMPZ estimates - All.xls", append title("Appendix Table A2. Panel 3. Estimates of the effect of empzs on local labor market outcomes - All") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg dd_avemer_ncdb empz i.statecd, re
outreg2 using "${tables}Appendix Table A2. Panel 3. EMPZ estimates - All.xls", append title("Appendix Table A2. Panel 3. Estimates of the effect of empzs on local labor market outcomes - All") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg dd_indemp_ncdb empz i.statecd, re
outreg2 using "${tables}Appendix Table A2. Panel 3. EMPZ estimates - All.xls", append title("Appendix Table A2. Panel 3. Estimates of the effect of empzs on local labor market outcomes - All") ///
ctitle("Employment")


***************************** 4. Busso and Kline *******************************

use empz_bk_reg, clear

* Number of counties for treatd tracts
codebook ucounty if empz_tr_hsis_ctrl_inter == 1

xtset ucounty
      
* Unemployment
xtreg dd_unemprt_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A2. Panel 4. EMPZ estimates - Busso and Kline.xls", replace title("Appendix Table A2. Panel 4. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Unemployment rate")

tab empz_tr_hsis_ctrl_inter if e(sample)

* Poverty
xtreg dd_povrat_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A2. Panel 4. EMPZ estimates - Busso and Kline.xls", append title("Appendix Table A2. Panel 4. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Poverty")

* Fraction
xtreg dd_frac_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A2. Panel 4. EMPZ estimates - Busso and Kline.xls", append title("Appendix Table A2. Panel 4. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg dd_avemer_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A2. Panel 4. EMPZ estimates - Busso and Kline.xls", append title("Appendix Table A2. Panel 4. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg dd_indemp_ncdb empz_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A2. Panel 4. EMPZ estimates - Busso and Kline.xls", append title("Appendix Table A2. Panel 4. Estimates of the effect of EMPZ on local labor market outcomes - Busso and Kline") ///
ctitle("Employment")


********************* 5. Propensity Score ********************

use empz_all_reg, clear

* Number of counties for treated tracts
codebook ucounty if empz == 1

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score.xls", replace title("Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score") ///
ctitle("Unemployment Rate")
codebook ucounty

tab empz if e(sample)

* Poverty rate
teffects psmatch (dd_povrat_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score.xls", append title("Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score") ///
ctitle("Poverty Rate")

* Fraction with W/S income
teffects psmatch (dd_frac_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score.xls", append title("Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score") ///
ctitle("Fraction")

* Average WS income
teffects psmatch (dd_avemer_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score.xls", append title("Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score") ///
ctitle("Average WS Income")

* Employment
teffects psmatch (dd_indemp_ncdb) (empz d_unemprt_90_80 d_povrat_90_80 d_avemer_90_80 d_frac_90_80 d_indemp_90_80 unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score.xls", append title("Appendix Table A2. Panel 5. EMPZ estimates - Propensity Score") ///
ctitle("Employment")

* Boostrapped differences
use table7_final, clear

********************************************************************************
********************************************************************************
* Appendix Table A3. Regression estimates of the effect of ENTCs on LMOs
********************************************************************************
********************************************************************************

********************************* 1. Nearest ***********************************
use entc_nearest_reg, clear

xtset ucounty

* Unemployment
xtreg ddd_unemprt_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 1. ENTC estimates - Nearest.xls", replace title("Appendix Table A3. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes - Nearest") ///
ctitle("Unemployment rate")

* Poverty
xtreg ddd_povrat_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 1. ENTC estimates - Nearest.xls", append title("Appendix Table A3. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes - Nearest") ///
ctitle("Poverty")

* Fraction
xtreg ddd_frac_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 1. ENTC estimates - Nearest.xls", append title("Appendix Table A3. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes - Nearest") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg ddd_avemer_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 1. ENTC estimates - Nearest.xls", append title("Appendix Table A3. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes - Nearest") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg ddd_indemp_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 1. ENTC estimates - Nearest.xls", append title("Appendix Table A3. Panel 1. Estimates of the effect of ENTCs on local labor market outcomes - Nearest") ///
ctitle("Employment")

******************************** 2. Contiguous *********************************
use entc_contiguous_reg, clear

xtset ucounty

* Unemployment
xtreg ddd_unemprt_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 2. ENTC estimates - Contiguous.xls", replace title("Appendix Table A3. Panel 2. Estimates of the effect of ENTCs on local labor market outcomes - Contiguous") ///
ctitle("Unemployment rate")

* Poverty
xtreg ddd_povrat_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 2. ENTC estimates - Contiguous.xls", append title("Appendix Table A3. Panel 2. Estimates of the effect of ENTCs on local labor market outcomes - Contiguous") ///
ctitle("Poverty")

* Fraction
xtreg ddd_frac_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 2. ENTC estimates - Contiguous.xls", append title("Appendix Table A3. Panel 2. Estimates of the effect of ENTCs on local labor market outcomes - Contiguous") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg ddd_avemer_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 2. ENTC estimates - Contiguous.xls", append title("Appendix Table A3. Panel 2. Estimates of the effect of ENTCs on local labor market outcomes - Contiguous") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg ddd_indemp_ncdb, re
outreg2 using "${tables}Appendix Table A3. Panel 2. ENTC estimates - Contiguous.xls", append title("Appendix Table A3. Panel 2. Estimates of the effect of ENTCs on local labor market outcomes - Contiguous") ///
ctitle("Employment")


************************************ 3. All ************************************
use entc_all_reg, clear

xtset ucounty
      
* Unemployment
xtreg dd_unemprt_ncdb entc i.statecd, re
outreg2 using "${tables}Appendix Table A3. Panel 3. ENTC estimates - All.xls", replace title("Appendix Table A3. Panel 3. Estimates of the effect of ENTCs on local labor market outcomes - All") ///
ctitle("Unemployment rate")

* Number of ENTCs
tab entc if e(sample)

* Poverty
xtreg dd_povrat_ncdb entc i.statecd, re
outreg2 using "${tables}Appendix Table A3. Panel 3. ENTC estimates - All.xls", append title("Appendix Table A3. Panel 3. Estimates of the effect of ENTCs on local labor market outcomes - All") ///
ctitle("Poverty")

* Fraction
xtreg dd_frac_ncdb entc i.statecd, re
outreg2 using "${tables}Appendix Table A3. Panel 3. ENTC estimates - All.xls", append title("Appendix Table A3. Panel 3. Estimates of the effect of ENTCs on local labor market outcomes - All") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg dd_avemer_ncdb entc i.statecd, re
outreg2 using "${tables}Appendix Table A3. Panel 3. ENTC estimates - All.xls", append title("Appendix Table A3. Panel 3. Estimates of the effect of ENTCs on local labor market outcomes - All") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg dd_indemp_ncdb entc i.statecd, re
outreg2 using "${tables}Appendix Table A3. Panel 3. ENTC estimates - All.xls", append title("Appendix Table A3. Panel 3. Estimates of the effect of ENTCs on local labor market outcomes - All") ///
ctitle("Employment")


***************************** 4. Busso and Kline *******************************

use entc_bk_reg, clear

* Number of counties for treatd tracts
codebook ucounty if entc_tr_hsis_ctrl_inter == 1

xtset ucounty

* Tabulate states and ENTCs
tabout fips entc_tr_hsis_ctrl_inter using "${tables}Tabulation of states and ENTCs for BK.xls", replace f(0c)
      
* Unemployment
xtreg dd_unemprt_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A3. Panel 4. ENTC estimates - Busso and Kline.xls", replace title("Appendix Table A3. Panel 4. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Unemployment rate")

* Number of ENTCs
tab entc_tr_hsis_ctrl_inter if e(sample)

* Poverty
xtreg dd_povrat_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A3. Panel 4. ENTC estimates - Busso and Kline.xls", append title("Appendix Table A3. Panel 4. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Poverty")

* Fraction
xtreg dd_frac_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A3. Panel 4. ENTC estimates - Busso and Kline.xls", append title("Appendix Table A3. Panel 4. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Fraction")

* Average Wage and Salary Income
xtreg dd_avemer_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A3. Panel 4. ENTC estimates - Busso and Kline.xls", append title("Appendix Table A3. Panel 4. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Average Wage and Salary Income")

* Employment
xtreg dd_indemp_ncdb entc_tr_hsis_ctrl_inter, re
outreg2 using "${tables}Appendix Table A3. Panel 4. ENTC estimates - Busso and Kline.xls", append title("Appendix Table A3. Panel 4. Estimates of the effect of entc on local labor market outcomes - Busso and Kline") ///
ctitle("Employment")

tab entc_tr_hsis_ctrl_inter if e(sample)
codebook tract2000 if e(sample) & entc_tr_hsis_ctrl_inter == 0


***************************** 5. Propensity Score ******************************

use entc_all_reg, clear

* Number of counties for treated tracts
codebook ucounty if entc == 1

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A3. Panel 5. ENTC estimates - Propensity Score.xls", replace title("Appendix Table A3. Panel 5. ENTC estimates - Propensity Score") ///
ctitle("Unemployment Rate")

* Number of ENTCs
tab entc if e(sample)

* Poverty rate
teffects psmatch (dd_povrat_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A3. Panel 5. ENTC estimates - Propensity Score.xls", append title("Appendix Table A3. Panel 5. ENTC estimates - Propensity Score") ///
ctitle("Poverty Rate")

* Fraction with W/S income
teffects psmatch (dd_frac_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A3. Panel 5. ENTC estimates - Propensity Score.xls", append title("Appendix Table A3. Panel 5. ENTC estimates - Propensity Score") ///
ctitle("Fraction")

* Average WS income
teffects psmatch (dd_avemer_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A3. Panel 5. ENTC estimates - Propensity Score.xls", append title("Appendix Table A3. Panel 5. ENTC estimates - Propensity Score") ///
ctitle("Average WS Income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entc unemprt8 unemprt9 povrat9 povrat8 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A3. Panel 5. ENTC estimates - Propensity Score.xls", append title("Appendix Table A3. Panel 5. ENTC estimates - Propensity Score") ///
ctitle("Employment")




















********************************************************************************
********************************************************************************
* Appendix Table A4. Panels 1 and 2. Robustness of ENTZ PSM triple difference estimates
********************************************************************************
********************************************************************************

********************************************************************************
* Create data for tables
********************************************************************************

* Import all data
use entz_all_reg, clear

* Identify nearest control tracts using flags.
preserve
use "hsis_NCDB_nearest.dta", clear
keep nentzid
gen near_ctrl = 1
rename nentzid entzid
duplicates drop

tempfile near_ctrl
save `near_ctrl', replace
restore

* Identify contiguous control tracts using flags.
preserve
use "hsis_NCDB_contiguous.dta", clear
keep nentz*
rename nentzid nentz0id
foreach i of numlist 0/11 {
rename nentz`i'id nentz`i'
}

* Reshape wide to long
gen n = _n
reshape long nentz, i(n) j(id)
keep nentz
drop if missing(nentz)
duplicates drop
rename nentz entzid
gen contig_ctrl = 1

tempfile contig_ctrl
save `contig_ctrl', replace
restore

merge 1:1 entzid using `near_ctrl'
drop if _merge == 2
drop _merge
merge 1:1 entzid using `contig_ctrl'
drop if _merge == 2
drop _merge

tab entz contig_ctrl

* Nearest controls
gen entz_near = entz
replace entz_near = . if near_ctrl == 1 & entz_near == 0
tab entz_near entz,m // We drop 522 controls

* Contigous controls
gen entz_contig = entz
replace entz_contig = . if contig_ctrl == 1 & entz_contig == 0

tab entz_contig entz,m // We drop 1,243 contiguous controls

save app_tab1, replace


********************************************************************************
* Run estimates
********************************************************************************

* Use data
use app_tab1, clear

						* Panel 1. No nearest controls included

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet gen(match)
outreg2 using "${tables}Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls.xls", replace title("Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (entz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls.xls", append title("Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (entz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls.xls", append title("Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (entz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls.xls", append title("Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls.xls", append title("Appendix Table A4. Panel 1. ENTZ PS estimates - No nearest controls") ///
ctitle("Employment")

* Number of ENTZ and NENTZ observations
tab entz_near if e(sample)
* Number of unique controls
codebook match if e(sample) & entz_near == 0
codebook entzid if e(sample) & entz_near==0
codebook county if e(sample)
drop match

			* Panel 2. No contiguous controls included
			
* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet gen(match)
outreg2 using "${tables}Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls.xls", replace title("Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (entz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls.xls", append title("Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (entz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls.xls", append title("Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (entz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls.xls", append title("Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls.xls", append title("Appendix Table A4. Panel 2. ENTZ PS estimates - No contiguous controls") ///
ctitle("Employment")			


* Number of ENTZ and NENTZ observations
tab entz_contig if e(sample)
* Number of unique controls
codebook match if e(sample) & entz_contig == 0
codebook entzid if e(sample) & entz_contig==0
codebook county if e(sample)
drop match


********************************************************************************
********************************************************************************
* Appendix Table A4. Panel 3. Robustness of ENTZ PSM triple difference estimates
********************************************************************************
********************************************************************************

* Import data
use entz_all_reg, clear

logit entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9

predict ps
egen sd_ps = sd(ps)
gen caliper = 0.2 * sd_ps // https://onlinelibrary.wiley.com/doi/full/10.1002/pst.433 
// and 
// https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3144483/


* Unemployment
* Run with caliper to identify restricted sample
capture noi teffects psmatch (dd_unemprt_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet caliper($caliper) osample(drop)

* Run estimates again without setting the caliper (the sample is already restricted)
teffects psmatch (dd_unemprt_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit)  if drop == 0, atet
tab entz if e(sample)
outreg2 using "${tables}Appendix Table A4. Panel 3. ENTZ PS estimates with caliper.xls", replace title("Appendix Table A4. Panel 3. ENTZ PS estimates with caliper") ///
ctitle("Unemployment rate")

* Poverty
capture noi teffects psmatch (dd_povrat_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A4. Panel 3. ENTZ PS estimates with caliper.xls", append title("Appendix Table A4. Panel 3. ENTZ PS estimates with caliper") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A4. Panel 3. ENTZ PS estimates with caliper.xls", append title("Appendix Table A4. Panel 3. ENTZ PS estimates with caliper") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A4. Panel 3. ENTZ PS estimates with caliper.xls", append title("Appendix Table A4. Panel 3. ENTZ PS estimates with caliper") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet gen(match)
outreg2 using "${tables}Appendix Table A4. Panel 3. ENTZ PS estimates with caliper.xls", append title("Appendix Table A4. Panel 3. ENTZ PS estimates with caliper") ///
ctitle("Employment")

* Number of ENTZ and NENTZ observations
tab entz if e(sample)
* Number of unique controls
codebook match if e(sample) & entz == 0
codebook entzid if e(sample) & entz==0
codebook county if e(sample)
drop match


********************************************************************************
********************************************************************************
* Appendix Table A4. Panel 4. Robustness of ENTZ PSM triple difference estimates
********************************************************************************
********************************************************************************

* Import data
use entz_all_reg, clear

* Unemployment
teffects ipw (dd_unemprt_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet 
outreg2 using "${tables}Appendix Table A4. Panel 4. ENTZ IPW estimates.xls", replace title("Appendix Table A4. Panel 4. ENTZ IPW estimates") ///
ctitle("Unemployment rate")

* Poverty
teffects ipw (dd_povrat_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 4. ENTZ IPW estimates.xls", append title("Appendix Table A4. Panel 4. ENTZ IPW estimates") ///
ctitle("Poverty rate")

* Average W/S income
// teffects ipw (dd_avemer_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet // NOT CONCAVE

* Run step by step
* 1. Run probit
probit entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9
* 2. Obtain predicted probabilities
predict ps if e(sample)
* 3. Define IPWs
gen ipw = 1 if entz == 1
replace ipw = ps/(1-ps) if entz == 0
* Run regressions -- these regressions produce the same estimates that the teffects ipw command does (above) however, the standard errors are not the same. This is because (according to Stata documentation -- https://www.stata.com/manuals/teteffectsipw.pdf) the teffects ipw command adjusts the standard errors to account for the second stage using estimated values of the propensity score from the first stage.
reg dd_unemprt_ncdb entz [pw = ipw]
reg dd_povrat_ncdb entz [pw = ipw]
reg dd_avemer_ncdb entz [pw = ipw]
outreg2 using "${tables}Appendix Table A4. Panel 4. ENTZ IPW estimates.xls", append title("Appendix Table A4. Panel 4. ENTZ IPW estimates") ///
ctitle("Aveage W/S income")

* Fraction
teffects ipw (dd_frac_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 4. ENTZ IPW estimates.xls", append title("Appendix Table A4. Panel 4. ENTZ IPW estimates") ///
ctitle("Fraction with W/S income")

* Employment
teffects ipw (dd_indemp_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A4. Panel 4. ENTZ IPW estimates.xls", append title("Appendix Table A4. Panel 4. ENTZ IPW estimates") ///
ctitle("Employment")



********************************************************************************
********************************************************************************
* Appendix Table A4. Panel 5. Robustness of ENTZ PSM triple difference estimates - using additional matched tracts
********************************************************************************
********************************************************************************

* Import data
use entz_all_reg, clear
			
* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors.xls", replace title("Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors.xls", append title("Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors.xls", append title("Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors.xls", append title("Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2) gen(match)
outreg2 using "${tables}Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors.xls", append title("Appendix Table A4. Panel 5. ENTZ PS estimates - Two nearest neighbors") ///
ctitle("Employment")			


* Counties
codebook ucounty if e(sample)

* Number of ENTZ and NENTZ observations
tab entz if e(sample)
* Number of unique controls
* Keep match1
preserve
keep if entz == 1
keep match1
tempfile match1
save `match1', replace
restore

* Append to match2 and determine number of unique matches
keep if entz == 1
keep match2
rename match2 match1
append using `match1'
codebook match1


********************************************************************************
********************************************************************************
* Appendix Table A5. Panels 1 and 2. Robustness of EMPZ PSM triple difference estimates
********************************************************************************
********************************************************************************

********************************************************************************
* Create data for tables
********************************************************************************

* Only need to do this for the PS models. Table will have two rows: excluding nearest and excluding contiguous tracts.

* Import all data
use empz_all_reg, clear
drop empzid
rename tractid empzid

* Identify nearest control tracts using flags.
preserve
use "hsis_NCDB_nearest_empz.dta", clear
keep nempzid
gen near_ctrl = 1
rename nempzid empzid
duplicates drop

tempfile near_ctrl
save `near_ctrl', replace
restore

* Identify contiguous control tracts using flags.
preserve
use "hsis_NCDB_contiguous_empz.dta", clear
keep nempz*
rename nempzid nempz0id
foreach i of numlist 0/11 {
rename nempz`i'id nempz`i'
}

* Reshape wide to long
gen n = _n
reshape long nempz, i(n) j(id)
keep nempz
drop if missing(nempz)
duplicates drop
rename nempz empzid
gen contig_ctrl = 1

tempfile contig_ctrl
save `contig_ctrl', replace
restore

merge 1:1 empzid using `near_ctrl'
drop if _merge == 2
drop _merge
merge 1:1 empzid using `contig_ctrl'
drop if _merge == 2
drop _merge

tab empz contig_ctrl

* Nearest controls
gen empz_near = empz
replace empz_near = . if near_ctrl == 1 & empz_near == 0
tab empz_near empz,m // We drop 156 controls

* Contigous controls
gen empz_contig = empz
replace empz_contig = . if contig_ctrl == 1 & empz_contig == 0

tab empz_contig empz,m // We drop 335 contiguous controls

save app_tab2, replace


********************************************************************************
* Run estimates
********************************************************************************

* Use data
use app_tab2, clear

						* Panel 1. No nearest controls included

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (empz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet gen(match)
outreg2 using "${tables}Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls.xls", replace title("Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (empz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls.xls", append title("Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (empz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls.xls", append title("Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (empz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls.xls", append title("Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (empz_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls.xls", append title("Appendix Table A5. Panel 1. EMPZ PS estimates - No nearest controls") ///
ctitle("Employment")

tab empz_near if e(sample) // Number of treated and controls
codebook match if e(sample) & empz_near==0 // Number of unique matched control tracts
codebook county if e(sample) // Number of counties
drop match
			* Panel 2. No contiguous controls included
			
* Unemployment
teffects psmatch (dd_unemprt_ncdb) (empz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet gen(match)
outreg2 using "${tables}Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls.xls", replace title("Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (empz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls.xls", append title("Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (empz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls.xls", append title("Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (empz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls.xls", append title("Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (empz_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls.xls", append title("Appendix Table A5. Panel 2. EMPZ PS estimates - No contiguous controls") ///
ctitle("Employment")			


tab empz_contig if e(sample) // Number of treated and controls
codebook match if e(sample) & empz_contig==0 // Number of unique matched control tracts
codebook county if e(sample) // Number of counties
drop match



********************************************************************************
********************************************************************************
* Appendix Table A5. Panel 3. Robustness of EMPZ PSM triple difference estimates
********************************************************************************
********************************************************************************

* Import data
use empz_all_reg, clear

logit empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9

predict ps
egen sd_ps = sd(ps)
gen caliper = 0.2 * sd_ps // https://onlinelibrary.wiley.com/doi/full/10.1002/pst.433 
// and 
// https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3144483/


* Unemployment
* Run with caliper to identify restricted sample
capture noi teffects psmatch (dd_unemprt_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet caliper($caliper) osample(drop)

* Run estimates again without setting the caliper (the sample is already restricted)
teffects psmatch (dd_unemprt_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit)  if drop == 0, atet gen(match)
tab empz if e(sample)
outreg2 using "${tables}Appendix Table A5. Panel 3. EMPZ PS estimates with caliper.xls", replace title("Appendix Table A5. Panel 3. EMPZ PS estimates with caliper") ///
ctitle("Unemployment rate")

* Poverty
capture noi teffects psmatch (dd_povrat_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A5. Panel 3. EMPZ PS estimates with caliper.xls", append title("Appendix Table A5. Panel 3. EMPZ PS estimates with caliper") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A5. Panel 3. EMPZ PS estimates with caliper.xls", append title("Appendix Table A5. Panel 3. EMPZ PS estimates with caliper") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A5. Panel 3. EMPZ PS estimates with caliper.xls", append title("Appendix Table A5. Panel 3. EMPZ PS estimates with caliper") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A5. Panel 3. EMPZ PS estimates with caliper.xls", append title("Appendix Table A5. Panel 3. EMPZ PS estimates with caliper") ///
ctitle("Employment")

* Number of empz and Nempz observations
tab empz if e(sample)
* Number of unique controls
codebook match if e(sample) & empz == 0
codebook empzid if e(sample) & empz==0
codebook county if e(sample)
drop match


********************************************************************************
********************************************************************************
* Appendix Table A5. Panel 4. Robustness of EMPZ PSM triple difference estimates
********************************************************************************
********************************************************************************

* Import data
use empz_all_reg, clear

* Unemployment
teffects ipw (dd_unemprt_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 4. EMPZ IPW estimates.xls", replace title("Appendix Table A5. Panel 4. EMPZ IPW estimates") ///
ctitle("Unemployment rate")

* Poverty
teffects ipw (dd_povrat_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 4. EMPZ IPW estimates.xls", append title("Appendix Table A5. Panel 4. EMPZ IPW estimates") ///
ctitle("Poverty rate")

* Average W/S income
// teffects ipw (dd_avemer_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet 
* Run step by step
* 1. Run probit
probit empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9
* 2. Obtain predicted probabilities
predict ps if e(sample)
* 3. Define IPWs
gen ipw = 1 if empz == 1
replace ipw = ps/(1-ps) if empz == 0
* Run regressions -- these regressions produce the same estimates that the teffects ipw command does (above) however, the standard errors are not the same. This is because (according to Stata documentation -- https://www.stata.com/manuals/teteffectsipw.pdf) the teffects ipw command adjusts the standard errors to account for the second stage using estimated values of the propensity score from the first stage.
reg dd_unemprt_ncdb empz [pw = ipw]
reg dd_povrat_ncdb empz [pw = ipw]
reg dd_frac_ncdb empz [pw = ipw]
reg dd_indemp_ncdb empz [pw = ipw]
reg dd_avemer_ncdb empz [pw = ipw]
outreg2 using "${tables}Appendix Table A5. Panel 4. EMPZ IPW estimates.xls", append title("Appendix Table A5. Panel 4. EMPZ IPW estimates") ///
ctitle("Aveage W/S income")

* Fraction
teffects ipw (dd_frac_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A5. Panel 4. EMPZ IPW estimates.xls", append title("Appendix Table A5. Panel 4. EMPZ IPW estimates") ///
ctitle("Fraction with W/S income")

* Employment
//teffects ipw (dd_indemp_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
reg dd_indemp_ncdb empz [pw = ipw]
outreg2 using "${tables}Appendix Table A5. Panel 4. EMPZ IPW estimates.xls", append title("Appendix Table A5. Panel 4. EMPZ IPW estimates") ///
ctitle("Employment")


tab empz if e(sample) // Number of treated and controls
codebook county if e(sample) // Number of counties




********************************************************************************
********************************************************************************
* Appendix Table A5. Panel 5. Robustness of ENTZ PSM triple difference estimates - using additional matched tracts
********************************************************************************
********************************************************************************

* Import data
use empz_all_reg, clear
			
* Unemployment
teffects psmatch (dd_unemprt_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors.xls", replace title("Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors.xls", append title("Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors.xls", append title("Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors.xls", append title("Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (empz unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2) gen(match)
outreg2 using "${tables}Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors.xls", append title("Appendix Table A5. Panel 5. EMPZ PS estimates - Two nearest neighbors") ///
ctitle("Employment")			


* Counties
codebook county if e(sample)

* Number of empz and Nempz observations
tab empz if e(sample)
* Number of unique controls
* Keep match1
preserve
keep if empz == 1
keep match1
tempfile match1
save `match1', replace
restore

* Append to match2 and determine number of unique matches
keep if empz == 1
keep match2
rename match2 match1
append using `match1'
codebook match1




********************************************************************************
********************************************************************************
* Appendix Table A6. Panels 1 and 2. Robustness of ENTC PSM triple difference estimates
********************************************************************************
********************************************************************************

********************************************************************************
* Create data for tables
********************************************************************************

* Only need to do this for the PS models. Table will have two rows: excluding nearest and excluding contiguous tracts.

* Import all data
use entc_all_reg, clear
drop entcid
rename tractid entcid

* Identify nearest control tracts using flags.
preserve
use "hsis_NCDB_nearest_entc.dta", clear
keep nentcid
gen near_ctrl = 1
rename nentcid entcid
duplicates drop

tempfile near_ctrl
save `near_ctrl', replace
restore

* Identify contiguous control tracts using flags.
preserve
use "hsis_NCDB_contiguous_entc.dta", clear
keep nentc*
rename nentcid nentc0id
foreach i of numlist 0/10 {
rename nentc`i'id nentc`i'
}

* Reshape wide to long
gen n = _n
reshape long nentc, i(n) j(id)
keep nentc
drop if missing(nentc)
duplicates drop
rename nentc entcid
gen contig_ctrl = 1

tempfile contig_ctrl
save `contig_ctrl', replace
restore

merge 1:1 entcid using `near_ctrl'
drop if _merge == 2
drop _merge
merge 1:1 entcid using `contig_ctrl'
drop if _merge == 2
drop _merge

tab entc contig_ctrl

* Nearest controls
gen entc_near = entc
replace entc_near = . if near_ctrl == 1 & entc_near == 0
tab entc_near entc,m // We drop 158 controls

* Contigous controls
gen entc_contig = entc
replace entc_contig = . if contig_ctrl == 1 & entc_contig == 0

tab entc_contig entc,m // We drop 422 contiguous controls

save app_tab2, replace


********************************************************************************
* Run estimates
********************************************************************************

* Use data
use app_tab2, clear

						* Panel 1. No nearest controls included

* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entc_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet gen(match)
outreg2 using "${tables}Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls.xls", replace title("Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (entc_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls.xls", append title("Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (entc_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls.xls", append title("Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (entc_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls.xls", append title("Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entc_near unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls.xls", append title("Appendix Table A6. Panel 1. ENTC PS estimates - No nearest controls") ///
ctitle("Employment")

tab entc_near if e(sample) // Number of treated and controls
codebook match if e(sample) & entc_near==0 // Number of unique matched control tracts
codebook county if e(sample) // Number of counties
drop match
			* Panel 2. No contiguous controls included
			
* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entc_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet gen(match)
outreg2 using "${tables}Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls.xls", replace title("Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (entc_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls.xls", append title("Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (entc_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls.xls", append title("Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (entc_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls.xls", append title("Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entc_contig unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls.xls", append title("Appendix Table A6. Panel 2. ENTC PS estimates - No contiguous controls") ///
ctitle("Employment")			


tab entc_contig if e(sample) // Number of treated and controls
codebook match if e(sample) & entc_contig==0 // Number of unique matched control tracts
codebook county if e(sample) // Number of counties
drop match



********************************************************************************
********************************************************************************
* Appendix Table A6. Panel 3. Robustness of ENTC PSM triple difference estimates
********************************************************************************
********************************************************************************

* Import data
use entc_all_reg, clear

logit entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9

predict ps
egen sd_ps = sd(ps)
gen caliper = 0.2 * sd_ps // https://onlinelibrary.wiley.com/doi/full/10.1002/pst.433 
// and 
// https://www.ncbi.nlm.nih.gov/pmc/articles/PMC3144483/
global caliper = caliper


* Unemployment
* Run with caliper to identify restricted sample
capture noi teffects psmatch (dd_unemprt_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet caliper($caliper) osample(drop)

* Run estimates again without setting the caliper (the sample is already restricted)
teffects psmatch (dd_unemprt_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit)  if drop == 0, atet gen(match)
tab entc if e(sample)
outreg2 using "${tables}Appendix Table A6. Panel 3. ENTC PS estimates with caliper.xls", replace title("Appendix Table A6. Panel 3. ENTC PS estimates with caliper") ///
ctitle("Unemployment rate")

* Poverty
capture noi teffects psmatch (dd_povrat_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A6. Panel 3. ENTC PS estimates with caliper.xls", append title("Appendix Table A6. Panel 3. ENTC PS estimates with caliper") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A6. Panel 3. ENTC PS estimates with caliper.xls", append title("Appendix Table A6. Panel 3. ENTC PS estimates with caliper") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A6. Panel 3. ENTC PS estimates with caliper.xls", append title("Appendix Table A6. Panel 3. ENTC PS estimates with caliper") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit) if drop == 0, atet
outreg2 using "${tables}Appendix Table A6. Panel 3. ENTC PS estimates with caliper.xls", append title("Appendix Table A6. Panel 3. ENTC PS estimates with caliper") ///
ctitle("Employment")

* Number of entc and Nentc observations
tab entc if e(sample)
* Number of unique controls
codebook match if e(sample) & entc == 0
codebook entcid if e(sample) & entc==0
codebook county if e(sample)
drop match


********************************************************************************
********************************************************************************
* Appendix Table A6. Panel 4. Robustness of ENTC PSM triple difference estimates
********************************************************************************
********************************************************************************

* Import data
use entc_all_reg, clear

* Run step by step
* 1. Run probit
probit entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9
* 2. Obtain predicted probabilities
predict ps if e(sample)
* 3. Define IPWs
gen ipw = 1 if entc == 1
replace ipw = ps/(1-ps) if entc == 0
* Run regressions -- these regressions produce the same estimates that the teffects ipw command does (above) however, the standard errors are not the same. This is because (according to Stata documentation -- https://www.stata.com/manuals/teteffectsipw.pdf) the teffects ipw command adjusts the standard errors to account for the second stage using estimated values of the propensity score from the first stage.

* Unemployment
//teffects ipw (dd_unemprt_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
reg dd_unemprt_ncdb entc [pw = ipw]
outreg2 using "${tables}Appendix Table A6. Panel 4. ENTC IPW estimates.xls", replace title("Appendix Table A6. Panel 4. ENTC IPW estimates") ///
ctitle("Unemployment rate")

* Poverty
teffects ipw (dd_povrat_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
outreg2 using "${tables}Appendix Table A6. Panel 4. ENTC IPW estimates.xls", append title("Appendix Table A6. Panel 4. entc IPW estimates") ///
ctitle("Poverty rate")

* Average W/S income
// teffects ipw (dd_avemer_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet 
reg dd_avemer_ncdb entc [pw = ipw]
outreg2 using "${tables}Appendix Table A6. Panel 4. ENTC IPW estimates.xls", append title("Appendix Table A6. Panel 4. ENTC IPW estimates") ///
ctitle("Aveage W/S income")

* Fraction
//teffects ipw (dd_frac_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
reg dd_frac_ncdb entc [pw = ipw]
outreg2 using "${tables}Appendix Table A6. Panel 4. ENTC IPW estimates.xls", append title("Appendix Table A6. Panel 4. ENTC IPW estimates") ///
ctitle("Fraction with W/S income")

* Employment
// teffects ipw (dd_indemp_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet
reg dd_indemp_ncdb entc [pw = ipw]
outreg2 using "${tables}Appendix Table A6. Panel 4. ENTC IPW estimates.xls", append title("Appendix Table A6. Panel 4. entc IPW estimates") ///
ctitle("Employment")


tab entc if e(sample) // Number of treated and controls
codebook county if e(sample) // Number of counties





********************************************************************************
********************************************************************************
* Appendix Table A6. Panel 5. Robustness of ENTZ PSM triple difference estimates - using additional matched tracts
********************************************************************************
********************************************************************************

* Import data
use entc_all_reg, clear
			
* Unemployment
teffects psmatch (dd_unemprt_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors.xls", replace title("Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors") ///
ctitle("Unemployment rate")

* Poverty
teffects psmatch (dd_povrat_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors.xls", append title("Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors") ///
ctitle("Poverty rate")

* Average W/S income
teffects psmatch (dd_avemer_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors.xls", append title("Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors") ///
ctitle("Aveage W/S income")

* Fraction
teffects psmatch (dd_frac_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2)
outreg2 using "${tables}Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors.xls", append title("Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors") ///
ctitle("Fraction with W/S income")

* Employment
teffects psmatch (dd_indemp_ncdb) (entc unemprt8 unemprt9 povrat8 povrat9 avemer8 avemer9 frac8 frac9 indemp8 indemp9, probit), atet nn(2) gen(match)
outreg2 using "${tables}Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors.xls", append title("Appendix Table A6. Panel 5. ENTC PS estimates - Two nearest neighbors") ///
ctitle("Employment")			


* Counties
codebook county if e(sample)

* Number of entc and Nentc observations
tab entc if e(sample)
* Number of unique controls
* Keep match1
preserve
keep if entc == 1
keep match1
tempfile match1
save `match1', replace
restore

* Append to match2 and determine number of unique matches
keep if entc == 1
keep match2
rename match2 match1
append using `match1'
codebook match1

